#!/bin/sh

#  -----------------------------------------------------------------------------
#  Gracenote (A Nielsen Company) Proprietary Information
#  This software is supplied under the terms of a license agreement or
#  nondisclosure agreement with Nielsen/Gracenote, Inc. and may not be copied
#  or disclosed except in accordance with the terms of that agreement.
#  Copyright(c) 2020-present. Gracenote, A Nielsen Company, All Rights Reserved.
#  -----------------------------------------------------------------------------

#  =============================================================================
#  DB inserts for Mongo
#  =============================================================================

. $GXD_PDK_DIR/bin/functions.sh
load_config

VARS=$GXD_PDK_DIR/vars
GXD_JSONL_DIR=$GXD_PDK_DIR/files/jsonl
echo "JOB_PHASE=INSERT" > $VARS/job_phase.var

SCHEMA_STAGE=${SCHEMA_PREFIX}_stage

echo

# Check which step the script failed on during previous run, if any
# If it is not 0, we'll skip to the failed step
JOB_STATUS=$1
if  [ $JOB_STATUS = "ERROR" ] &&
	[ -e $VARS/job_phase_step.var ]
then
	. $VARS/job_phase_step.var
else
	JOB_PHASE_STEP=0
fi


# 1. Run inserts for each entity
if [ $JOB_PHASE_STEP -le 1 ]; then
	echo "JOB_PHASE_STEP=1" > $VARS/job_phase_step.var

	ENTITIES=$( cut -f1 $GXD_PDK_DIR/config/$ENTITY_CONFIGS )
	for ENTITY in $ENTITIES; do
		if [ -e $GXD_PDK_DIR/files/jsonl/$ENTITY.jsonl ]; then

			# Run inserts; drop stage collection before inserting
			msg_ok "INSERT: $PYTHON db_mongo/inserts.py $ENTITY files/jsonl $SCHEMA_STAGE TRUE"
			$PYTHON $GXD_PDK_DIR/bin/db_mongo/inserts.py $ENTITY $GXD_JSONL_DIR $SCHEMA_STAGE TRUE
			if [ $? != 0 ]; then
				msg_err "INSERT: ERROR: $PYTHON db_mongo/inserts.py $ENTITY files/jsonl $SCHEMA_STAGE TRUE returned error"
				exit_abnormal
			fi

			# Once JSONL successfully inserted, delete/log JSONL
			if [ $WITH_JSONL_AFTER_IMPORT = "DELETE" ]; then
				rm -f $GXD_JSONL_DIR/$ENTITY.jsonl
			elif [ $WITH_JSONL_AFTER_IMPORT = "LOG" ]; then
				mkdir -p $GXD_LOG_DIR/jsonl
				gzip -f $GXD_JSONL_DIR/$ENTITY.jsonl
				mv $GXD_JSONL_DIR/$ENTITY.gz $GXD_LOG_DIR/jsonl/
			fi			
		else
			msg_ok "INSERT: No JSONL file for $ENTITY"
		fi
	done
	echo
fi


# Once all steps ran successfully, clear previously failed step (if any)
rm -f $VARS/job_phase_step.var

echo
