#!/bin/sh

#  -----------------------------------------------------------------------------
#  Gracenote (A Nielsen Company) Proprietary Information
#  This software is supplied under the terms of a license agreement or
#  nondisclosure agreement with Nielsen/Gracenote, Inc. and may not be copied
#  or disclosed except in accordance with the terms of that agreement.
#  Copyright(c) 2020-present. Gracenote, A Nielsen Company, All Rights Reserved.
#  -----------------------------------------------------------------------------

#  =============================================================================
#  Staging sequence for Mongo
#  =============================================================================

. $GXD_PDK_DIR/bin/functions.sh
load_config

VARS=$GXD_PDK_DIR/vars
GXD_JSONL_DIR=$GXD_PDK_DIR/files/jsonl
echo "JOB_PHASE=STAGE" > $VARS/job_phase.var

SCHEMA_STAGE=${SCHEMA_PREFIX}_stage

echo

# Check which step the script failed on during previous run, if any
# If it is not 0, we'll skip to the failed step
JOB_STATUS=$1
if  [ $JOB_STATUS = "ERROR" ] &&
	[ -e $VARS/job_phase_step.var ]
then
	. $VARS/job_phase_step.var
else
	JOB_PHASE_STEP=0
fi

# 1. De-duplicate objects with multiple updates per object (possibility with longer update runs)
if [ $JOB_PHASE_STEP -le 1 ]; then
	echo "JOB_PHASE_STEP=1" > $VARS/job_phase_step.var

	while read -r ENTITY_CONFIG; do
		ENTITY=$( echo "$ENTITY_CONFIG" | cut -f1 )

		msg_ok "STAGE: $PYTHON db_mongo/stage_dedupe.py $SCHEMA_STAGE $ENTITY"
		$PYTHON $GXD_PDK_DIR/bin/db_mongo/stage_dedupe.py $SCHEMA_STAGE $ENTITY
		if [ $? != 0 ]; then
			msg_err "STAGE: ERROR: $PYTHON db_mongo/stage_dedupe.py $SCHEMA_STAGE $ENTITY returned error"
			exit_abnormal
		fi
	done < $GXD_PDK_DIR/config/$ENTITY_CONFIGS
	echo
fi


# Once all steps ran successfully, clear previously failed step (if any)
rm -f $VARS/job_phase_step.var

echo
