#!/bin/sh

#  -----------------------------------------------------------------------------
#  Gracenote (A Nielsen Company) Proprietary Information
#  This software is supplied under the terms of a license agreement or
#  nondisclosure agreement with Nielsen/Gracenote, Inc. and may not be copied
#  or disclosed except in accordance with the terms of that agreement.
#  Copyright(c) 2020-present. Gracenote, A Nielsen Company, All Rights Reserved.
#  -----------------------------------------------------------------------------

#  =============================================================================
#  DB inserts for Postgres
#  =============================================================================

. $GXD_PDK_DIR/bin/functions.sh
load_config

VARS=$GXD_PDK_DIR/vars
GXD_TSV_DIR=$GXD_PDK_DIR/files/tsv
echo "JOB_PHASE=INSERT" > $VARS/job_phase.var

SCHEMA_STAGE=${SCHEMA_PREFIX}_stage

echo

# Check which step the script failed on during previous run, if any
# If it is not 0, we'll skip to the failed step
JOB_STATUS=$1
if  [ $JOB_STATUS = "ERROR" ] &&
	[ -e $VARS/job_phase_step.var ]
then
	. $VARS/job_phase_step.var
else
	JOB_PHASE_STEP=0
fi

# 1. Create schema
if [ $JOB_PHASE_STEP -le 1 ]; then
	echo "JOB_PHASE_STEP=1" > $VARS/job_phase_step.var

	if [ -e $VARS/last_good_ingest_id.var ]; then
		. $VARS/last_good_ingest_id.var
	fi

	# Check if schema exists first
	msg_ok "INSERT: $PYTHON db_pgsql/runsql.py \"SELECT 'TRUE' AS result FROM pg_namespace WHERE nspname = '${SCHEMA_STAGE}';\""
	SCHEMA_EXISTS=$( echo "SELECT 'TRUE' AS result FROM pg_namespace WHERE nspname = '{0}';" | $PYTHON $GXD_PDK_DIR/bin/db_pgsql/runsql.py "" "$SCHEMA_STAGE" FALSE ";" "FETCH_ONE" )
	if [ $? != 0 ]; then
		msg_err "INSERT: ERROR: $PYTHON db_pgsql/runsql.py \"SELECT 'TRUE' AS result FROM pg_namespace WHERE nspname = '${SCHEMA_STAGE}';\" returned error"
		exit_abnormal
	fi

	if [ "$SCHEMA_EXISTS" != "TRUE" ]; then
		msg_ok "INSERT: $PYTHON db_pgsql/runsql.py db/pgsql/schema_stage.sql '$SCHEMA_STAGE|$PGSQL_USER' FALSE ;"
		$PYTHON $GXD_PDK_DIR/bin/db_pgsql/runsql.py $GXD_PDK_DIR/db/pgsql/schema_stage.sql "$SCHEMA_STAGE|$PGSQL_USER" FALSE ";"
		if [ $? != 0 ]; then
			msg_err "INSERT: ERROR: $PYTHON db_pgsql/runsql.py db/pgsql/schema_stage.sql returned error"
			exit_abnormal
		fi	
	fi
fi

# 2. Run inserts for each table/TSV
if [ $JOB_PHASE_STEP -le 2 ]; then
	echo "JOB_PHASE_STEP=2" > $VARS/job_phase_step.var

	TABLES=$( cut -f2 $GXD_PDK_DIR/config/$FIELD_CONFIGS | sort | uniq )
	for TABLE in $TABLES; do
		if [ -e $GXD_PDK_DIR/files/tsv/$TABLE.tsv ]; then

			# Clear destination table prior to inserting
			msg_ok "INSERT: $PYTHON db_pgsql/runsql.py \"DELETE FROM $SCHEMA_STAGE.$TABLE;\""
			echo "DELETE FROM {0}.{1};" | $PYTHON $GXD_PDK_DIR/bin/db_pgsql/runsql.py "" "$SCHEMA_STAGE|$TABLE"
			if [ $? != 0 ]; then
				msg_err "INSERT: ERROR: $PYTHON db_pgsql/runsql.py \"DELETE FROM $SCHEMA_STAGE.$TABLE;\" returned error"
				exit_abnormal
			fi
			# Run inserts
			msg_ok "INSERT: $PYTHON db_pgsql/inserts.py $TABLE files/tsv $SCHEMA_STAGE"
			$PYTHON $GXD_PDK_DIR/bin/db_pgsql/inserts.py $TABLE $GXD_TSV_DIR $SCHEMA_STAGE
			if [ $? != 0 ]; then
				msg_err "INSERT: ERROR: $PYTHON db_pgsql/inserts.py $TABLE files/tsv config/config.sh $SCHEMA_STAGE returned error"
				exit_abnormal
			fi
			# Once TSV successfully inserted, delete/log TSV
			if [ $WITH_TSV_AFTER_IMPORT = "DELETE" ]; then
				rm -f $GXD_TSV_DIR/$TABLE.tsv
			elif [ $WITH_TSV_AFTER_IMPORT = "LOG" ]; then
				mkdir -p $GXD_LOG_DIR/tsv
				gzip -f $GXD_TSV_DIR/$TABLE.tsv
				mv $GXD_TSV_DIR/$TABLE.tsv.gz $GXD_LOG_DIR/tsv/
			fi			
		else
			msg_ok "INSERT: No TSV file for $TABLE"
		fi
	done
	echo
fi

# Once all steps ran successfully, clear previously failed step (if any)
rm -f $VARS/job_phase_step.var

echo
