#!/bin/sh

#  -----------------------------------------------------------------------------
#  Gracenote (A Nielsen Company) Proprietary Information
#  This software is supplied under the terms of a license agreement or
#  nondisclosure agreement with Nielsen/Gracenote, Inc. and may not be copied
#  or disclosed except in accordance with the terms of that agreement.
#  Copyright(c) 2020-present. Gracenote, A Nielsen Company, All Rights Reserved.
#  -----------------------------------------------------------------------------

#  =============================================================================
#  Core update sequence for Postgres
#  =============================================================================

. $GXD_PDK_DIR/bin/functions.sh
load_config

VARS=$GXD_PDK_DIR/vars
GXD_TSV_DIR=$GXD_PDK_DIR/files/tsv
echo "JOB_PHASE=CORE_UPDATE" > $VARS/job_phase.var

SCHEMA_CORE=${SCHEMA_PREFIX}_core
SCHEMA_STAGE=${SCHEMA_PREFIX}_stage

echo

# Check which step the script failed on during previous run, if any
# If it is not 0, we'll skip to the failed step
JOB_STATUS=$1
if  [ $JOB_STATUS = "ERROR" ] &&
	[ -e $VARS/job_phase_step.var ]
then
	. $VARS/job_phase_step.var
else
	JOB_PHASE_STEP=0
fi

while read LINE; do
	PDK_VER=$LINE
done < $GXD_PDK_DIR/docs/version.txt

if [ $BOOL_TO_INT = "TRUE" ]; then
	TRUTH_VALUE="1"
else
	TRUTH_VALUE="TRUE"
fi

# 1. Create schema
if [ $JOB_PHASE_STEP -le 1 ]; then
	echo "JOB_PHASE_STEP=1" > $VARS/job_phase_step.var

	if [ -e $VARS/last_good_ingest_id.var ]; then
		. $VARS/last_good_ingest_id.var
	fi

	# Check if it exists first
	msg_ok "UPDATE: $PYTHON db_pgsql/runsql.py \"SELECT 'TRUE' AS result FROM pg_namespace WHERE nspname = '${SCHEMA_CORE}';\""
	SCHEMA_EXISTS=$( echo "SELECT 'TRUE' AS result FROM pg_namespace WHERE nspname = '{0}';" | $PYTHON $GXD_PDK_DIR/bin/db_pgsql/runsql.py "" "$SCHEMA_CORE" FALSE ";" "FETCH_ONE" )
	if [ $? != 0 ]; then
		msg_err "UPDATE: ERROR: $PYTHON db_pgsql/runsql.py \"SELECT 'TRUE' AS result FROM pg_namespace WHERE nspname = '${SCHEMA_CORE}';\" returned error"
		exit_abnormal
	fi

	if [ "$SCHEMA_EXISTS" != "TRUE" ]; then
		msg_ok "UPDATE: $PYTHON db_pgsql/runsql.py db/pgsql/schema_core.sql '$SCHEMA_CORE|$PGSQL_USER' FALSE ;"
		$PYTHON $GXD_PDK_DIR/bin/db_pgsql/runsql.py $GXD_PDK_DIR/db/pgsql/schema_core.sql "$SCHEMA_CORE|$PGSQL_USER" FALSE ";"
		if [ $? != 0 ]; then
			msg_err "UPDATE: ERROR: $PYTHON db_pgsql/runsql.py db/pgsql/schema_core.sql '$SCHEMA_CORE|$PGSQL_USER' returned error"
			exit_abnormal
		fi	

		# Create _vars table and initialize variables (PDK version)
		msg_ok "UPDATE: $PYTHON db_pgsql/runsql.py db/pgsql/vars.sql '$SCHEMA_CORE|$PGSQL_USER|$PDK_VER'"
		$PYTHON $GXD_PDK_DIR/bin/db_pgsql/runsql.py $GXD_PDK_DIR/db/pgsql/vars.sql "$SCHEMA_CORE|$PGSQL_USER|$PDK_VER"
		if [ $? != 0 ]; then
			msg_err "UPDATE: ERROR: $PYTHON db_pgsql/runsql.py db/pgsql/vars.sql '$SCHEMA_CORE|$PGSQL_USER|$PDK_VER' returned error"
			exit_abnormal
		fi	
	fi
fi

# 2. Optionally drop non-key constraints in core
if [ $JOB_PHASE_STEP -le 2 ]; then
	echo "JOB_PHASE_STEP=2" > $VARS/job_phase_step.var
	if [ "$PG_KEEP_IDX_ON_UPDATE" = "FALSE" ]; then

		while read -r ENTITY_CONFIG; do
			ENTITY=$( echo "$ENTITY_CONFIG" | cut -f1 )

			msg_ok "UPDATE: $PYTHON db_pgsql/runsql.py db/pgsql/update_core/${ENTITY}/drop_nonkey_constraints.sql $SCHEMA_CORE"
			$PYTHON $GXD_PDK_DIR/bin/db_pgsql/runsql.py $GXD_PDK_DIR/db/pgsql/update_core/${ENTITY}/drop_nonkey_constraints.sql $SCHEMA_CORE
			if [ $? != 0 ]; then
				msg_err "UPDATE: ERROR: $PYTHON db_pgsql/runsql.py db/pgsql/update_core/${ENTITY}/drop_nonkey_constraints.sql $SCHEMA_CORE returned error"
				exit_abnormal
			fi
		done < $GXD_PDK_DIR/config/$ENTITY_CONFIGS
	fi
fi

# 3. Optionally drop non-key indexes in core
if [ $JOB_PHASE_STEP -le 3 ]; then
	echo "JOB_PHASE_STEP=3" > $VARS/job_phase_step.var
	if [ "$PG_KEEP_IDX_ON_UPDATE" = "FALSE" ]; then

		while read -r ENTITY_CONFIG; do
			ENTITY=$( echo "$ENTITY_CONFIG" | cut -f1 )

			msg_ok "UPDATE: $PYTHON db_pgsql/runsql.py db/pgsql/update_core/${ENTITY}/drop_nonkey_indexes.sql $SCHEMA_CORE"
			$PYTHON $GXD_PDK_DIR/bin/db_pgsql/runsql.py $GXD_PDK_DIR/db/pgsql/update_core/${ENTITY}/drop_nonkey_indexes.sql $SCHEMA_CORE
			if [ $? != 0 ]; then
				msg_err "UPDATE: ERROR: $PYTHON db_pgsql/runsql.py db/pgsql/update_core/${ENTITY}/drop_nonkey_indexes.sql $SCHEMA_CORE returned error"
				exit_abnormal
			fi
		done < $GXD_PDK_DIR/config/$ENTITY_CONFIGS
	fi
fi

# 4. Insert new entities
if [ $JOB_PHASE_STEP -le 4 ]; then
	echo "JOB_PHASE_STEP=4" > $VARS/job_phase_step.var

	while read -r ENTITY_CONFIG; do
		ENTITY=$( echo "$ENTITY_CONFIG" | cut -f1 )
		# Insert new entities into core (regardless of stage delete or inactive flag value)
		msg_ok "UPDATE: $PYTHON db_pgsql/runsql.py db/pgsql/update_core/${ENTITY}/insert_new_all.sql '$SCHEMA_STAGE|$SCHEMA_CORE'"
		$PYTHON $GXD_PDK_DIR/bin/db_pgsql/runsql.py $GXD_PDK_DIR/db/pgsql/update_core/${ENTITY}/insert_new_all.sql "$SCHEMA_STAGE|$SCHEMA_CORE"
		if [ $? != 0 ]; then
			msg_err "UPDATE: ERROR: $PYTHON db_pgsql/runsql.py db/pgsql/update_core/${ENTITY}/insert_new_all.sql '$SCHEMA_STAGE|$SCHEMA_CORE' returned error"
			exit_abnormal
		fi
	done < $GXD_PDK_DIR/config/$ENTITY_CONFIGS
fi

# 5. Update new+existing entities in batches
if [ $JOB_PHASE_STEP -le 5 ]; then
	echo "JOB_PHASE_STEP=5" > $VARS/job_phase_step.var

	# Since we're advancing entity by entity, ensure that tracker is created (or exists) to record successfully processed entities
	touch $VARS/job_phase_step_tracker.var

	while read -r BATCH_CONFIG; do
		ENTITY=$( echo "$BATCH_CONFIG" | cut -f1 )
		BATCH_SIZE=$( echo "$BATCH_CONFIG" | cut -f2 )

		# Only proceed if the entity has not already been successfully processed
		FOUND=$( grep -w $ENTITY $VARS/job_phase_step_tracker.var )
		if [ "$FOUND" = "" ]; then

			# Retrieve max batch ordinal for the current table (need deterministic order for batched updates)
			msg_ok "UPDATE: $PYTHON db_pgsql/runsql.py db/pgsql/update_core/${ENTITY}/get_max_batch_ordinal.sql '$SCHEMA_STAGE|$ENTITY'"
			ROW_COUNT=$( $PYTHON $GXD_PDK_DIR/bin/db_pgsql/runsql.py db/pgsql/update_core/${ENTITY}/get_max_batch_ordinal.sql "$SCHEMA_STAGE|$ENTITY" FALSE ";" "FETCH_ONE" )
			if [ $? != 0 ]; then
				msg_err "UPDATE: ERROR: $PYTHON db_pgsql/runsql.py db/pgsql/update_core/${ENTITY}/get_max_batch_ordinal.sql '$SCHEMA_STAGE|$ENTITY' returned error"
				exit_abnormal
			fi
			msg_ok "UPDATE: -> $ROW_COUNT"

			# Skip table if no rows
			if [ "$ROW_COUNT" = "0" ]; then
				continue
			else
				# Otherwise calculate required number of update batches and proceed to update
				NUM_BATCHES=$(( (ROW_COUNT - 1) / BATCH_SIZE + 1 ))

				# Experimental support for multiple Pg update threads
				if [ -z "$PG_CORE_UPDATE_THREADS" ]; then	# single thread
					:
				else
					NUM_THREADS=$PG_CORE_UPDATE_THREADS
					NUM_FAILS=0
					THREAD=0
				fi

				BATCH=0
				# Load any previously stored batch number (in case of previous error) for the entity
				if [ -e $VARS/update_core_${ENTITY}_batch.var ]; then
				    . $VARS/update_core_${ENTITY}_batch.var
				    msg_ok "UPDATE: Found previously stored update batch number for ${ENTITY}, resuming update from batch ${BATCH}"
				fi

				while [ $BATCH -lt $NUM_BATCHES ]; do
					LOWER_BOUND=$((BATCH_SIZE * BATCH))
					UPPER_BOUND=$((LOWER_BOUND + BATCH_SIZE))

					if [ "$UPDATE_FLAGS" = "TRUE" ]; then
						# Update non-deleted, non-inactive entities from stage to core; for deleted, then inactive entities, update corresponding core flag and updateId, updateDate, ingestId fields only
						msg_ok "UPDATE: $PYTHON db_pgsql/runsql.py db/pgsql/update_core/${ENTITY}/update_batch.sql '$SCHEMA_STAGE|$SCHEMA_CORE|$LOWER_BOUND|$UPPER_BOUND|$TRUTH_VALUE'"

						# Experimental support for multiple Pg update threads
						if [ -z "$PG_CORE_UPDATE_THREADS" ]; then	# single thread
							$PYTHON $GXD_PDK_DIR/bin/db_pgsql/runsql.py $GXD_PDK_DIR/db/pgsql/update_core/${ENTITY}/update_batch.sql "$SCHEMA_STAGE|$SCHEMA_CORE|$LOWER_BOUND|$UPPER_BOUND|$TRUTH_VALUE" FALSE ";"
						else
							$PYTHON $GXD_PDK_DIR/bin/db_pgsql/runsql.py $GXD_PDK_DIR/db/pgsql/update_core/${ENTITY}/update_batch.sql "$SCHEMA_STAGE|$SCHEMA_CORE|$LOWER_BOUND|$UPPER_BOUND|$TRUTH_VALUE" FALSE ";" &	
						fi

						if [ $? != 0 ]; then
							msg_err "UPDATE: ERROR: $PYTHON db_pgsql/runsql.py db/pgsql/update_core/${ENTITY}/update_batch.sql '$SCHEMA_STAGE|$SCHEMA_CORE|$LOWER_BOUND|$UPPER_BOUND|$TRUTH_VALUE' returned error"
							exit_abnormal
						fi
					else
						# Update entities from stage to core in their entirety regardless of flags
						msg_ok "UPDATE: $PYTHON db_pgsql/runsql.py db/pgsql/update_core/${ENTITY}/update_batch_all.sql '$SCHEMA_STAGE|$SCHEMA_CORE|$LOWER_BOUND|$UPPER_BOUND'"

						# Experimental support for multiple Pg update threads
						if [ -z "$PG_CORE_UPDATE_THREADS" ]; then	# single thread
							$PYTHON $GXD_PDK_DIR/bin/db_pgsql/runsql.py $GXD_PDK_DIR/db/pgsql/update_core/${ENTITY}/update_batch_all.sql "$SCHEMA_STAGE|$SCHEMA_CORE|$LOWER_BOUND|$UPPER_BOUND" FALSE ";"
						else
							$PYTHON $GXD_PDK_DIR/bin/db_pgsql/runsql.py $GXD_PDK_DIR/db/pgsql/update_core/${ENTITY}/update_batch_all.sql "$SCHEMA_STAGE|$SCHEMA_CORE|$LOWER_BOUND|$UPPER_BOUND" FALSE ";" &
						fi

						if [ $? != 0 ]; then
							msg_err "UPDATE: ERROR: $PYTHON db_pgsql/runsql.py db/pgsql/update_core/${ENTITY}/update_batch_all.sql '$SCHEMA_STAGE|$SCHEMA_CORE|$LOWER_BOUND|$UPPER_BOUND' returned error"
							exit_abnormal
						fi
					fi

					BATCH=$((BATCH + 1))

					# Experimental support for multiple Pg update threads
					if [ -z "$PG_CORE_UPDATE_THREADS" ]; then	# single thread
						echo "BATCH=$BATCH" > $VARS/update_core_${ENTITY}_batch.var

					else
						# Iterate on outer loop to spawn additional threads
						THREAD=$((THREAD + 1))

						# Or wait for them to complete if already created NUM_THREADS
						if  [ $THREAD -ge $NUM_THREADS ] || [ $BATCH -ge $NUM_BATCHES ]
						then
							# Output pids of spawned threads to a temp file
							jobs -p > $VARS/update_core_${ENTITY}_pids.tsv

							# Compare pid count with number of spawned threads (given by $THREAD), they should be the same. This is JIC a thread fails before `jobs` runs.
							PID_COUNT=$( wc -l < $VARS/update_core_${ENTITY}_pids.tsv | tr -d ' ')		# get linecount and strip whitespace
							if [ "$PID_COUNT" != "$THREAD" ]; then
								msg_err "UPDATE: ERROR: PID_COUNT ($PID_COUNT) does not equal to number of threads ($THREAD)"
								exit_abnormal
							fi

							# Wait for threads to complete/fail
							while read -r PID; do
								wait $PID || NUM_FAILS=$((NUM_FAILS + 1))
							done < $VARS/update_core_${ENTITY}_pids.tsv
							rm $VARS/update_core_${ENTITY}_pids.tsv

							# Exit if any errors were encountered
							if [ $NUM_FAILS != "0" ]; then
								msg_err "UPDATE: ERROR: $NUM_FAILS parallel update_core process(es) returned an error"
								exit_abnormal
							fi

							# Threads completed successfully, proceed with next set of threads
							THREAD=0
							echo "BATCH=$BATCH" > $VARS/update_core_${ENTITY}_batch.var
						fi
					fi
				done

				# Remove batch counter if all batches have been successfully processed
				rm -f $VARS/update_core_${ENTITY}_batch.var
			fi

			# Record entity as successfully processed
			echo "$ENTITY" >> $VARS/job_phase_step_tracker.var

		else
			msg_ok "UPDATE: Entity $ENTITY has already been processed"
		fi

	done < $GXD_PDK_DIR/config/$ENTITY_CONFIGS

	# Remove tracker if all entities have been successfully processed
	rm -f $VARS/job_phase_step_tracker.var		
fi

# 6. If processing deletes, delete children in core, for each entity
if [ $JOB_PHASE_STEP -le 6 ]; then
	echo "JOB_PHASE_STEP=6" > $VARS/job_phase_step.var
	if [ $DB_DELETES = "TRUE" ]; then

		while read -r ENTITY_CONFIG; do
			ENTITY=$( echo "$ENTITY_CONFIG" | cut -f1 )

			msg_ok "UPDATE: $PYTHON db_pgsql/runsql.py db/pgsql/update_core/${ENTITY}/delete_children.sql '$SCHEMA_STAGE|$SCHEMA_CORE|$TRUTH_VALUE'"
			$PYTHON $GXD_PDK_DIR/bin/db_pgsql/runsql.py $GXD_PDK_DIR/db/pgsql/update_core/${ENTITY}/delete_children.sql "$SCHEMA_STAGE|$SCHEMA_CORE|$TRUTH_VALUE" FALSE ";"
			if [ $? != 0 ]; then
				msg_err "UPDATE: ERROR: $PYTHON db_pgsql/runsql.py db/pgsql/update_core/${ENTITY}/delete_children.sql '$SCHEMA_STAGE|$SCHEMA_CORE|$TRUTH_VALUE' returned error"
				exit_abnormal
			fi

		done < $GXD_PDK_DIR/config/$ENTITY_CONFIGS
	fi
fi

# 7. If processing deletes, delete core entities (updating self-references - if any - to NULL)
if [ $JOB_PHASE_STEP -le 7 ]; then
	echo "JOB_PHASE_STEP=7" > $VARS/job_phase_step.var
	if [ $DB_DELETES = "TRUE" ]; then

		while read -r ENTITY_CONFIG; do
			ENTITY=$( echo "$ENTITY_CONFIG" | cut -f1 )

			msg_ok "UPDATE: $PYTHON db_pgsql/runsql.py db/pgsql/update_core/${ENTITY}/delete_entities.sql '$SCHEMA_STAGE|$SCHEMA_CORE|$TRUTH_VALUE'"
			$PYTHON $GXD_PDK_DIR/bin/db_pgsql/runsql.py $GXD_PDK_DIR/db/pgsql/update_core/${ENTITY}/delete_entities.sql "$SCHEMA_STAGE|$SCHEMA_CORE|$TRUTH_VALUE"
			if [ $? != 0 ]; then
				msg_err "UPDATE: ERROR: $PYTHON db_pgsql/runsql.py db/pgsql/update_core/${ENTITY}/delete_entities.sql '$SCHEMA_STAGE|$SCHEMA_CORE|$TRUTH_VALUE' returned error"
				exit_abnormal
			fi
		done < $GXD_PDK_DIR/config/$ENTITY_CONFIGS
	fi
fi

# 8. Drop stage indexes
if [ $JOB_PHASE_STEP -le 8 ]; then
	echo "JOB_PHASE_STEP=8" > $VARS/job_phase_step.var

	while read -r ENTITY_CONFIG; do
		ENTITY=$( echo "$ENTITY_CONFIG" | cut -f1 )

		msg_ok "UPDATE: $PYTHON db_pgsql/runsql.py db/pgsql/stage/${ENTITY}/drop_indexes.sql $SCHEMA_STAGE"
		$PYTHON $GXD_PDK_DIR/bin/db_pgsql/runsql.py $GXD_PDK_DIR/db/pgsql/stage/${ENTITY}/drop_indexes.sql $SCHEMA_STAGE
		if [ $? != 0 ]; then
			msg_err "UPDATE: ERROR: $PYTHON db_pgsql/runsql.py db/pgsql/stage/${ENTITY}/drop_indexes.sql $SCHEMA_STAGE returned error"
			exit_abnormal
		fi
	done < $GXD_PDK_DIR/config/$ENTITY_CONFIGS
fi

# 9. Clear stage
if [ $JOB_PHASE_STEP -le 9 ]; then
	echo "JOB_PHASE_STEP=9" > $VARS/job_phase_step.var

	while read -r ENTITY_CONFIG; do
		ENTITY=$( echo "$ENTITY_CONFIG" | cut -f1 )

		msg_ok "UPDATE: $PYTHON db_pgsql/runsql.py db/pgsql/stage/${ENTITY}/delete_data.sql $SCHEMA_STAGE"
		$PYTHON $GXD_PDK_DIR/bin/db_pgsql/runsql.py $GXD_PDK_DIR/db/pgsql/stage/${ENTITY}/delete_data.sql $SCHEMA_STAGE
		if [ $? != 0 ]; then
			msg_err "UPDATE: ERROR: $PYTHON db_pgsql/runsql.py db/pgsql/stage/${ENTITY}/delete_data.sql $SCHEMA_STAGE returned error"
			exit_abnormal
		fi
	done < $GXD_PDK_DIR/config/$ENTITY_CONFIGS
fi

# 10. Optionally recreate non-key indexes
if [ $JOB_PHASE_STEP -le 10 ]; then
	echo "JOB_PHASE_STEP=10" > $VARS/job_phase_step.var
	if [ "$PG_KEEP_IDX_ON_UPDATE" = "FALSE" ]; then

		while read -r ENTITY_CONFIG; do
			ENTITY=$( echo "$ENTITY_CONFIG" | cut -f1 )

			msg_ok "UPDATE: $PYTHON db_pgsql/runsql.py db/pgsql/update_core/${ENTITY}/recreate_nonkey_indexes.sql $SCHEMA_CORE"
			$PYTHON $GXD_PDK_DIR/bin/db_pgsql/runsql.py $GXD_PDK_DIR/db/pgsql/update_core/${ENTITY}/recreate_nonkey_indexes.sql $SCHEMA_CORE
			if [ $? != 0 ]; then
				msg_err "UPDATE: ERROR: $PYTHON db_pgsql/runsql.py db/pgsql/update_core/${ENTITY}/recreate_nonkey_indexes.sql $SCHEMA_CORE returned error"
				exit_abnormal
			fi
		done < $GXD_PDK_DIR/config/$ENTITY_CONFIGS
	fi
fi

# 11. Optionally recreate non-key constraints
if [ $JOB_PHASE_STEP -le 11 ]; then
	echo "JOB_PHASE_STEP=11" > $VARS/job_phase_step.var
	if [ "$PG_KEEP_IDX_ON_UPDATE" = "FALSE" ]; then

		while read -r ENTITY_CONFIG; do
			ENTITY=$( echo "$ENTITY_CONFIG" | cut -f1 )

			msg_ok "UPDATE: $PYTHON db_pgsql/runsql.py db/pgsql/update_core/${ENTITY}/recreate_nonkey_constraints.sql $SCHEMA_CORE"
			$PYTHON $GXD_PDK_DIR/bin/db_pgsql/runsql.py $GXD_PDK_DIR/db/pgsql/update_core/${ENTITY}/recreate_nonkey_constraints.sql $SCHEMA_CORE
			if [ $? != 0 ]; then
				msg_err "UPDATE: ERROR: $PYTHON db_pgsql/runsql.py db/pgsql/update_core/${ENTITY}/recreate_nonkey_constraints.sql $SCHEMA_CORE returned error"
				exit_abnormal
			fi
		done < $GXD_PDK_DIR/config/$ENTITY_CONFIGS
	fi
fi

# Once all steps ran successfully, clear previously failed step
rm -f $VARS/job_phase_step.var

echo
