#  -----------------------------------------------------------------------------
#  Gracenote (A Nielsen Company) Proprietary Information
#  This software is supplied under the terms of a license agreement or
#  nondisclosure agreement with Nielsen/Gracenote, Inc. and may not be copied
#  or disclosed except in accordance with the terms of that agreement.
#  Copyright(c) 2020-present. Gracenote, A Nielsen Company, All Rights Reserved.
#  -----------------------------------------------------------------------------

#  =============================================================================
#  Parses a given ON Celebrities XML file
#  Validates each record against fields configuration file
#  Writes validated records into TSV files for the endpoint
#  =============================================================================

import os
import sys

sys.path.append(os.path.join(sys.path[0],'..'))
import gxd_functions as gxd

xml_file 	= sys.argv[1]
files_path 	= sys.argv[2]

class GnCelebritiesParser(gxd.GnEndpointParser):

	def parse(self, xml_file):

		use_natural_keys = (self.parser_options.get('natural_keys') != '0') 	# use natural keys by default

		# Override if specific option given
		if self.parser_options.get('natural_mediographyId'):
			use_natural_keys = (self.parser_options.get('natural_mediographyId') != '0') 	# use natural keys by default		

		for p in self.xml_nodes(xml_file, "on/celebrities/person"):

			celebrity = {}

			personId 	= self.check( p, 'personId' )
			updateId 	= self.check( p, 'updateId' )

			celebrity['personId']		= personId
			celebrity['updateId']		= updateId
			celebrity['updateDate'] 	= self.check( p, 'updateDate' )
			celebrity['deleted'] 		= self.format_boolean( self.check( p, 'deleted' ) )

			celebrity['type'] 		= self.check( p.find('profile/type') )
			celebrity['gender'] 	= self.check( p.find('profile/gender') )
			celebrity['birthName'] 	= self.check( p.find('profile/birthName') )
			celebrity['birthPlace'] = self.check( p.find('profile/birthPlace') )
			celebrity['birthDate'] 	= self.check( p.find('profile/birthDate') )
			celebrity['deathDate'] 	= self.check( p.find('profile/deathDate') )
			celebrity['deathPlace'] = self.check( p.find('profile/deathPlace') )
			celebrity['deathCause'] = self.check( p.find('profile/deathCause') )

			celebrity['nationality'] 	= self.check( p.find('nationality') )
			celebrity['ethnicity'] 		= self.check( p.find('ethnicity') )

			if self.do_output_tsv:
				if not self.validate_and_write_tsv(celebrity, 'celebrity', 'personId'):
					p.clear()
					continue


			for pln in p.findall('localizedPersonNames/localizedPersonName'):

				primary = self.format_boolean( self.check( pln, 'primary' ) )
				nameId 	= self.check( pln, 'nameId' )

				for ln in pln.findall('localizedName'):

					name = {}
					
					name['personId']	= personId
					name['updateId']	= updateId

					name['primary'] 	= primary
					name['nameId'] 		= nameId

					name['lang'] 		= self.check( ln, 'language' )
					name['sort'] 		= self.format_boolean( self.check( ln, 'sort' ) )

					name['first'] 		= self.check( ln.find('first') )
					name['last'] 		= self.check( ln.find('last') )
					name['middle'] 		= self.check( ln.find('middle') )
					name['prefix'] 		= self.check( ln.find('prefix') )
					name['suffix'] 		= self.check( ln.find('suffix') )

					if self.do_output_tsv:
						if not self.validate_and_write_tsv(name, 'celebrity_name', 'personId'):
							ln.clear()
							continue

					if self.do_output_jsonl:
						[ name.pop(key) for key in ['personId','updateId'] ]
						celebrity['names'] = ( celebrity.get('names') or [] ) + [ name.copy() ]

					ln.clear()

				pln.clear()


			for pa in p.findall('assets/asset'):

				asset = {}

				asset['personId']		= personId
				asset['updateId']		= updateId

				asset['assetId']		= self.check( pa, 'assetId' )
				asset['assetUpdateId']	= self.check( pa, 'updateId' )
				asset['type'] 			= self.check( pa, 'type' )
				asset['expiredDate'] 	= self.check( pa, 'expiredDate' )
				asset['lastModified'] 	= self.check( pa, 'lastModified' )
				asset['width'] 			= self.check( pa, 'width' )
				asset['height'] 		= self.check( pa, 'height' )
				asset['category'] 		= self.check( pa, 'category' )
				asset['ratio'] 			= self.check( pa, 'ratio' )
				asset['primary'] 		= self.format_boolean( self.check( pa, 'primary' ) )
				asset['deleted'] 		= self.format_boolean( self.check( pa, 'deleted' ) )			
				asset['provider'] 		= self.check( pa.find('provider') )
				asset['URI'] 			= self.check( pa.find('URI') )
				asset['caption'] 		= self.check( pa.find('caption') )
				asset['caption_lang'] 	= self.check( pa.find('caption'), 'lang' )

				if self.do_output_tsv:
					if not self.validate_and_write_tsv(asset, 'celebrity_asset', 'personId'):
						pa.clear()
						continue

				if self.do_output_jsonl:
					[ asset.pop(key) for key in ['personId','updateId'] ]
					celebrity['assets'] = ( celebrity.get('assets') or [] ) + [ asset.copy() ]

				pa.clear()

			if self.do_parse_all:

				for pba in p.findall('baselineAssets/baselineAsset'):

					asset = {}

					asset['personId']		= personId
					asset['updateId']		= updateId

					asset['assetId']		= self.check( pba, 'assetId' )
					asset['assetUpdateId'] 	= self.check( pba, 'updateId' )
					asset['type'] 			= self.check( pba, 'type' )

					asset['width'] 			= self.check( pba, 'width' )
					asset['height'] 		= self.check( pba, 'height' )
					asset['category'] 		= self.check( pba, 'category' )

					asset['URI'] 			= self.check( pba.find('url') )
					asset['caption'] 		= self.check( pba.find('caption') )
					asset['enhRank'] 		= self.check( pba.find('rank') )

					if self.do_output_tsv:
						if not self.validate_and_write_tsv(asset, 'celebrity_asset', 'personId'):
							pba.clear()
							continue

					if self.do_output_jsonl:
						[ asset.pop(key) for key in ['personId','updateId'] ]
						celebrity['assets'] = ( celebrity.get('assets') or [] ) + [ asset.copy() ]

					pba.clear()


				mediography_inc = 0
				for pmg in p.findall('mediography/production'):

					prod = {}

					rootId 			= self.check( pmg, 'rootId' )

					if use_natural_keys:
						mediographyId 	= "{}-{}".format( personId, rootId )
					else:
						mediography_inc += 1
						mediographyId 	= "{}-{}".format( personId, str(mediography_inc) )

					prod['mediographyId']	= mediographyId
					prod['personId']		= personId
					prod['updateId']		= updateId
					prod['rootId'] 			= rootId

					prod['type']			= self.check( pmg, 'type' )
					prod['year'] 			= self.check( pmg.find('year') )
					prod['title'] 			= self.check( pmg.find('title') )
					prod['title_type'] 		= self.check( pmg.find('title'), 'type' )
					prod['title_subType'] 	= self.check( pmg.find('title'), 'subType' )
					prod['title_lang'] 		= self.check( pmg.find('title'), 'lang' )

					if self.do_output_tsv:
						if not self.validate_and_write_tsv(prod, 'celebrity_mediography', 'personId'):
							pmg.clear()
							continue

					for pmgc in pmg.findall('credits/credit'):

						credit = {}

						credit['mediographyId']	= mediographyId
						credit['personId']		= personId
						credit['updateId']		= updateId

						credit['role']			= self.check( pmgc )
						credit['roleId']	 	= self.check( pmgc, 'roleId' )
						credit['nameId'] 		= self.check( pmgc, 'nameId' )
						credit['characterName'] = self.check( pmgc, 'characterName' )

						if self.do_output_tsv:
							if not self.validate_and_write_tsv(credit, 'celebrity_mediography_credit', 'mediographyId'):
								pmgc.clear()
								continue

						if self.do_output_jsonl:
							[ credit.pop(key) for key in ['personId','updateId','mediographyId'] ]
							prod['credits'] = ( prod.get('credits') or [] ) + [ credit.copy() ]

						pmgc.clear()

					if self.do_output_jsonl:
						[ prod.pop(key) for key in ['personId','updateId'] ]
						celebrity['mediography'] = ( celebrity.get('mediography') or [] ) + [ prod.copy() ]

					pmg.clear()

				for ppt in p.findall('participantTypes/participantType'):

					pt = {}

					pt['personId']	= personId
					pt['updateId']	= updateId

					pt['participantType'] 	= self.check( ppt )
					pt['isPrimary'] 		= self.format_boolean( self.check( ppt, 'isPrimary' ) )

					if self.do_output_tsv:
						if not self.validate_and_write_tsv(pt, 'celebrity_participanttype', 'personId'):
							ppt.clear()
							continue

					if self.do_output_jsonl:
						[ pt.pop(key) for key in ['personId','updateId'] ]
						celebrity['participantTypes'] = ( celebrity.get('participantTypes') or [] ) + [ pt['participantType'] ]

					pt.clear()

				for pa in p.findall('awards/award'):

					award = {}

					award['personId']		= personId
					award['updateId']		= updateId

					award['won'] 			= self.format_boolean( self.check( pa, 'won' ) )
					award['rootId'] 		= self.check( pa, 'rootId' )
					award['award'] 			= self.check( pa.find('name') )
					award['awardId'] 		= self.check( pa.find('name'), 'awardId' )
					award['category'] 		= self.check( pa.find('category') )
					award['awardCatId'] 	= self.check( pa.find('category'), 'awardCatId' )
					award['recipient'] 		= self.check( pa.find('recipient') )
					award['recipientNameId']= self.check( pa.find('recipient'), 'nameId' )
					award['year'] 			= self.check( pa.find('year') )

					if self.do_output_tsv:
						if not self.validate_and_write_tsv(award, 'celebrity_award', 'personId'):
							pa.clear()
							continue

					if self.do_output_jsonl:
						[ award.pop(key) for key in ['personId','updateId'] ]
						celebrity['awards'] = ( celebrity.get('awards') or [] ) + [ award.copy() ]

					pa.clear()

				for pb in p.findall('biographies/biography'):

					bio = {}

					bio['personId']		= personId
					bio['updateId']		= updateId

					bio['biography']	= self.check( pb )
					bio['type']			= self.check( pb, 'type' )
					bio['lang']			= self.check( pb, 'lang' )
					bio['territory']	= self.check( pb, 'territory' )

					if self.do_output_tsv:
						if not self.validate_and_write_tsv(bio, 'celebrity_biography', 'personId'):
							pb.clear()
							continue

					if self.do_output_jsonl:
						[ bio.pop(key) for key in ['personId','updateId'] ]
						celebrity['biographies'] = ( celebrity.get('biographies') or [] ) + [ bio.copy() ]

					pb.clear()							

				for pr in p.findall('relationships/relationship'):

					rel = {}

					rel['personId'] 		= personId
					rel['updateId'] 		= updateId

					rel['type']				= self.check( pr.find('type') )
					rel['relationship']		= self.check( pr.find('relationshipType') )
					rel['rel_personId']		= self.check( pr.find('personID') )
					rel['name_prefix']		= self.check( pr.find('personName/prefix') )
					rel['name_first']		= self.check( pr.find('personName/first') )
					rel['name_middle']		= self.check( pr.find('personName/middle') )
					rel['name_last']		= self.check( pr.find('personName/last') )
					rel['name_suffix']		= self.check( pr.find('personName/suffix') )
					rel['name_aka']			= self.check( pr.find('personName/aka') )
					rel['description']		= self.check( pr.find('description') )

					if self.do_output_tsv:
						if not self.validate_and_write_tsv(rel, 'celebrity_relationship', 'personId'):
							pr.clear()
							continue

					if self.do_output_jsonl:
						[ rel.pop(key) for key in ['personId','updateId'] ]
						celebrity['relationships'] = ( celebrity.get('relationships') or [] ) + [ rel.copy() ]

					pr.clear()							

				for pr in p.findall('relationshipEvents/relationshipEvent'):

					groupType			= self.check( pr.find('groupType') )
					relationshipType	= self.check( pr.find('relationshipType') )
					name				= self.check( pr.find('name') )

					for pre in pr.findall('events/event'):

						rel_event = {}

						rel_event['personId']		= personId
						rel_event['updateId']		= updateId

						rel_event['type']			= groupType
						rel_event['relationship']	= relationshipType
						rel_event['name']			= name

						rel_event['event_type']		= self.check( pre.find('type') )
						rel_event['event_date']		= self.check( pre.find('date') )
						rel_event['event_desc']		= self.check( pre.find('description') )

						if self.do_output_tsv:
							if not self.validate_and_write_tsv(rel_event, 'celebrity_relationshipevent', 'personId'):
								pre.clear()
								continue

						if self.do_output_jsonl:
							[ rel_event.pop(key) for key in ['personId','updateId'] ]
							celebrity['relationshipEvents'] = ( celebrity.get('relationshipEvents') or [] ) + [ rel_event.copy() ]

						pre.clear()

					pr.clear()

				for pe in p.findall('educations/education'):

					education = {}

					education['personId']		= personId
					education['updateId']		= updateId

					education['degree']			= self.check( pe.find('degree') )
					education['institution']	= self.check( pe.find('institution') )
					education['location']		= self.check( pe.find('location') )
					education['major']			= self.check( pe.find('major') )
					education['yearRange']		= self.check( pe.find('yearRange') )
					education['notes']			= self.check( pe.find('notes') )

					if self.do_output_tsv:
						if not self.validate_and_write_tsv(education, 'celebrity_education', 'personId'):
							pe.clear()
							continue

					if self.do_output_jsonl:
						[ education.pop(key) for key in ['personId','updateId'] ]
						celebrity['educations'] = ( celebrity.get('educations') or [] ) + [ education.copy() ]

					pe.clear()


				for pm in p.findall('milestones/milestone'):

					milestone = {}

					milestone['personId']		= personId
					milestone['updateId']		= updateId

					milestone['beginDate']		= self.check( pm.find('beginDate') )
					milestone['endDate']		= self.check( pm.find('endDate') )
					milestone['description']	= self.check( pm.find('description') )

					if self.do_output_tsv:
						if not self.validate_and_write_tsv(milestone, 'celebrity_milestone', 'personId'):
							pm.clear()
							continue

					if self.do_output_jsonl:
						[ milestone.pop(key) for key in ['personId','updateId'] ]
						celebrity['milestones'] = ( celebrity.get('milestones') or [] ) + [ milestone.copy() ]

					pm.clear()

				for pn in p.findall('notes/note'):

					note = {}

					note['personId']	= personId
					note['updateId']	= updateId

					note['note']		= self.check( pn )

					if self.do_output_tsv:
						if not self.validate_and_write_tsv(note, 'celebrity_note', 'personId'):
							pn.clear()
							continue

					if self.do_output_jsonl:
						[ note.pop(key) for key in ['personId','updateId'] ]
						celebrity['notes'] = ( celebrity.get('notes') or [] ) + [ note['note'] ]

					pn.clear()

				for pq in p.findall('quotes/quote'):

					quote = {}

					quote['personId']		= personId
					quote['updateId']		= updateId

					quote['type']			= self.check( pq.find('type') )
					quote['description']	= self.check( pq.find('description') )
					quote['beginDate']		= self.check( pq.find('beginDate') )
					quote['endDate']		= self.check( pq.find('endDate') )

					if self.do_output_tsv:
						if not self.validate_and_write_tsv(quote, 'celebrity_quote', 'personId'):
							pq.clear()
							continue

					if self.do_output_jsonl:
						[ quote.pop(key) for key in ['personId','updateId'] ]
						celebrity['quotes'] = ( celebrity.get('quotes') or [] ) + [ quote.copy() ]

					pq.clear()

				for ph in p.findall('highlights/highlight'):

					highlight = {}

					highlight['personId']	= personId
					highlight['updateId']	= updateId

					highlight['highlight']	= self.check( ph )
					highlight['lang']		= self.check( ph, 'lang' )

					if self.do_output_tsv:
						if not self.validate_and_write_tsv(highlight, 'celebrity_highlight', 'personId'):
							ph.clear()
							continue

					if self.do_output_jsonl:
						[ highlight.pop(key) for key in ['personId','updateId'] ]
						celebrity['highlights'] = ( celebrity.get('highlights') or [] ) + [ highlight.copy() ]

					ph.clear()

				for psm in p.findall('socialMedia/socialMedium'):

					media = {}

					media['personId']	= personId
					media['updateId']	= updateId

					media['handle']		= self.check( psm.find('handle') )
					media['host']		= self.check( psm.find('host') )
					media['URL']		= self.check( psm.find('URL') )

					if self.do_output_tsv:
						if not self.validate_and_write_tsv(media, 'celebrity_socialmedia', 'personId'):
							psm.clear()
							continue

					if self.do_output_jsonl:
						[ media.pop(key) for key in ['personId','updateId'] ]
						celebrity['socialMedia'] = ( celebrity.get('socialMedia') or [] ) + [ media.copy() ]

					psm.clear()

				for pea in p.findall('enhancedAwards/enhancedAward'):

					award = {}

					award['personId']		= personId
					award['updateId']		= updateId

					award['group'] 			= self.check( pea.find('group') )
					award['category'] 		= self.check( pea.find('category') )
					award['year'] 			= self.check( pea.find('year') )
					award['result'] 		= self.check( pea.find('result') )
					award['project_title']	= self.check( pea.find('project/title') )
					award['showTitle'] 		= self.check( pea.find('showTitle') )
					award['notes'] 			= self.check( pea.find('notes') )

					if self.do_output_tsv:
						if not self.validate_and_write_tsv(award, 'celebrity_enhancedaward', 'personId'):
							pea.clear()
							continue

					if self.do_output_jsonl:
						[ award.pop(key) for key in ['personId','updateId'] ]
						celebrity['enhancedAwards'] = ( celebrity.get('enhancedAwards') or [] ) + [ award.copy() ]

					pea.clear()

			if self.do_output_jsonl:
				self.write_jsonl(celebrity, 'celebrity')

			p.clear()



# ================== ENDPOINT SPECIFIC INIT CODE BEGIN ==================
# Here insert the endpoint-specific code from schema/release/<product>/parse_.py


endpoint = 'Celebrities'

entities = [
	 'celebrity' 
]

tables = [
	 'celebrity' 
	,'celebrity_name'
	,'celebrity_award' 
	,'celebrity_asset' 
	,'celebrity_mediography' 
	,'celebrity_mediography_credit' 
	,'celebrity_participanttype' 
	,'celebrity_biography' 
	,'celebrity_relationship' 
	,'celebrity_relationshipevent' 
	,'celebrity_education' 
	,'celebrity_milestone' 
	,'celebrity_note' 
	,'celebrity_quote' 
	,'celebrity_highlight' 
	,'celebrity_socialmedia' 
	,'celebrity_enhancedaward' 
]

fields = {
	 'celebrity': ['personId', 'updateId', 'updateDate', 'deleted', 'type', 'gender', 'nationality', 'ethnicity', 'birthName', 'birthPlace', 'birthDate', 'deathDate', 'deathPlace', 'deathCause', 'MD5', 'ingestId', 'batchUpdateOrd']
	,'celebrity_name': ['personId', 'updateId', 'nameId', 'primary', 'lang', 'sort', 'prefix', 'first', 'middle', 'last', 'suffix', 'MD5', 'ingestId']
	,'celebrity_award': ['personId', 'updateId', 'won', 'rootId', 'award', 'awardId', 'category', 'awardCatId', 'year', 'recipient', 'recipientNameId', 'MD5', 'ingestId']
	,'celebrity_asset': ['personId', 'updateId', 'assetUpdateId', 'assetId', 'deleted', 'lastModified', 'expiredDate', 'type', 'width', 'height', 'primary', 'category', 'ratio', 'provider', 'URI', 'caption', 'caption_lang', 'enhRank', 'MD5', 'ingestId']
	,'celebrity_mediography': ['mediographyId', 'personId', 'updateId', 'type', 'rootId', 'year', 'title', 'title_type', 'title_subType', 'title_lang', 'MD5', 'ingestId']
	,'celebrity_mediography_credit': ['mediographyId', 'personId', 'updateId', 'nameId', 'characterName', 'roleId', 'role', 'MD5', 'ingestId']
	,'celebrity_participanttype': ['personId', 'updateId', 'participantType', 'isPrimary', 'MD5', 'ingestId']
	,'celebrity_biography': ['personId', 'updateId', 'biography', 'type', 'lang', 'territory', 'MD5', 'ingestId']
	,'celebrity_relationship': ['personId', 'updateId', 'type', 'relationship', 'rel_personId', 'name_prefix', 'name_first', 'name_middle', 'name_last', 'name_suffix', 'name_aka', 'description', 'MD5', 'ingestId']
	,'celebrity_relationshipevent': ['personId', 'updateId', 'type', 'relationship', 'name', 'event_type', 'event_date', 'event_desc', 'MD5', 'ingestId']
	,'celebrity_education': ['personId', 'updateId', 'degree', 'institution', 'location', 'major', 'yearRange', 'notes', 'MD5', 'ingestId']
	,'celebrity_milestone': ['personId', 'updateId', 'beginDate', 'endDate', 'description', 'MD5', 'ingestId']
	,'celebrity_note': ['personId', 'updateId', 'note', 'MD5', 'ingestId']
	,'celebrity_quote': ['personId', 'updateId', 'type', 'description', 'beginDate', 'endDate', 'MD5', 'ingestId']
	,'celebrity_highlight': ['personId', 'updateId', 'highlight', 'lang', 'MD5', 'ingestId']
	,'celebrity_socialmedia': ['personId', 'updateId', 'handle', 'host', 'URL', 'MD5', 'ingestId']
	,'celebrity_enhancedaward': ['personId', 'updateId', 'group', 'category', 'year', 'result', 'project_title', 'showTitle', 'notes', 'MD5', 'ingestId']
}


# =================== ENDPOINT SPECIFIC INIT CODE END ===================


gnCelebritiesParser = GnCelebritiesParser( endpoint, entities, tables, fields )
gnCelebritiesParser.set_config( os.environ['GXD_PDK_DIR'], os.environ['GXD_PDK_CONFIG'], files_path )
gnCelebritiesParser.run( xml_file )
