#  -----------------------------------------------------------------------------
#  Gracenote (A Nielsen Company) Proprietary Information
#  This software is supplied under the terms of a license agreement or
#  nondisclosure agreement with Nielsen/Gracenote, Inc. and may not be copied
#  or disclosed except in accordance with the terms of that agreement.
#  Copyright(c) 2020-present. Gracenote, A Nielsen Company, All Rights Reserved.
#  -----------------------------------------------------------------------------

#  =============================================================================
#  Parses a given ON Orgaizations XML file
#  Validates each record against fields configuration file
#  Writes validated records into TSV files for the endpoint
#  =============================================================================

import os
import sys

sys.path.append(os.path.join(sys.path[0],'..'))
import gxd_functions as gxd

xml_file 	= sys.argv[1]
files_path 	= sys.argv[2]

class GnOrganizationsParser(gxd.GnEndpointParser):

	def parse(self, xml_file):

		for o in self.xml_nodes(xml_file, "on/organizations/organization"):

			sportsorg = {}

			organizationId 				= self.check( o, 'organizationId')
			updateId 					= self.check( o, 'updateId' )
			updateDate 					= self.check( o, 'updateDate' )

			sportsorg['organizationId'] = organizationId
			sportsorg['updateId'] 		= updateId
			sportsorg['updateDate']		= updateDate

			sportsorg['deleted'] 		= self.format_boolean( self.check( o, 'deleted' ) )
			sportsorg['sportGId'] 		= self.check( o, 'sportGId' )
			sportsorg['rootId'] 		= self.check( o, 'rootId' )
			sportsorg['official'] 		= self.format_boolean( self.check( o, 'official' ) )
			sportsorg['name'] 			= self.check( o.find('name') )
			sportsorg['genre'] 			= self.check( o.find('genre') )
			sportsorg['genreId'] 		= self.check( o.find('genre'), 'genreId' )

			if self.do_output_tsv:
				if not self.validate_and_write_tsv(sportsorg, 'sportsorg', 'organizationId'):
					o.clear()
					continue


			# Conference - child table
			for c in o.findall('conferences/conference'):

				conferenceId 				= self.check( c, 'conferenceId')
				orgConfId 					= "{}-{}".format(organizationId, conferenceId)

				org_conf = {}

				org_conf['confId'] 			= orgConfId
				org_conf['organizationId'] 	= organizationId
				org_conf['updateId'] 		= updateId

				org_conf['conferenceId'] 	= conferenceId
				org_conf['conferenceGId'] 	= self.check( c, 'conferenceGId')
				org_conf['name'] 			= self.check( c.find('name') )
				org_conf['abbreviation'] 	= self.check( c.find('abbreviation') )

				if self.do_output_tsv:
					if not self.validate_and_write_tsv(org_conf, 'sportsorg_conf', 'confId'):
						c.clear()
						continue

				for ca in c.findall('assets/asset'):

					asset = {}

					asset['confId'] 		= orgConfId
					asset['organizationId'] = organizationId
					asset['updateId'] 		= updateId

					asset['assetId'] 		= self.check( ca, 'assetId' )
					asset['assetUpdateId'] 	= self.check( ca, 'updateId' )
					asset['lastModified'] 	= self.format_datetime( self.check( ca, 'lastModified' ))
					asset['expiredDate'] 	= self.check( ca, 'expiredDate' )
					asset['type'] 			= self.check( ca, 'type' )
					asset['width'] 			= self.check( ca, 'width' )
					asset['height'] 		= self.check( ca, 'height' )
					asset['ratio'] 			= self.check( ca, 'ratio' )
					asset['tier']	 		= self.check( ca, 'tier' )
					asset['category'] 		= self.check( ca, 'category' )
					asset['deleted'] 		= self.format_boolean( self.check( ca, 'deleted' ))
					asset['primary'] 		= self.format_boolean( self.check( ca, 'primary' ))
					asset['URI'] 			= self.check( ca.find('URI') )

					if self.do_output_tsv:
						if not self.validate_and_write_tsv(asset, 'sportsorg_conf_asset', 'confId'):
							ca.clear()
							continue

					if self.do_output_jsonl:
						[ asset.pop(key) for key in ['confId','organizationId','updateId'] ]
						org_conf['assets'] = ( org_conf.get('assets') or [] ) + [ asset.copy() ]

					ca.clear()

				if self.do_output_jsonl:
					[ org_conf.pop(key) for key in ['confId','organizationId','updateId'] ]
					sportsorg['conferences'] = ( sportsorg.get('conferences') or [] ) + [ org_conf.copy() ]

				c.clear()


			for od in o.findall('divisions/division'):

				divisionId 					= self.check( od, 'divisionId')
				orgDivId 					= "{}-{}".format(organizationId, divisionId)

				org_div = {}

				org_div['divId'] 			= orgDivId
				org_div['organizationId'] 	= organizationId
				org_div['updateId'] 		= updateId

				org_div['divisionId'] 		= self.check( od, 'divisionId' )
				org_div['divisionGId'] 		= self.check( od, 'divisionGId' )

				org_div['name'] 			= self.check( od.find('name') )
				org_div['abbreviation'] 	= self.check( od.find('abbreviation') )


				if self.do_output_tsv:
					if not self.validate_and_write_tsv(org_div, 'sportsorg_div', 'organizationId'):
						od.clear()
						continue

				if self.do_output_jsonl:
					[ org_div.pop(key) for key in ['divId','organizationId','updateId'] ]
					sportsorg['divisions'] = ( sportsorg.get('divisions') or [] ) + [ org_div.copy() ]

				od.clear()

			for oa in o.findall('assets/asset'):

				asset = {}

				asset['organizationId'] = organizationId
				asset['updateId'] 		= updateId

				asset['assetId'] 		= self.check( oa, 'assetId' )
				asset['assetUpdateId'] 	= self.check( oa, 'updateId' )
				asset['lastModified'] 	= self.format_datetime( self.check( oa, 'lastModified' ))
				asset['expiredDate'] 	= self.check( oa, 'expiredDate' )
				asset['type'] 			= self.check( oa, 'type' )
				asset['width'] 			= self.check( oa, 'width' )
				asset['height'] 		= self.check( oa, 'height' )
				asset['ratio'] 			= self.check( oa, 'ratio' )
				asset['tier']	 		= self.check( oa, 'tier' )
				asset['category'] 		= self.check( oa, 'category' )
				asset['familyId'] 		= self.check( oa, 'familyId' )
				asset['deleted'] 		= self.format_boolean( self.check( oa, 'deleted' ))
				asset['primary'] 		= self.format_boolean( self.check( oa, 'primary' ))
				asset['familyMaster'] 	= self.format_boolean( self.check( oa, 'familyMaster' ))
				asset['URI'] 			= self.check( oa.find('URI') )

				if self.do_output_tsv:
					if not self.validate_and_write_tsv(asset, 'sportsorg_asset', 'organizationId'):
						oa.clear()
						continue

				if self.do_output_jsonl:
					[ asset.pop(key) for key in ['organizationId','updateId'] ]
					sportsorg['assets'] = ( sportsorg.get('assets') or [] ) + [ asset.copy() ]
						
				oa.clear()

			for oe in o.findall('relatedSportsEvents/relatedSportsEvent'):

				event = {}

				event['organizationId'] = organizationId
				event['updateId'] 		= updateId

				event['sportsEventGId'] = self.check( oe, 'sportsEventGId' )
				event['type'] 			= self.check( oe, 'type' )
				event['event'] 			= self.check( oe )

				if self.do_output_tsv:
					if not self.validate_and_write_tsv(event, 'sportsorg_event', 'organizationId'):
						oe.clear()
						continue

				if self.do_output_jsonl:
					[ event.pop(key) for key in ['organizationId','updateId'] ]
					sportsorg['events'] = ( sportsorg.get('events') or [] ) + [ event.copy() ]
						
				oe.clear()

			for ot in o.findall('teams/team'):

				org_teambrand = {}

				org_teambrand['organizationId'] = organizationId
				org_teambrand['updateId'] 		= updateId

				org_teambrand['teamId'] 		= self.check( ot, 'id' )
				org_teambrand['teamBrandId'] 	= self.check( ot, 'brandId' )
				org_teambrand['conferenceId'] 	= self.check( ot, 'conferenceId' )

				org_teambrand['divisionId'] 	= self.check( ot, 'divisionId' )

				org_teambrand['teamGId'] 		= self.check( ot, 'teamGId' )
				org_teambrand['teamBrandGId'] 	= self.check( ot, 'teamBrandGId' )
				org_teambrand['conferenceGId'] 	= self.check( ot, 'conferenceGId' )
				org_teambrand['divisionGId'] 	= self.check( ot, 'divisionGId' )

				if self.do_output_tsv:
					if not self.validate_and_write_tsv(org_teambrand, 'sportsorg_teambrand', 'organizationId'):
						ot.clear()
						continue

				if self.do_output_jsonl:
					[ org_teambrand.pop(key) for key in ['organizationId','updateId'] ]
					sportsorg['teams'] = ( sportsorg.get('teams') or [] ) + [ org_teambrand.copy() ]

				ot.clear()

			if self.do_output_jsonl:
				self.write_jsonl(sportsorg, 'sportsorg')

			o.clear()



# ================== ENDPOINT SPECIFIC INIT CODE BEGIN ==================
# Here insert the endpoint-specific code from schema/release/<product>/parse_.py

endpoint = 'Organizations'


entities = [
	 'sportsorg' 
]

tables = [
	 'sportsorg' 
	,'sportsorg_asset' 
	,'sportsorg_conf' 
	,'sportsorg_conf_asset' 
	,'sportsorg_div' 
	,'sportsorg_teambrand' 
	,'sportsorg_event' 


]

fields = {
	 'sportsorg': ['organizationId', 'updateId', 'updateDate', 'deleted', 'rootId', 'official', 'sportGId', 'name', 'genre', 'genreId', 'MD5', 'ingestId', 'batchUpdateOrd']
	,'sportsorg_asset': ['organizationId', 'updateId', 'assetUpdateId', 'assetId', 'deleted', 'lastModified', 'expiredDate', 'type', 'width', 'height', 'primary', 'category', 'ratio', 'tier', 'URI', 'MD5', 'ingestId']
	,'sportsorg_conf': ['confId', 'organizationId', 'updateId', 'conferenceId', 'conferenceGId', 'name', 'abbreviation', 'MD5', 'ingestId']
	,'sportsorg_conf_asset': ['confId', 'organizationId', 'updateId', 'assetUpdateId', 'assetId', 'deleted', 'lastModified', 'expiredDate', 'type', 'width', 'height', 'primary', 'category', 'ratio', 'tier', 'URI', 'MD5', 'ingestId']
	,'sportsorg_div': ['divId', 'organizationId', 'updateId', 'divisionId', 'divisionGId', 'name', 'abbreviation', 'MD5', 'ingestId']
	,'sportsorg_teambrand': ['organizationId', 'updateId', 'teamId', 'teamBrandId', 'teamGId', 'teamBrandGId', 'conferenceId', 'conferenceGId', 'divisionId', 'divisionGId', 'MD5', 'ingestId']
	,'sportsorg_event': ['organizationId', 'updateId', 'sportsEventGId', 'type', 'event', 'MD5', 'ingestId']
}

# =================== ENDPOINT SPECIFIC INIT CODE END ===================


gnOrganizationsParser = GnOrganizationsParser( endpoint, entities, tables, fields )
gnOrganizationsParser.set_config( os.environ['GXD_PDK_DIR'], os.environ['GXD_PDK_CONFIG'], files_path )
gnOrganizationsParser.run( xml_file )
