#  -----------------------------------------------------------------------------
#  Gracenote (A Nielsen Company) Proprietary Information
#  This software is supplied under the terms of a license agreement or
#  nondisclosure agreement with Nielsen/Gracenote, Inc. and may not be copied
#  or disclosed except in accordance with the terms of that agreement.
#  Copyright(c) 2020-present. Gracenote, A Nielsen Company, All Rights Reserved.
#  -----------------------------------------------------------------------------

#  =============================================================================
#  Parses a given ON ProgramAnnotations XML file
#  Validates each record against fields configuration file
#  Writes validated records into TSV files for the endpoint
#  =============================================================================

import os
import sys

sys.path.append(os.path.join(sys.path[0],'..'))
import gxd_functions as gxd

xml_file 	= sys.argv[1]
files_path 	= sys.argv[2]

class GnProgramAnnotationsParser(gxd.GnEndpointParser):

	def parse(self, xml_file):

		for a in self.xml_nodes(xml_file, "on/programAnnotations/programAnnotation"):

			vdannot = {}

			TMSId 			= self.check( a, 'TMSId' )
			updateId 		= self.check( a, 'updateId' )
			updateDate 		= self.check( a, 'updateDate' )
			deleted 		= self.format_boolean( self.check( a, 'deleted' ) )

			vdannot['TMSId'] 	 	= TMSId
			vdannot['updateId'] 	= updateId
			vdannot['updateDate'] 	= updateDate
			vdannot['deleted'] 		= deleted

			vdannot['rootId'] 		= self.check( a, 'rootId' )

			if self.do_output_tsv:
				if not self.validate_and_write_tsv(vdannot, 'vdannotation', 'TMSId'):
					a.clear()
					continue

			for ad in a.findall('videoDescriptors/videoDescriptor'):

				desc = {}

				desc['TMSId'] 			= TMSId
				desc['updateId'] 		= updateId

				desc['descriptorId'] 	= self.check( ad.find('videoDescriptorId') )
				desc['weight'] 			= self.check( ad.find('weight') )
				desc['ord'] 			= self.check( ad, 'ord' )

				if self.do_output_tsv:
					if not self.validate_and_write_tsv(desc, 'vdannotation_descriptor', 'TMSId'):
						ad.clear()
						continue

				if self.do_output_jsonl:
					[ desc.pop(key) for key in ['TMSId','updateId'] ]
					vdannot['descriptors'] = ( vdannot.get('descriptors') or [] ) + [ desc.copy() ]

				ad.clear()


			if self.do_output_jsonl:
				self.write_jsonl(vdannot, 'vdannotation')

			a.clear()

# ================== ENDPOINT SPECIFIC INIT CODE BEGIN ==================
# Here insert the endpoint-specific code from schema/release/<product>/parse_.py

endpoint = 'ProgramAnnotations'

entities = [
	 'vdannotation' 
]

tables = [
	 'vdannotation' 
	,'vdannotation_descriptor' 
]

fields = {
	 'vdannotation': ['TMSId', 'updateId', 'updateDate', 'deleted', 'rootId', 'MD5', 'ingestId', 'batchUpdateOrd']
	,'vdannotation_descriptor': ['TMSId', 'updateId', 'ord', 'descriptorId', 'weight', 'MD5', 'ingestId']
}
# =================== ENDPOINT SPECIFIC INIT CODE END ===================


gnProgramAnnotationsParser = GnProgramAnnotationsParser( endpoint, entities, tables, fields )
gnProgramAnnotationsParser.set_config( os.environ['GXD_PDK_DIR'], os.environ['GXD_PDK_CONFIG'], files_path )
gnProgramAnnotationsParser.run( xml_file )
