#  -----------------------------------------------------------------------------
#  Gracenote (A Nielsen Company) Proprietary Information
#  This software is supplied under the terms of a license agreement or
#  nondisclosure agreement with Nielsen/Gracenote, Inc. and may not be copied
#  or disclosed except in accordance with the terms of that agreement.
#  Copyright(c) 2020-present. Gracenote, A Nielsen Company, All Rights Reserved.
#  -----------------------------------------------------------------------------

#  =============================================================================
#  Parses a given ON Sources XML file
#  Validates each record against fields configuration file
#  Writes validated records into TSV files for the endpoint
#  =============================================================================

import os
import sys

sys.path.append(os.path.join(sys.path[0],'..'))
import gxd_functions as gxd

xml_file 	= sys.argv[1]
files_path 	= sys.argv[2]

class GnSourcesParser(gxd.GnEndpointParser):

	def parse(self, xml_file):

		for s in self.xml_nodes(xml_file, "on/sources/prgSvcs/prgSvc"):

			source = {}
			prgSvcId 	= self.check( s, 'prgSvcId' )
			updateId 	= self.check( s, 'updateId' )
			updateDate 	= self.check( s, 'updateDate' )

			source['prgSvcId'] 	= prgSvcId
			source['updateId'] 	= updateId
			source['updateDate'] = updateDate
			source['deleted'] 	= self.format_boolean( self.check( s, 'deleted' ))
			source['inactive'] 	= self.format_boolean( self.check( s, 'inactive' ))

			source['name'] 	 	= self.check( s.find('name') )
			source['callSign'] 	= self.check( s.find('callSign') )
			source['reach'] 	= self.check( s.find('reach') )

			num = s.find('num')
			source['num'] 	 	= self.check( num )
			source['majorNum'] 	= self.check( num, 'majorNum' )
			source['minorNum'] 	= self.check( num, 'minorNum' )

			if self.do_parse_all:

				source['city'] 		= self.check( s.find('address/city') )
				source['state'] 	= self.check( s.find('address/state') )
				source['postalCode'] = self.check( s.find('address/postalCode') )
				source['country'] 	= self.check( s.find('address/country') )

				source['type'] 		= self.check( s.find('type') )

				status 	= s.find('status')
				source['status'] 	= self.check( status )
				source['statusId']	= self.check( status, 'statusId' )

				source['signalType'] 	= self.check( s.find('videoQuality/signalType') )
				source['videoType'] 	= self.check( s.find('videoQuality/videoType') )
				source['truResolution']	= self.check( s.find('videoQuality/truResolution') )

				source['enhancedCallSign'] 	= self.check( s.find('enhancedCallSign') )
				source['cityOfLicense'] 	= self.check( s.find('cityOfLicense') )
				source['timeZone'] 			= self.check( s.find('timeZone') )
				source['ianaTimeZone'] 		= self.check( s.find('ianaTimeZone') )
				source['URL'] 				= self.check( s.find('URL') )

			if self.do_output_tsv:
				if not self.validate_and_write_tsv(source, 'source', 'prgSvcId'):
					s.clear()
					continue


			for saff in s.findall('affils/affil'):

				aff = {}
				aff['prgSvcId'] 		= prgSvcId
				aff['updateId'] 		= updateId
				aff['affil'] 		= self.check( saff )
				aff['affil_prgSvcId'] = self.check( saff, 'prgSvcId' )
				aff['affiliateId'] 	= self.check( saff, 'affiliateId' )
				aff['ord'] 			= self.check( saff, 'ord' )

				if self.do_output_tsv:
					if not self.validate_and_write_tsv(aff, 'source_affiliate', 'prgSvcId'):
						saff.clear()
						continue

				if self.do_output_jsonl:
					[ aff.pop(key) for key in ['prgSvcId','updateId'] ]
					source['affils'] = ( source.get('affils') or [] ) + [ aff.copy() ]

				saff.clear()

			for sass in s.findall('assets/asset'):

				asset = {}
				asset['prgSvcId'] 		= prgSvcId
				asset['updateId'] 		= updateId
				asset['assetId'] 		= self.check( sass, 'assetId' )
				asset['assetUpdateId'] 	= self.check( sass, 'updateId' )
				asset['lastModified'] 	= self.format_datetime( self.check( sass, 'lastModified' ))
				asset['type'] 			= self.check( sass, 'type' )
				asset['width'] 			= self.check( sass, 'width' )
				asset['height'] 		= self.check( sass, 'height' )
				asset['ratio'] 			= self.check( sass, 'ratio' )
				asset['category'] 		= self.check( sass, 'category' )
				asset['expiredDate'] 	= self.check( sass, 'expiredDate' )
				asset['deleted'] 		= self.format_boolean( self.check( sass, 'deleted' ))
				asset['primary'] 		= self.format_boolean( self.check( sass, 'primary' ))
				asset['URI'] 			= self.check( sass.find('URI') )

				if self.do_output_tsv:
					if not self.validate_and_write_tsv(asset, 'source_asset', 'prgSvcId'):
						sass.clear()
						continue

				if self.do_output_jsonl:
					[ asset.pop(key) for key in ['prgSvcId','updateId'] ]
					source['assets'] = ( source.get('assets') or [] ) + [ asset.copy() ]

				sass.clear()

			# Following will be optionally parsed
			if self.do_parse_all:
				for scc in s.findall('countriesOfCoverage/country'):

					country = {}
					country['prgSvcId'] 	= prgSvcId
					country['updateId'] 	= updateId
					country['country'] 	= self.check( scc )

					if self.do_output_tsv:
						if not self.validate_and_write_tsv(country, 'source_country', 'prgSvcId'):
							scc.clear()
							continue

					if self.do_output_jsonl:
						#[ country.pop(key) for key in ['prgSvcId','updateId'] ]
						source['countries'] = ( source.get('countries') or [] ) + [ country['country'] ]

					scc.clear()

				for san in s.findall('alternateNames/alternateName'):

					altname = {}
					altname['prgSvcId'] 	= prgSvcId
					altname['updateId'] 	= updateId
					altname['altName'] 		= self.check( san )

					if self.do_output_tsv:
						if not self.validate_and_write_tsv(altname, 'source_altname', 'prgSvcId'):
							san.clear()
							continue

					if self.do_output_jsonl:
						source['altNames'] = ( source.get('altNames') or [] ) + [ altname['altName'] ]

					san.clear()

				for satt in s.findall('attribs/attrib'):

					attrib = {}
					attrib['prgSvcId'] 	= prgSvcId
					attrib['updateId'] 	= updateId
					attrib['attrib'] 	= self.check( satt )

					if self.do_output_tsv:
						if not self.validate_and_write_tsv(attrib, 'source_attribute', 'prgSvcId'):
							satt.clear()
							continue

					if self.do_output_jsonl:
						#[ attrib.pop(key) for key in ['prgSvcId','updateId'] ]
						source['attribs'] = ( source.get('attribs') or [] ) + [ attrib['attrib'] ]

					satt.clear()

				for sedl in s.findall('edLangs/edLang'):

					edlang = {}
					edlang['prgSvcId'] 	= prgSvcId
					edlang['updateId'] 	= updateId
					edlang['edLang'] 	= self.check( sedl )
#					sys.stderr.write("assigned: "+str(edlang)+"\n")

					if self.do_output_tsv:
						if not self.validate_and_write_tsv(edlang, 'source_edlang', 'prgSvcId'):
							sedl.clear()
							continue

					if self.do_output_jsonl:
						#[ edlang.pop(key) for key in ['prgSvcId','updateId'] ]
						source['edLangs'] = ( source.get('edLangs') or [] ) + [ edlang['edLang'] ]

					sedl.clear()

				for sbcl in s.findall('bcastLangs/bcastLang'):

					bcastlang = {}
					bcastlang['prgSvcId'] 	= prgSvcId
					bcastlang['updateId'] 	= updateId
					bcastlang['bcastLang']	= self.check( sbcl )

					if self.do_output_tsv:
						if not self.validate_and_write_tsv(bcastlang, 'source_bcastlang', 'prgSvcId'):
							sbcl.clear()
							continue

					if self.do_output_jsonl:
						#[ bcastlang.pop(key) for key in ['prgSvcId','updateId'] ]
						source['bcastLangs'] = ( source.get('bcastLangs') or [] ) + [ bcastlang['bcastLang'] ]

					sbcl.clear()

				for sr in s.findall('relationships/relationship'):

					rel = {}
					rel['prgSvcId']		= prgSvcId
					rel['updateId'] 		= updateId
					rel['relationship'] 	= self.check( sr )
					rel['type'] 			= self.check( sr, 'type' )

					if self.do_output_tsv:
						if not self.validate_and_write_tsv(rel, 'source_relationship', 'prgSvcId'):
							sr.clear()
							continue

					if self.do_output_jsonl:
						[ rel.pop(key) for key in ['prgSvcId','updateId'] ]
						source['relationships'] = ( source.get('relationships') or [] ) + [ rel.copy() ]

					sr.clear()

				for smid in s.findall('marketIds/marketId'):

					mid = {}
					mid['prgSvcId'] 	= prgSvcId
					mid['updateId'] 	= updateId
					mid['marketId'] 	= self.check( smid )
					mid['type'] 		= self.check( smid, 'type' )

					if self.do_output_tsv:
						if not self.validate_and_write_tsv(mid, 'source_marketid', 'prgSvcId'):
							smid.clear()
							continue

					if self.do_output_jsonl:
						[ mid.pop(key) for key in ['prgSvcId','updateId'] ]
						source['marketIds'] = ( source.get('marketIds') or [] ) + [ mid.copy() ]

					smid.clear()

				for sg in s.findall('genres/genre'):

					genre = {}
					genre['prgSvcId'] 	= prgSvcId
					genre['updateId'] 	= updateId
					genre['genre'] 		= self.check( sg )
					genre['genreId'] 	= self.check( sg, 'genreId' )

					if self.do_output_tsv:
						if not self.validate_and_write_tsv(genre, 'source_genre', 'prgSvcId'):
							sg.clear()
							continue

					if self.do_output_jsonl:
						[ genre.pop(key) for key in ['prgSvcId','updateId'] ]
						source['genres'] = ( source.get('genres') or [] ) + [ genre.copy() ]

					sg.clear()

				for sg in s.findall('sourceGroups/sourceGroup'):

					group = {}
					group['prgSvcId'] 	= prgSvcId
					group['updateId'] 	= updateId
					group['group'] 		= self.check( sg )
					group['groupId'] 	= self.check( sg, 'id' )
					group['type'] 		= self.check( sg, 'type' )

					if self.do_output_tsv:
						if not self.validate_and_write_tsv(group, 'source_group', 'prgSvcId'):
							sg.clear()
							continue

					if self.do_output_jsonl:
						[ group.pop(key) for key in ['prgSvcId','updateId'] ]
						source['groups'] = ( source.get('groups') or [] ) + [ group.copy() ]

					sg.clear()

				for stid in s.findall('transportIds/transportId'):

					tid = {}
					tid['prgSvcId'] 	= prgSvcId
					tid['updateId'] 	= updateId
					tid['id'] 			= self.check( stid )
					tid['type'] 		= self.check( stid, 'type' )
					tid['system'] 		= self.check( stid, 'system' )
					tid['subsystem'] 	= self.check( stid, 'subsystem' )

					if self.do_output_tsv:
						if not self.validate_and_write_tsv(tid, 'source_transportid', 'prgSvcId'):
							stid.clear()
							continue

					if self.do_output_jsonl:
						[ tid.pop(key) for key in ['prgSvcId','updateId'] ]
						source['transportIds'] = ( source.get('transportIds') or [] ) + [ tid.copy() ]

					stid.clear()


			if self.do_output_jsonl:
				self.write_jsonl(source, 'source')

			s.clear()


# ================== ENDPOINT SPECIFIC INIT CODE BEGIN ==================
# Here insert the endpoint-specific code from schema/release/<product>/parse_.py

endpoint = 'Sources'

entities = [
	 'source' 
]

tables = [
	 'source' 
	,'source_country' 
	,'source_altname' 
	,'source_attribute' 
	,'source_edlang' 
	,'source_bcastlang' 
	,'source_relationship' 
	,'source_affiliate' 
	,'source_asset' 
	,'source_marketid' 
	,'source_genre' 
	,'source_group' 
	,'source_transportid'
]

fields = {
	 'source': ['prgSvcId', 'updateId', 'updateDate', 'deleted', 'inactive', 'name', 'callSign', 'num', 'majorNum', 'minorNum', 'city', 'state', 'postalCode', 'country', 'type', 'status', 'statusId', 'reach', 'signalType', 'videoType', 'truResolution', 'enhancedCallSign', 'cityOfLicense', 'timeZone', 'ianaTimeZone', 'URL', 'MD5', 'ingestId', 'batchUpdateOrd']
	,'source_country': ['prgSvcId', 'updateId', 'country', 'MD5', 'ingestId']
	,'source_altname': ['prgSvcId', 'updateId', 'altName', 'MD5', 'ingestId']
	,'source_attribute': ['prgSvcId', 'updateId', 'attrib', 'MD5', 'ingestId']
	,'source_edlang': ['prgSvcId', 'updateId', 'edLang', 'MD5', 'ingestId']
	,'source_bcastlang': ['prgSvcId', 'updateId', 'bcastLang', 'MD5', 'ingestId']
	,'source_relationship': ['prgSvcId', 'updateId', 'relationship', 'type', 'MD5', 'ingestId']
	,'source_affiliate': ['prgSvcId', 'updateId', 'affil', 'affil_prgSvcId', 'affiliateId', 'ord', 'MD5', 'ingestId']
	,'source_asset': ['prgSvcId', 'updateId', 'assetUpdateId', 'assetId', 'deleted', 'lastModified', 'expiredDate', 'type', 'width', 'height', 'primary', 'category', 'ratio', 'URI', 'MD5', 'ingestId']
	,'source_marketid': ['prgSvcId', 'updateId', 'marketId', 'type', 'MD5', 'ingestId']
	,'source_genre': ['prgSvcId', 'updateId', 'genre', 'genreId', 'MD5', 'ingestId']
	,'source_group': ['prgSvcId', 'updateId', 'group', 'groupId', 'type', 'MD5', 'ingestId']
	,'source_transportid': ['prgSvcId', 'updateId', 'system', 'subsystem', 'type', 'id', 'MD5', 'ingestId']
}

# =================== ENDPOINT SPECIFIC INIT CODE END ===================


gnSourcesParser = GnSourcesParser( endpoint, entities, tables, fields )
gnSourcesParser.set_config( os.environ['GXD_PDK_DIR'], os.environ['GXD_PDK_CONFIG'], files_path )
gnSourcesParser.run( xml_file )
