#  -----------------------------------------------------------------------------
#  Gracenote (A Nielsen Company) Proprietary Information
#  This software is supplied under the terms of a license agreement or
#  nondisclosure agreement with Nielsen/Gracenote, Inc. and may not be copied
#  or disclosed except in accordance with the terms of that agreement.
#  Copyright(c) 2020-present. Gracenote, A Nielsen Company, All Rights Reserved.
#  -----------------------------------------------------------------------------

#  =============================================================================
#  Parses a given ON VideoDescriptorsTaxonomy XML file
#  Validates each record against fields configuration file
#  Writes validated records into TSV files for the endpoint
#  =============================================================================

import os
import sys

sys.path.append(os.path.join(sys.path[0],'..'))
import gxd_functions as gxd

xml_file 	= sys.argv[1]
files_path 	= sys.argv[2]

class GnVideoDescriptorsTaxonomyParser(gxd.GnEndpointParser):

	def parse(self, xml_file):

		for i in self.xml_nodes(xml_file, "on/videoDescriptorsTaxonomy/taxonomyItem"):

			item = {}

			updateId 		= self.check( i, 'updateId' )
			updateDate 		= self.check( i, 'updateDate' )
			deleted 		= self.format_boolean( self.check( i, 'deleted' ))

			taxonomyId = ''
			# TaxonomyItem does not contain an identifier, but is known to represent a specific type of descriptors
			# As a workaround, we will go into the item, extract the first typeId and use it as a taxonomyId
			for d in i.findall('videoDescriptors/videoDescriptor'):
				taxonomyId = self.check( d.find('typeId') )
				break

			item['taxonomyId'] 	= taxonomyId
			item['updateId'] 	= updateId
			item['updateDate'] 	= updateDate
			item['deleted']		= deleted

			if self.do_output_tsv:
				if not self.validate_and_write_tsv(item, 'descriptortaxonomy', 'taxonomyId'):
					i.clear()
					continue			

			for d in i.findall('videoDescriptors/videoDescriptor'):

				descriptor = {}

				descriptorId 				= self.check( d.find('videoDescriptorId') )

				descriptor['descriptorId'] 	= descriptorId
				descriptor['updateId'] 		= updateId
				descriptor['updateDate']	= updateDate
				descriptor['deleted']		= deleted

				descriptor['descriptorName'] 		= self.check( d.find('videoDescriptorName') )
				descriptor['parent_descriptorId'] 	= self.check( d.find('videoDescriptorParentId') )
				descriptor['typeId'] 				= self.check( d.find('typeId') )
				descriptor['typeName'] 				= self.check( d.find('typeName') )

				if self.do_output_tsv:
					if not self.validate_and_write_tsv(descriptor, 'descriptor', 'descriptorId'):
						d.clear()
						continue

				# Link between taxonomy item and descriptor
				item_descriptor = {}
				item_descriptor['updateId'] 	= updateId
				item_descriptor['taxonomyId'] 	= taxonomyId
				item_descriptor['descriptorId'] = descriptorId

				if self.do_output_tsv:
					if not self.validate_and_write_tsv(item_descriptor, 'descriptortaxonomy_descriptor', 'taxonomyId') and not self.rdb_skeleton:
						d.clear()
						continue

				if self.do_output_jsonl:
					item['taxonomy'] = ( item.get('taxonomy') or [] ) + [ item_descriptor['descriptorId'] ]


				if self.do_output_jsonl:
					self.write_jsonl(descriptor, 'descriptor')

				d.clear()

			if self.do_output_jsonl:
				self.write_jsonl(item, 'descriptortaxonomy')

			i.clear()

# ================== ENDPOINT SPECIFIC INIT CODE BEGIN ==================
# Here insert the endpoint-specific code from schema/release/<product>/parse_.py

endpoint = 'VideoDescriptorsTaxonomy'

entities = [
	 'descriptortaxonomy' 
	,'descriptor' 
]

tables = [
	 'descriptortaxonomy' 
	,'descriptortaxonomy_descriptor' 
	,'descriptor' 
]

fields = {
	 'descriptortaxonomy': ['taxonomyId', 'updateId', 'updateDate', 'deleted', 'MD5', 'ingestId', 'batchUpdateOrd']
	,'descriptortaxonomy_descriptor': ['taxonomyId', 'updateId', 'descriptorId', 'MD5', 'ingestId']
	,'descriptor': ['descriptorId', 'updateId', 'updateDate', 'deleted', 'descriptorName', 'parent_descriptorId', 'typeId', 'typeName', 'MD5', 'ingestId', 'batchUpdateOrd']
}
# =================== ENDPOINT SPECIFIC INIT CODE END ===================


gnVideoDescriptorsTaxonomyParser = GnVideoDescriptorsTaxonomyParser( endpoint, entities, tables, fields )
gnVideoDescriptorsTaxonomyParser.set_config( os.environ['GXD_PDK_DIR'], os.environ['GXD_PDK_CONFIG'], files_path )
gnVideoDescriptorsTaxonomyParser.run( xml_file )
