#  -----------------------------------------------------------------------------
#  Gracenote (A Nielsen Company) Proprietary Information
#  This software is supplied under the terms of a license agreement or
#  nondisclosure agreement with Nielsen/Gracenote, Inc. and may not be copied
#  or disclosed except in accordance with the terms of that agreement.
#  Copyright(c) 2020-present. Gracenote, A Nielsen Company, All Rights Reserved.
#  -----------------------------------------------------------------------------

#  =============================================================================
#  Parses a given ON Popularity XML file
#  Validates each record against fields configuration file
#  Writes validated records into TSV files for the endpoint
#  =============================================================================

import os
import sys

sys.path.append(os.path.join(sys.path[0],'..'))
import gxd_functions as gxd

xml_file 	= sys.argv[1]
files_path 	= sys.argv[2]

class GnVideoPopularityParser(gxd.GnEndpointParser):

	def parse(self, xml_file):

		do_parse_deleted = (self.parser_options.get('parse_deleted') != '0') 	# parse deleted objects by default		

		for p in self.xml_nodes(xml_file, "on/videoPopularityScores/videoPopularityScore"):

			popularity = {}

			popularityId 	= self.check( p, 'id' )
			updateId 		= self.check( p, 'updateId' )
			updateDate 		= self.check( p, 'updateDate' )
			deleted 		= self.format_boolean( self.check( p, 'deleted' ) )

			if not do_parse_deleted and deleted and deleted.upper() in ['TRUE','1']:
				p.clear()
				continue			

			popularity['popularityId'] 	= popularityId
			popularity['updateId'] 		= updateId
			popularity['updateDate'] 	= updateDate
			popularity['deleted'] 		= deleted

			popularity['country']	= self.check( p, 'country' )
			popularity['rootId'] 	= self.check( p, 'rootId' )
			popularity['score'] 	= self.check( p.find('score') )
			popularity['scoreDate'] = self.format_datetime( self.check( p.find('scoreDate') ))

			if self.do_output_tsv:
				if not self.validate_and_write_tsv(popularity, 'popularity', 'popularityId'):
					p.clear()
					continue

			if self.do_output_jsonl:
				self.write_jsonl(popularity, 'popularity')

			p.clear()

# ================== ENDPOINT SPECIFIC INIT CODE BEGIN ==================
# Here insert the endpoint-specific code from schema/release/<product>/parse_.py

endpoint = 'VideoPopularity'

entities = [
	 'popularity' 
]

tables = [
	 'popularity' 
]

fields = {
	 'popularity': ['popularityId', 'updateId', 'updateDate', 'deleted', 'country', 'rootId', 'score', 'scoreDate', 'MD5', 'ingestId', 'batchUpdateOrd']
}
# =================== ENDPOINT SPECIFIC INIT CODE END ===================


gnVideoPopularityParser = GnVideoPopularityParser( endpoint, entities, tables, fields )
gnVideoPopularityParser.set_config( os.environ['GXD_PDK_DIR'], os.environ['GXD_PDK_CONFIG'], files_path )
gnVideoPopularityParser.run( xml_file )
