
DROP PROCEDURE IF EXISTS {0}.AddConstraintIfNotExists;;
CREATE PROCEDURE {0}.AddConstraintIfNotExists(
    IN my_table_name VARCHAR(128),
    IN my_constr_name VARCHAR(128),
    IN my_col_name VARCHAR(128),
    IN my_detstable_name VARCHAR(128),
    IN my_destcol_name VARCHAR(128) )
BEGIN
    IF NOT EXISTS ( SELECT 1 FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS
        WHERE TABLE_SCHEMA = SCHEMA()
          AND TABLE_NAME = my_table_name
          AND CONSTRAINT_TYPE = "FOREIGN KEY"
          AND CONSTRAINT_NAME = my_constr_name )
    THEN
        SET @query = CONCAT("ALTER TABLE ", my_table_name, " ADD CONSTRAINT `", my_constr_name, "` FOREIGN KEY (`", my_col_name, "`) REFERENCES ", my_detstable_name, " (`", my_destcol_name, "`);");
        PREPARE stmt FROM @query;
        EXECUTE stmt;
        DEALLOCATE PREPARE stmt;
    END IF;
END;;

CALL {0}.AddConstraintIfNotExists( "availability_id", "availability_id_ibfk_1", "availabilityId", "availability", "availabilityId" );;
CALL {0}.AddConstraintIfNotExists( "availability_providerdata", "availability_providerdata_ibfk_1", "availabilityId", "availability", "availabilityId" );;
CALL {0}.AddConstraintIfNotExists( "availability_url", "availability_url_ibfk_1", "availabilityId", "availability", "availabilityId" );;
CALL {0}.AddConstraintIfNotExists( "availability_viewingoption", "availability_viewingoption_ibfk_1", "availabilityId", "availability", "availabilityId" );;
CALL {0}.AddConstraintIfNotExists( "celebrity_asset", "celebrity_asset_ibfk_1", "personId", "celebrity", "personId" );;
CALL {0}.AddConstraintIfNotExists( "celebrity_award", "celebrity_award_ibfk_1", "personId", "celebrity", "personId" );;
CALL {0}.AddConstraintIfNotExists( "celebrity_biography", "celebrity_biography_ibfk_1", "personId", "celebrity", "personId" );;
CALL {0}.AddConstraintIfNotExists( "celebrity_education", "celebrity_education_ibfk_1", "personId", "celebrity", "personId" );;
CALL {0}.AddConstraintIfNotExists( "celebrity_enhancedaward", "celebrity_enhancedaward_ibfk_1", "personId", "celebrity", "personId" );;
CALL {0}.AddConstraintIfNotExists( "celebrity_highlight", "celebrity_highlight_ibfk_1", "personId", "celebrity", "personId" );;
CALL {0}.AddConstraintIfNotExists( "celebrity_mediography", "celebrity_mediography_ibfk_1", "personId", "celebrity", "personId" );;
CALL {0}.AddConstraintIfNotExists( "celebrity_mediography_credit", "celebrity_mediography_credit_ibfk_1", "mediographyId", "celebrity_mediography", "mediographyId" );;
CALL {0}.AddConstraintIfNotExists( "celebrity_mediography_credit", "celebrity_mediography_credit_ibfk_2", "personId", "celebrity", "personId" );;
CALL {0}.AddConstraintIfNotExists( "celebrity_milestone", "celebrity_milestone_ibfk_1", "personId", "celebrity", "personId" );;
CALL {0}.AddConstraintIfNotExists( "celebrity_name", "celebrity_name_ibfk_1", "personId", "celebrity", "personId" );;
CALL {0}.AddConstraintIfNotExists( "celebrity_note", "celebrity_note_ibfk_1", "personId", "celebrity", "personId" );;
CALL {0}.AddConstraintIfNotExists( "celebrity_participanttype", "celebrity_participanttype_ibfk_1", "personId", "celebrity", "personId" );;
CALL {0}.AddConstraintIfNotExists( "celebrity_quote", "celebrity_quote_ibfk_1", "personId", "celebrity", "personId" );;
CALL {0}.AddConstraintIfNotExists( "celebrity_relationship", "celebrity_relationship_ibfk_1", "personId", "celebrity", "personId" );;
CALL {0}.AddConstraintIfNotExists( "celebrity_relationshipevent", "celebrity_relationshipevent_ibfk_1", "personId", "celebrity", "personId" );;
CALL {0}.AddConstraintIfNotExists( "celebrity_socialmedia", "celebrity_socialmedia_ibfk_1", "personId", "celebrity", "personId" );;
CALL {0}.AddConstraintIfNotExists( "cv_attribute", "cv_attribute_ibfk_1", "cvId", "cv", "cvId" );;
CALL {0}.AddConstraintIfNotExists( "descriptortaxonomy_descriptor", "descriptortaxonomy_descriptor_ibfk_1", "taxonomyId", "descriptortaxonomy", "taxonomyId" );;
CALL {0}.AddConstraintIfNotExists( "lineup_channel", "lineup_channel_ibfk_1", "lineupId", "lineup", "lineupId" );;
CALL {0}.AddConstraintIfNotExists( "lineup_channel_transport", "lineup_channel_transport_ibfk_1", "channelId", "lineup_channel", "channelId" );;
CALL {0}.AddConstraintIfNotExists( "lineup_channel_transport", "lineup_channel_transport_ibfk_2", "lineupId", "lineup", "lineupId" );;
CALL {0}.AddConstraintIfNotExists( "lineup_channel_transport_id", "lineup_channel_transport_id_ibfk_1", "transportId", "lineup_channel_transport", "transportId" );;
CALL {0}.AddConstraintIfNotExists( "lineup_channel_transport_id", "lineup_channel_transport_id_ibfk_2", "lineupId", "lineup", "lineupId" );;
CALL {0}.AddConstraintIfNotExists( "lineup_market", "lineup_market_ibfk_1", "lineupId", "lineup", "lineupId" );;
CALL {0}.AddConstraintIfNotExists( "lineup_postalcode", "lineup_postalcode_ibfk_1", "lineupId", "lineup", "lineupId" );;
CALL {0}.AddConstraintIfNotExists( "mapping_id", "mapping_id_ibfk_1", "mappingId", "mapping", "mappingId" );;
CALL {0}.AddConstraintIfNotExists( "mapping_link", "mapping_link_ibfk_1", "mappingId", "mapping", "mappingId" );;
CALL {0}.AddConstraintIfNotExists( "program_asset", "program_asset_ibfk_1", "TMSId", "program", "TMSId" );;
CALL {0}.AddConstraintIfNotExists( "program_asset_id", "program_asset_id_ibfk_1", "programAssetId", "program_asset", "programAssetId" );;
CALL {0}.AddConstraintIfNotExists( "program_asset_id", "program_asset_id_ibfk_2", "TMSId", "program", "TMSId" );;
CALL {0}.AddConstraintIfNotExists( "program_award", "program_award_ibfk_1", "TMSId", "program", "TMSId" );;
CALL {0}.AddConstraintIfNotExists( "program_cast", "program_cast_ibfk_1", "TMSId", "program", "TMSId" );;
CALL {0}.AddConstraintIfNotExists( "program_country", "program_country_ibfk_1", "TMSId", "program", "TMSId" );;
CALL {0}.AddConstraintIfNotExists( "program_crew", "program_crew_ibfk_1", "TMSId", "program", "TMSId" );;
CALL {0}.AddConstraintIfNotExists( "program_description", "program_description_ibfk_1", "TMSId", "program", "TMSId" );;
CALL {0}.AddConstraintIfNotExists( "program_descriptor", "program_descriptor_ibfk_1", "TMSId", "program", "TMSId" );;
CALL {0}.AddConstraintIfNotExists( "program_epinfo", "program_epinfo_ibfk_1", "TMSId", "program", "TMSId" );;
CALL {0}.AddConstraintIfNotExists( "program_epinfo_alt", "program_epinfo_alt_ibfk_1", "episodeInfoId", "program_epinfo", "episodeInfoId" );;
CALL {0}.AddConstraintIfNotExists( "program_epinfo_alt", "program_epinfo_alt_ibfk_2", "TMSId", "program", "TMSId" );;
CALL {0}.AddConstraintIfNotExists( "program_externallink", "program_externallink_ibfk_1", "TMSId", "program", "TMSId" );;
CALL {0}.AddConstraintIfNotExists( "program_genre", "program_genre_ibfk_1", "TMSId", "program", "TMSId" );;
CALL {0}.AddConstraintIfNotExists( "program_mvinfo", "program_mvinfo_ibfk_1", "TMSId", "program", "TMSId" );;
CALL {0}.AddConstraintIfNotExists( "program_mvtrailer", "program_mvtrailer_ibfk_1", "TMSId", "program", "TMSId" );;
CALL {0}.AddConstraintIfNotExists( "program_origaudiolang", "program_origaudiolang_ibfk_1", "TMSId", "program", "TMSId" );;
CALL {0}.AddConstraintIfNotExists( "program_qualityrating", "program_qualityrating_ibfk_1", "TMSId", "program", "TMSId" );;
CALL {0}.AddConstraintIfNotExists( "program_rating", "program_rating_ibfk_1", "TMSId", "program", "TMSId" );;
CALL {0}.AddConstraintIfNotExists( "program_ratingadvisory", "program_ratingadvisory_ibfk_1", "TMSId", "program", "TMSId" );;
CALL {0}.AddConstraintIfNotExists( "program_relationship", "program_relationship_ibfk_1", "TMSId", "program", "TMSId" );;
CALL {0}.AddConstraintIfNotExists( "program_release", "program_release_ibfk_1", "TMSId", "program", "TMSId" );;
CALL {0}.AddConstraintIfNotExists( "program_release_attribute", "program_release_attribute_ibfk_1", "releaseId", "program_release", "releaseId" );;
CALL {0}.AddConstraintIfNotExists( "program_release_attribute", "program_release_attribute_ibfk_2", "TMSId", "program", "TMSId" );;
CALL {0}.AddConstraintIfNotExists( "program_release_distributor", "program_release_distributor_ibfk_1", "releaseId", "program_release", "releaseId" );;
CALL {0}.AddConstraintIfNotExists( "program_release_distributor", "program_release_distributor_ibfk_2", "TMSId", "program", "TMSId" );;
CALL {0}.AddConstraintIfNotExists( "program_season", "program_season_ibfk_1", "TMSId", "program", "TMSId" );;
CALL {0}.AddConstraintIfNotExists( "program_spdata", "program_spdata_ibfk_1", "TMSId", "program", "TMSId" );;
CALL {0}.AddConstraintIfNotExists( "program_spdata_event", "program_spdata_event_ibfk_1", "sportsDataId", "program_spdata", "sportsDataId" );;
CALL {0}.AddConstraintIfNotExists( "program_spdata_event", "program_spdata_event_ibfk_2", "TMSId", "program", "TMSId" );;
CALL {0}.AddConstraintIfNotExists( "program_spevent", "program_spevent_ibfk_1", "TMSId", "program", "TMSId" );;
CALL {0}.AddConstraintIfNotExists( "program_spinfo", "program_spinfo_ibfk_1", "TMSId", "program", "TMSId" );;
CALL {0}.AddConstraintIfNotExists( "program_spteam", "program_spteam_ibfk_1", "TMSId", "program", "TMSId" );;
CALL {0}.AddConstraintIfNotExists( "program_title", "program_title_ibfk_1", "TMSId", "program", "TMSId" );;
CALL {0}.AddConstraintIfNotExists( "schedule_event", "schedule_event_ibfk_1", "scheduleId", "schedule", "scheduleId" );;
CALL {0}.AddConstraintIfNotExists( "schedule_event_bcastid", "schedule_event_bcastid_ibfk_1", "eventId", "schedule_event", "eventId" );;
CALL {0}.AddConstraintIfNotExists( "schedule_event_bcastid", "schedule_event_bcastid_ibfk_2", "scheduleId", "schedule", "scheduleId" );;
CALL {0}.AddConstraintIfNotExists( "schedule_event_right", "schedule_event_right_ibfk_1", "eventId", "schedule_event", "eventId" );;
CALL {0}.AddConstraintIfNotExists( "schedule_event_right", "schedule_event_right_ibfk_2", "scheduleId", "schedule", "scheduleId" );;
CALL {0}.AddConstraintIfNotExists( "schedule_event_right_param", "schedule_event_right_param_ibfk_1", "rightId", "schedule_event_right", "rightId" );;
CALL {0}.AddConstraintIfNotExists( "schedule_event_right_param", "schedule_event_right_param_ibfk_2", "scheduleId", "schedule", "scheduleId" );;
CALL {0}.AddConstraintIfNotExists( "season_asset", "season_asset_ibfk_1", "seasonTMSId", "season", "seasonTMSId" );;
CALL {0}.AddConstraintIfNotExists( "season_asset_id", "season_asset_id_ibfk_1", "seasonAssetId", "season_asset", "seasonAssetId" );;
CALL {0}.AddConstraintIfNotExists( "season_asset_id", "season_asset_id_ibfk_2", "seasonTMSId", "season", "seasonTMSId" );;
CALL {0}.AddConstraintIfNotExists( "season_cast", "season_cast_ibfk_1", "seasonTMSId", "season", "seasonTMSId" );;
CALL {0}.AddConstraintIfNotExists( "season_crew", "season_crew_ibfk_1", "seasonTMSId", "season", "seasonTMSId" );;
CALL {0}.AddConstraintIfNotExists( "season_description", "season_description_ibfk_1", "seasonTMSId", "season", "seasonTMSId" );;
CALL {0}.AddConstraintIfNotExists( "season_title", "season_title_ibfk_1", "seasonTMSId", "season", "seasonTMSId" );;
CALL {0}.AddConstraintIfNotExists( "source_affiliate", "source_affiliate_ibfk_1", "prgSvcId", "source", "prgSvcId" );;
CALL {0}.AddConstraintIfNotExists( "source_altname", "source_altname_ibfk_1", "prgSvcId", "source", "prgSvcId" );;
CALL {0}.AddConstraintIfNotExists( "source_asset", "source_asset_ibfk_1", "prgSvcId", "source", "prgSvcId" );;
CALL {0}.AddConstraintIfNotExists( "source_attribute", "source_attribute_ibfk_1", "prgSvcId", "source", "prgSvcId" );;
CALL {0}.AddConstraintIfNotExists( "source_bcastlang", "source_bcastlang_ibfk_1", "prgSvcId", "source", "prgSvcId" );;
CALL {0}.AddConstraintIfNotExists( "source_country", "source_country_ibfk_1", "prgSvcId", "source", "prgSvcId" );;
CALL {0}.AddConstraintIfNotExists( "source_edlang", "source_edlang_ibfk_1", "prgSvcId", "source", "prgSvcId" );;
CALL {0}.AddConstraintIfNotExists( "source_genre", "source_genre_ibfk_1", "prgSvcId", "source", "prgSvcId" );;
CALL {0}.AddConstraintIfNotExists( "source_group", "source_group_ibfk_1", "prgSvcId", "source", "prgSvcId" );;
CALL {0}.AddConstraintIfNotExists( "source_marketid", "source_marketid_ibfk_1", "prgSvcId", "source", "prgSvcId" );;
CALL {0}.AddConstraintIfNotExists( "source_relationship", "source_relationship_ibfk_1", "prgSvcId", "source", "prgSvcId" );;
CALL {0}.AddConstraintIfNotExists( "source_transportid", "source_transportid_ibfk_1", "prgSvcId", "source", "prgSvcId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_asset", "sourceprogram_asset_ibfk_1", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_asset_extattr", "sourceprogram_asset_extattr_ibfk_1", "spAssetId", "sourceprogram_asset", "spAssetId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_asset_extattr", "sourceprogram_asset_extattr_ibfk_2", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_asset_id", "sourceprogram_asset_id_ibfk_1", "spAssetId", "sourceprogram_asset", "spAssetId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_asset_id", "sourceprogram_asset_id_ibfk_2", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_asset_language", "sourceprogram_asset_language_ibfk_1", "spAssetId", "sourceprogram_asset", "spAssetId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_asset_language", "sourceprogram_asset_language_ibfk_2", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_asset_market", "sourceprogram_asset_market_ibfk_1", "spAssetId", "sourceprogram_asset", "spAssetId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_asset_market", "sourceprogram_asset_market_ibfk_2", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_asset_tag", "sourceprogram_asset_tag_ibfk_1", "spAssetId", "sourceprogram_asset", "spAssetId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_asset_tag", "sourceprogram_asset_tag_ibfk_2", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_cast", "sourceprogram_cast_ibfk_1", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_catalog", "sourceprogram_catalog_ibfk_1", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_catalog_language", "sourceprogram_catalog_language_ibfk_1", "spCatalogId", "sourceprogram_catalog", "spCatalogId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_catalog_language", "sourceprogram_catalog_language_ibfk_2", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_catalog_market", "sourceprogram_catalog_market_ibfk_1", "spCatalogId", "sourceprogram_catalog", "spCatalogId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_catalog_market", "sourceprogram_catalog_market_ibfk_2", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_country", "sourceprogram_country_ibfk_1", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_crew", "sourceprogram_crew_ibfk_1", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_description", "sourceprogram_description_ibfk_1", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_epinfo", "sourceprogram_epinfo_ibfk_1", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_genre", "sourceprogram_genre_ibfk_1", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_label", "sourceprogram_label_ibfk_1", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_mvinfo", "sourceprogram_mvinfo_ibfk_1", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_rating", "sourceprogram_rating_ibfk_1", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_rating_advisory", "sourceprogram_rating_advisory_ibfk_1", "spRatingId", "sourceprogram_rating", "spRatingId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_rating_advisory", "sourceprogram_rating_advisory_ibfk_2", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_season", "sourceprogram_season_ibfk_1", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_season_asset", "sourceprogram_season_asset_ibfk_1", "spSeasonId", "sourceprogram_season", "spSeasonId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_season_asset", "sourceprogram_season_asset_ibfk_2", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_season_asset_extattr", "sourceprogram_season_asset_extattr_ibfk_1", "spAssetId", "sourceprogram_season_asset", "spAssetId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_season_asset_extattr", "sourceprogram_season_asset_extattr_ibfk_2", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_season_asset_id", "sourceprogram_season_asset_id_ibfk_1", "spAssetId", "sourceprogram_season_asset", "spAssetId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_season_asset_id", "sourceprogram_season_asset_id_ibfk_2", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_season_asset_language", "sourceprogram_season_asset_language_ibfk_1", "spAssetId", "sourceprogram_season_asset", "spAssetId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_season_asset_language", "sourceprogram_season_asset_language_ibfk_2", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_season_asset_market", "sourceprogram_season_asset_market_ibfk_1", "spAssetId", "sourceprogram_season_asset", "spAssetId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_season_asset_market", "sourceprogram_season_asset_market_ibfk_2", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_season_asset_tag", "sourceprogram_season_asset_tag_ibfk_1", "spAssetId", "sourceprogram_season_asset", "spAssetId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_season_asset_tag", "sourceprogram_season_asset_tag_ibfk_2", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_season_cast", "sourceprogram_season_cast_ibfk_1", "spSeasonId", "sourceprogram_season", "spSeasonId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_season_cast", "sourceprogram_season_cast_ibfk_2", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_season_crew", "sourceprogram_season_crew_ibfk_1", "spSeasonId", "sourceprogram_season", "spSeasonId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_season_crew", "sourceprogram_season_crew_ibfk_2", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_season_desc", "sourceprogram_season_desc_ibfk_1", "spSeasonId", "sourceprogram_season", "spSeasonId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_season_desc", "sourceprogram_season_desc_ibfk_2", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_season_title", "sourceprogram_season_title_ibfk_1", "spSeasonId", "sourceprogram_season", "spSeasonId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_season_title", "sourceprogram_season_title_ibfk_2", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_season_xid", "sourceprogram_season_xid_ibfk_1", "spSeasonId", "sourceprogram_season", "spSeasonId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_season_xid", "sourceprogram_season_xid_ibfk_2", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_title", "sourceprogram_title_ibfk_1", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_versionlabel", "sourceprogram_versionlabel_ibfk_1", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sourceprogram_xid", "sourceprogram_xid_ibfk_1", "gnidsId", "sourceprogram", "gnidsId" );;
CALL {0}.AddConstraintIfNotExists( "sportsorg_asset", "sportsorg_asset_ibfk_1", "organizationId", "sportsorg", "organizationId" );;
CALL {0}.AddConstraintIfNotExists( "sportsorg_conf", "sportsorg_conf_ibfk_1", "organizationId", "sportsorg", "organizationId" );;
CALL {0}.AddConstraintIfNotExists( "sportsorg_conf_asset", "sportsorg_conf_asset_ibfk_1", "confId", "sportsorg_conf", "confId" );;
CALL {0}.AddConstraintIfNotExists( "sportsorg_conf_asset", "sportsorg_conf_asset_ibfk_2", "organizationId", "sportsorg", "organizationId" );;
CALL {0}.AddConstraintIfNotExists( "sportsorg_div", "sportsorg_div_ibfk_1", "organizationId", "sportsorg", "organizationId" );;
CALL {0}.AddConstraintIfNotExists( "sportsorg_event", "sportsorg_event_ibfk_1", "organizationId", "sportsorg", "organizationId" );;
CALL {0}.AddConstraintIfNotExists( "sportsorg_teambrand", "sportsorg_teambrand_ibfk_1", "organizationId", "sportsorg", "organizationId" );;
CALL {0}.AddConstraintIfNotExists( "team_genre", "team_genre_ibfk_1", "teamId", "team", "teamId" );;
CALL {0}.AddConstraintIfNotExists( "teambrand_asset", "teambrand_asset_ibfk_1", "teamBrandId", "teambrand", "teamBrandId" );;
CALL {0}.AddConstraintIfNotExists( "teambrand_name", "teambrand_name_ibfk_1", "teamBrandId", "teambrand", "teamBrandId" );;
CALL {0}.AddConstraintIfNotExists( "university_asset", "university_asset_ibfk_1", "universityId", "university", "universityId" );;
CALL {0}.AddConstraintIfNotExists( "university_name", "university_name_ibfk_1", "universityId", "university", "universityId" );;
CALL {0}.AddConstraintIfNotExists( "vdannotation_descriptor", "vdannotation_descriptor_ibfk_1", "TMSId", "vdannotation", "TMSId" );;
CALL {0}.AddConstraintIfNotExists( "venuebrand_name", "venuebrand_name_ibfk_1", "venueBrandId", "venuebrand", "venueBrandId" );;