-- {0}: core schema

USE {0};


CREATE TABLE IF NOT EXISTS `_stats` (
    `timestamp` datetime NOT NULL,
    `metric` varchar(255) NOT NULL,
    `dimension` varchar(255),
    `value` real,
  KEY `_stats_timestamp` (`timestamp`),
  KEY `_stats_metric` (`metric`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;



-- update_date stats for source
INSERT INTO {0}._stats (`timestamp`, `metric`, `value`)
SELECT FROM_UNIXTIME(CEILING( UNIX_TIMESTAMP(t.`updateDate`) / 900 ) * 900) AS `timestamp`
    ,'source_updates' AS `metric`, COUNT(t.`prgSvcId`) AS `value`
FROM {0}.source t
WHERE t.`updateDate` > (SELECT COALESCE(MAX(`timestamp`),'1970-01-01') FROM {0}._stats WHERE `metric` = 'source_updates')
GROUP BY `timestamp` ORDER BY `timestamp` DESC;

-- update_date stats for lineup
INSERT INTO {0}._stats (`timestamp`, `metric`, `value`)
SELECT FROM_UNIXTIME(CEILING( UNIX_TIMESTAMP(t.`updateDate`) / 900 ) * 900) AS `timestamp`
    ,'lineup_updates' AS `metric`, COUNT(t.`lineupId`) AS `value`
FROM {0}.lineup t
WHERE t.`updateDate` > (SELECT COALESCE(MAX(`timestamp`),'1970-01-01') FROM {0}._stats WHERE `metric` = 'lineup_updates')
GROUP BY `timestamp` ORDER BY `timestamp` DESC;

-- update_date stats for celebrity
INSERT INTO {0}._stats (`timestamp`, `metric`, `value`)
SELECT FROM_UNIXTIME(CEILING( UNIX_TIMESTAMP(t.`updateDate`) / 900 ) * 900) AS `timestamp`
    ,'celebrity_updates' AS `metric`, COUNT(t.`personId`) AS `value`
FROM {0}.celebrity t
WHERE t.`updateDate` > (SELECT COALESCE(MAX(`timestamp`),'1970-01-01') FROM {0}._stats WHERE `metric` = 'celebrity_updates')
GROUP BY `timestamp` ORDER BY `timestamp` DESC;

-- update_date stats for program
INSERT INTO {0}._stats (`timestamp`, `metric`, `value`)
SELECT FROM_UNIXTIME(CEILING( UNIX_TIMESTAMP(t.`updateDate`) / 900 ) * 900) AS `timestamp`
    ,'program_updates' AS `metric`, COUNT(t.`TMSId`) AS `value`
FROM {0}.program t
WHERE t.`updateDate` > (SELECT COALESCE(MAX(`timestamp`),'1970-01-01') FROM {0}._stats WHERE `metric` = 'program_updates')
GROUP BY `timestamp` ORDER BY `timestamp` DESC;

-- update_date stats for availability
INSERT INTO {0}._stats (`timestamp`, `metric`, `value`)
SELECT FROM_UNIXTIME(CEILING( UNIX_TIMESTAMP(t.`updateDate`) / 900 ) * 900) AS `timestamp`
    ,'availability_updates' AS `metric`, COUNT(t.`availabilityId`) AS `value`
FROM {0}.availability t
WHERE t.`updateDate` > (SELECT COALESCE(MAX(`timestamp`),'1970-01-01') FROM {0}._stats WHERE `metric` = 'availability_updates')
GROUP BY `timestamp` ORDER BY `timestamp` DESC;

-- update_date stats for mapping
INSERT INTO {0}._stats (`timestamp`, `metric`, `value`)
SELECT FROM_UNIXTIME(CEILING( UNIX_TIMESTAMP(t.`updateDate`) / 900 ) * 900) AS `timestamp`
    ,'mapping_updates' AS `metric`, COUNT(t.`mappingId`) AS `value`
FROM {0}.mapping t
WHERE t.`updateDate` > (SELECT COALESCE(MAX(`timestamp`),'1970-01-01') FROM {0}._stats WHERE `metric` = 'mapping_updates')
GROUP BY `timestamp` ORDER BY `timestamp` DESC;

-- update_date stats for schedule
INSERT INTO {0}._stats (`timestamp`, `metric`, `value`)
SELECT FROM_UNIXTIME(CEILING( UNIX_TIMESTAMP(t.`updateDate`) / 900 ) * 900) AS `timestamp`
    ,'schedule_updates' AS `metric`, COUNT(t.`scheduleId`) AS `value`
FROM {0}.schedule t
WHERE t.`updateDate` > (SELECT COALESCE(MAX(`timestamp`),'1970-01-01') FROM {0}._stats WHERE `metric` = 'schedule_updates')
GROUP BY `timestamp` ORDER BY `timestamp` DESC;


-- ingest_id stats for source
INSERT INTO {0}._stats (`timestamp`, `metric`, `value`)
SELECT STR_TO_DATE( CAST(t.`ingestId` AS CHAR(14)), '%Y%m%d%H%i%s' ) AS `timestamp`,
    'source_ingests' AS `metric`, COUNT(t.`prgSvcId`) AS `value`
FROM {0}.source t
WHERE STR_TO_DATE( CAST(t.`ingestId` AS CHAR(14)), '%Y%m%d%H%i%s' ) > (SELECT COALESCE(MAX(`timestamp`),'1970-01-01') FROM {0}._stats WHERE `metric` = 'source_ingests')
GROUP BY t.`ingestId` ORDER BY t.`ingestId` DESC;

-- ingest_id stats for lineup
INSERT INTO {0}._stats (`timestamp`, `metric`, `value`)
SELECT STR_TO_DATE( CAST(t.`ingestId` AS CHAR(14)), '%Y%m%d%H%i%s' ) AS `timestamp`,
    'lineup_ingests' AS `metric`, COUNT(t.`lineupId`) AS `value`
FROM {0}.lineup t
WHERE STR_TO_DATE( CAST(t.`ingestId` AS CHAR(14)), '%Y%m%d%H%i%s' ) > (SELECT COALESCE(MAX(`timestamp`),'1970-01-01') FROM {0}._stats WHERE `metric` = 'lineup_ingests')
GROUP BY t.`ingestId` ORDER BY t.`ingestId` DESC;

-- ingest_id stats for celebrity
INSERT INTO {0}._stats (`timestamp`, `metric`, `value`)
SELECT STR_TO_DATE( CAST(t.`ingestId` AS CHAR(14)), '%Y%m%d%H%i%s' ) AS `timestamp`,
    'celebrity_ingests' AS `metric`, COUNT(t.`personId`) AS `value`
FROM {0}.celebrity t
WHERE STR_TO_DATE( CAST(t.`ingestId` AS CHAR(14)), '%Y%m%d%H%i%s' ) > (SELECT COALESCE(MAX(`timestamp`),'1970-01-01') FROM {0}._stats WHERE `metric` = 'celebrity_ingests')
GROUP BY t.`ingestId` ORDER BY t.`ingestId` DESC;

-- ingest_id stats for program
INSERT INTO {0}._stats (`timestamp`, `metric`, `value`)
SELECT STR_TO_DATE( CAST(t.`ingestId` AS CHAR(14)), '%Y%m%d%H%i%s' ) AS `timestamp`,
    'program_ingests' AS `metric`, COUNT(t.`TMSId`) AS `value`
FROM {0}.program t
WHERE STR_TO_DATE( CAST(t.`ingestId` AS CHAR(14)), '%Y%m%d%H%i%s' ) > (SELECT COALESCE(MAX(`timestamp`),'1970-01-01') FROM {0}._stats WHERE `metric` = 'program_ingests')
GROUP BY t.`ingestId` ORDER BY t.`ingestId` DESC;

-- ingest_id stats for availability
INSERT INTO {0}._stats (`timestamp`, `metric`, `value`)
SELECT STR_TO_DATE( CAST(t.`ingestId` AS CHAR(14)), '%Y%m%d%H%i%s' ) AS `timestamp`,
    'availability_ingests' AS `metric`, COUNT(t.`availabilityId`) AS `value`
FROM {0}.availability t
WHERE STR_TO_DATE( CAST(t.`ingestId` AS CHAR(14)), '%Y%m%d%H%i%s' ) > (SELECT COALESCE(MAX(`timestamp`),'1970-01-01') FROM {0}._stats WHERE `metric` = 'availability_ingests')
GROUP BY t.`ingestId` ORDER BY t.`ingestId` DESC;

-- ingest_id stats for mapping
INSERT INTO {0}._stats (`timestamp`, `metric`, `value`)
SELECT STR_TO_DATE( CAST(t.`ingestId` AS CHAR(14)), '%Y%m%d%H%i%s' ) AS `timestamp`,
    'mapping_ingests' AS `metric`, COUNT(t.`mappingId`) AS `value`
FROM {0}.mapping t
WHERE STR_TO_DATE( CAST(t.`ingestId` AS CHAR(14)), '%Y%m%d%H%i%s' ) > (SELECT COALESCE(MAX(`timestamp`),'1970-01-01') FROM {0}._stats WHERE `metric` = 'mapping_ingests')
GROUP BY t.`ingestId` ORDER BY t.`ingestId` DESC;

-- ingest_id stats for schedule
INSERT INTO {0}._stats (`timestamp`, `metric`, `value`)
SELECT STR_TO_DATE( CAST(t.`ingestId` AS CHAR(14)), '%Y%m%d%H%i%s' ) AS `timestamp`,
    'schedule_ingests' AS `metric`, COUNT(t.`scheduleId`) AS `value`
FROM {0}.schedule t
WHERE STR_TO_DATE( CAST(t.`ingestId` AS CHAR(14)), '%Y%m%d%H%i%s' ) > (SELECT COALESCE(MAX(`timestamp`),'1970-01-01') FROM {0}._stats WHERE `metric` = 'schedule_ingests')
GROUP BY t.`ingestId` ORDER BY t.`ingestId` DESC;
