-- {0}: core schema
-- {1}: start at 0 (cold start) or 1 (first update)
-- {2}: purge tables after N days

SET SEARCH_PATH TO '{0}';


-- Create _md5_entity_cv table
CREATE TABLE IF NOT EXISTS {0}._md5_entity_cv (
	 "timestamp" TIMESTAMP
	,"entityId" TEXT
	,"updateId" INT8
	,"updateDate" TIMESTAMP
	,"ingestId" INT8
	,"cv" TEXT
	,"attribute" TEXT
);

-- Purge old data
DELETE FROM {0}._md5_entity_cv WHERE "timestamp" < CURRENT_DATE-{2};


-- Create _md5_entity_source table
CREATE TABLE IF NOT EXISTS {0}._md5_entity_source (
	 "timestamp" TIMESTAMP
	,"entityId" TEXT
	,"updateId" INT8
	,"updateDate" TIMESTAMP
	,"ingestId" INT8
	,"source" TEXT
	,"country" TEXT
	,"altname" TEXT
	,"attribute" TEXT
	,"edlang" TEXT
	,"bcastlang" TEXT
	,"relationship" TEXT
	,"affiliate" TEXT
	,"asset" TEXT
	,"marketid" TEXT
	,"genre" TEXT
	,"group" TEXT
	,"transportid" TEXT
);

-- Purge old data
DELETE FROM {0}._md5_entity_source WHERE "timestamp" < CURRENT_DATE-{2};


-- Create _md5_entity_lineup table
CREATE TABLE IF NOT EXISTS {0}._md5_entity_lineup (
	 "timestamp" TIMESTAMP
	,"entityId" TEXT
	,"updateId" INT8
	,"updateDate" TIMESTAMP
	,"ingestId" INT8
	,"lineup" TEXT
	,"channel" TEXT
	,"channel_transport" TEXT
	,"channel_transport_id" TEXT
	,"postalcode" TEXT
	,"market" TEXT
);

-- Purge old data
DELETE FROM {0}._md5_entity_lineup WHERE "timestamp" < CURRENT_DATE-{2};


-- Create _md5_entity_celebrity table
CREATE TABLE IF NOT EXISTS {0}._md5_entity_celebrity (
	 "timestamp" TIMESTAMP
	,"entityId" TEXT
	,"updateId" INT8
	,"updateDate" TIMESTAMP
	,"ingestId" INT8
	,"celebrity" TEXT
	,"name" TEXT
	,"award" TEXT
	,"asset" TEXT
	,"mediography" TEXT
	,"mediography_credit" TEXT
	,"participanttype" TEXT
	,"biography" TEXT
	,"relationship" TEXT
	,"relationshipevent" TEXT
	,"education" TEXT
	,"milestone" TEXT
	,"note" TEXT
	,"quote" TEXT
	,"highlight" TEXT
	,"socialmedia" TEXT
	,"enhancedaward" TEXT
);

-- Purge old data
DELETE FROM {0}._md5_entity_celebrity WHERE "timestamp" < CURRENT_DATE-{2};


-- Create _md5_entity_descriptortaxonomy table
CREATE TABLE IF NOT EXISTS {0}._md5_entity_descriptortaxonomy (
	 "timestamp" TIMESTAMP
	,"entityId" TEXT
	,"updateId" INT8
	,"updateDate" TIMESTAMP
	,"ingestId" INT8
	,"descriptortaxonomy" TEXT
	,"descriptor" TEXT
);

-- Purge old data
DELETE FROM {0}._md5_entity_descriptortaxonomy WHERE "timestamp" < CURRENT_DATE-{2};


-- Create _md5_entity_descriptor table
CREATE TABLE IF NOT EXISTS {0}._md5_entity_descriptor (
	 "timestamp" TIMESTAMP
	,"entityId" TEXT
	,"updateId" INT8
	,"updateDate" TIMESTAMP
	,"ingestId" INT8
	,"descriptor" TEXT
);

-- Purge old data
DELETE FROM {0}._md5_entity_descriptor WHERE "timestamp" < CURRENT_DATE-{2};


-- Create _md5_entity_season table
CREATE TABLE IF NOT EXISTS {0}._md5_entity_season (
	 "timestamp" TIMESTAMP
	,"entityId" TEXT
	,"updateId" INT8
	,"updateDate" TIMESTAMP
	,"ingestId" INT8
	,"season" TEXT
	,"title" TEXT
	,"description" TEXT
	,"cast" TEXT
	,"crew" TEXT
	,"asset" TEXT
	,"asset_id" TEXT
);

-- Purge old data
DELETE FROM {0}._md5_entity_season WHERE "timestamp" < CURRENT_DATE-{2};


-- Create _md5_entity_program table
CREATE TABLE IF NOT EXISTS {0}._md5_entity_program (
	 "timestamp" TIMESTAMP
	,"entityId" TEXT
	,"updateId" INT8
	,"updateDate" TIMESTAMP
	,"ingestId" INT8
	,"program" TEXT
	,"season" TEXT
	,"title" TEXT
	,"description" TEXT
	,"cast" TEXT
	,"crew" TEXT
	,"country" TEXT
	,"award" TEXT
	,"genre" TEXT
	,"rating" TEXT
	,"qualityrating" TEXT
	,"ratingadvisory" TEXT
	,"mvinfo" TEXT
	,"mvtrailer" TEXT
	,"epinfo" TEXT
	,"epinfo_alt" TEXT
	,"spinfo" TEXT
	,"spteam" TEXT
	,"spevent" TEXT
	,"spdata" TEXT
	,"spdata_event" TEXT
	,"asset" TEXT
	,"asset_id" TEXT
	,"release" TEXT
	,"release_attribute" TEXT
	,"release_distributor" TEXT
	,"relationship" TEXT
	,"externallink" TEXT
	,"descriptor" TEXT
	,"origaudiolang" TEXT
);

-- Purge old data
DELETE FROM {0}._md5_entity_program WHERE "timestamp" < CURRENT_DATE-{2};


-- Create _md5_entity_availability table
CREATE TABLE IF NOT EXISTS {0}._md5_entity_availability (
	 "timestamp" TIMESTAMP
	,"entityId" TEXT
	,"updateId" INT8
	,"updateDate" TIMESTAMP
	,"ingestId" INT8
	,"availability" TEXT
	,"id" TEXT
	,"url" TEXT
	,"viewingoption" TEXT
	,"providerdata" TEXT
);

-- Purge old data
DELETE FROM {0}._md5_entity_availability WHERE "timestamp" < CURRENT_DATE-{2};


-- Create _md5_entity_mapping table
CREATE TABLE IF NOT EXISTS {0}._md5_entity_mapping (
	 "timestamp" TIMESTAMP
	,"entityId" TEXT
	,"updateId" INT8
	,"updateDate" TIMESTAMP
	,"ingestId" INT8
	,"mapping" TEXT
	,"id" TEXT
	,"link" TEXT
);

-- Purge old data
DELETE FROM {0}._md5_entity_mapping WHERE "timestamp" < CURRENT_DATE-{2};


-- Create _md5_entity_schedule table
CREATE TABLE IF NOT EXISTS {0}._md5_entity_schedule (
	 "timestamp" TIMESTAMP
	,"entityId" TEXT
	,"updateId" INT8
	,"updateDate" TIMESTAMP
	,"ingestId" INT8
	,"schedule" TEXT
	,"event" TEXT
	,"event_bcastid" TEXT
	,"event_right" TEXT
	,"event_right_param" TEXT
);

-- Purge old data
DELETE FROM {0}._md5_entity_schedule WHERE "timestamp" < CURRENT_DATE-{2};


-- Create _md5_entity_sourceprogram table
CREATE TABLE IF NOT EXISTS {0}._md5_entity_sourceprogram (
	 "timestamp" TIMESTAMP
	,"entityId" TEXT
	,"updateId" INT8
	,"updateDate" TIMESTAMP
	,"ingestId" INT8
	,"sourceprogram" TEXT
	,"label" TEXT
	,"versionlabel" TEXT
	,"catalog" TEXT
	,"catalog_language" TEXT
	,"catalog_market" TEXT
	,"title" TEXT
	,"description" TEXT
	,"cast" TEXT
	,"crew" TEXT
	,"country" TEXT
	,"genre" TEXT
	,"rating" TEXT
	,"rating_advisory" TEXT
	,"mvinfo" TEXT
	,"epinfo" TEXT
	,"season" TEXT
	,"season_title" TEXT
	,"season_desc" TEXT
	,"season_cast" TEXT
	,"season_crew" TEXT
	,"season_asset" TEXT
	,"season_asset_id" TEXT
	,"season_asset_language" TEXT
	,"season_asset_market" TEXT
	,"season_asset_extattr" TEXT
	,"season_asset_tag" TEXT
	,"season_xid" TEXT
	,"asset" TEXT
	,"asset_id" TEXT
	,"asset_language" TEXT
	,"asset_market" TEXT
	,"asset_extattr" TEXT
	,"asset_tag" TEXT
	,"xid" TEXT
);

-- Purge old data
DELETE FROM {0}._md5_entity_sourceprogram WHERE "timestamp" < CURRENT_DATE-{2};


-- Create _md5_entity_popularity table
CREATE TABLE IF NOT EXISTS {0}._md5_entity_popularity (
	 "timestamp" TIMESTAMP
	,"entityId" TEXT
	,"updateId" INT8
	,"updateDate" TIMESTAMP
	,"ingestId" INT8
	,"popularity" TEXT
);

-- Purge old data
DELETE FROM {0}._md5_entity_popularity WHERE "timestamp" < CURRENT_DATE-{2};


-- Create _md5_entity_university table
CREATE TABLE IF NOT EXISTS {0}._md5_entity_university (
	 "timestamp" TIMESTAMP
	,"entityId" TEXT
	,"updateId" INT8
	,"updateDate" TIMESTAMP
	,"ingestId" INT8
	,"university" TEXT
	,"name" TEXT
	,"asset" TEXT
);

-- Purge old data
DELETE FROM {0}._md5_entity_university WHERE "timestamp" < CURRENT_DATE-{2};


-- Create _md5_entity_venue table
CREATE TABLE IF NOT EXISTS {0}._md5_entity_venue (
	 "timestamp" TIMESTAMP
	,"entityId" TEXT
	,"updateId" INT8
	,"updateDate" TIMESTAMP
	,"ingestId" INT8
	,"venue" TEXT
);

-- Purge old data
DELETE FROM {0}._md5_entity_venue WHERE "timestamp" < CURRENT_DATE-{2};


-- Create _md5_entity_venuebrand table
CREATE TABLE IF NOT EXISTS {0}._md5_entity_venuebrand (
	 "timestamp" TIMESTAMP
	,"entityId" TEXT
	,"updateId" INT8
	,"updateDate" TIMESTAMP
	,"ingestId" INT8
	,"venuebrand" TEXT
	,"name" TEXT
);

-- Purge old data
DELETE FROM {0}._md5_entity_venuebrand WHERE "timestamp" < CURRENT_DATE-{2};


-- Create _md5_entity_sportsorg table
CREATE TABLE IF NOT EXISTS {0}._md5_entity_sportsorg (
	 "timestamp" TIMESTAMP
	,"entityId" TEXT
	,"updateId" INT8
	,"updateDate" TIMESTAMP
	,"ingestId" INT8
	,"sportsorg" TEXT
	,"asset" TEXT
	,"conf" TEXT
	,"conf_asset" TEXT
	,"div" TEXT
	,"teambrand" TEXT
	,"event" TEXT
);

-- Purge old data
DELETE FROM {0}._md5_entity_sportsorg WHERE "timestamp" < CURRENT_DATE-{2};


-- Create _md5_entity_team table
CREATE TABLE IF NOT EXISTS {0}._md5_entity_team (
	 "timestamp" TIMESTAMP
	,"entityId" TEXT
	,"updateId" INT8
	,"updateDate" TIMESTAMP
	,"ingestId" INT8
	,"team" TEXT
	,"genre" TEXT
);

-- Purge old data
DELETE FROM {0}._md5_entity_team WHERE "timestamp" < CURRENT_DATE-{2};


-- Create _md5_entity_teambrand table
CREATE TABLE IF NOT EXISTS {0}._md5_entity_teambrand (
	 "timestamp" TIMESTAMP
	,"entityId" TEXT
	,"updateId" INT8
	,"updateDate" TIMESTAMP
	,"ingestId" INT8
	,"teambrand" TEXT
	,"name" TEXT
	,"asset" TEXT
);

-- Purge old data
DELETE FROM {0}._md5_entity_teambrand WHERE "timestamp" < CURRENT_DATE-{2};


-- Create _md5_entity_vdannotation table
CREATE TABLE IF NOT EXISTS {0}._md5_entity_vdannotation (
	 "timestamp" TIMESTAMP
	,"entityId" TEXT
	,"updateId" INT8
	,"updateDate" TIMESTAMP
	,"ingestId" INT8
	,"vdannotation" TEXT
	,"descriptor" TEXT
);

-- Purge old data
DELETE FROM {0}._md5_entity_vdannotation WHERE "timestamp" < CURRENT_DATE-{2};


-- Populate _md5_entity_cv table
WITH max_ingest_id AS ( 	SELECT COALESCE( MAX("ingestId"), {1}*( SELECT COALESCE(MIN("ingestId"),0) FROM {0}.cv ) )	FROM {0}._md5_entity_cv )
INSERT INTO {0}._md5_entity_cv ("timestamp","entityId","updateId","updateDate","ingestId","cv","attribute")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp", p."cvId"::TEXT AS "entityId", p."updateId", p."updateDate", p."ingestId", p."MD5" AS "cv"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.cv_attribute c WHERE p."cvId"=c."cvId" ) AS "attribute"
FROM cv p
WHERE "ingestId" > (SELECT * FROM max_ingest_id)
;


-- Populate _md5_entity_source table
WITH max_ingest_id AS ( 	SELECT COALESCE( MAX("ingestId"), {1}*( SELECT COALESCE(MIN("ingestId"),0) FROM {0}.source ) )	FROM {0}._md5_entity_source )
INSERT INTO {0}._md5_entity_source ("timestamp","entityId","updateId","updateDate","ingestId","source","country","altname","attribute","edlang","bcastlang","relationship","affiliate","asset","marketid","genre","group","transportid")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp", p."prgSvcId"::TEXT AS "entityId", p."updateId", p."updateDate", p."ingestId", p."MD5" AS "source"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.source_country c WHERE p."prgSvcId"=c."prgSvcId" ) AS "country"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.source_altname c WHERE p."prgSvcId"=c."prgSvcId" ) AS "altname"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.source_attribute c WHERE p."prgSvcId"=c."prgSvcId" ) AS "attribute"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.source_edlang c WHERE p."prgSvcId"=c."prgSvcId" ) AS "edlang"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.source_bcastlang c WHERE p."prgSvcId"=c."prgSvcId" ) AS "bcastlang"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.source_relationship c WHERE p."prgSvcId"=c."prgSvcId" ) AS "relationship"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.source_affiliate c WHERE p."prgSvcId"=c."prgSvcId" ) AS "affiliate"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.source_asset c WHERE p."prgSvcId"=c."prgSvcId" ) AS "asset"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.source_marketid c WHERE p."prgSvcId"=c."prgSvcId" ) AS "marketid"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.source_genre c WHERE p."prgSvcId"=c."prgSvcId" ) AS "genre"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.source_group c WHERE p."prgSvcId"=c."prgSvcId" ) AS "group"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.source_transportid c WHERE p."prgSvcId"=c."prgSvcId" ) AS "transportid"
FROM source p
WHERE "ingestId" > (SELECT * FROM max_ingest_id)
;


-- Populate _md5_entity_lineup table
WITH max_ingest_id AS ( 	SELECT COALESCE( MAX("ingestId"), {1}*( SELECT COALESCE(MIN("ingestId"),0) FROM {0}.lineup ) )	FROM {0}._md5_entity_lineup )
INSERT INTO {0}._md5_entity_lineup ("timestamp","entityId","updateId","updateDate","ingestId","lineup","channel","channel_transport","channel_transport_id","postalcode","market")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp", p."lineupId"::TEXT AS "entityId", p."updateId", p."updateDate", p."ingestId", p."MD5" AS "lineup"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.lineup_channel c WHERE p."lineupId"=c."lineupId" ) AS "channel"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.lineup_channel_transport c WHERE p."lineupId"=c."lineupId" ) AS "channel_transport"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.lineup_channel_transport_id c WHERE p."lineupId"=c."lineupId" ) AS "channel_transport_id"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.lineup_postalcode c WHERE p."lineupId"=c."lineupId" ) AS "postalcode"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.lineup_market c WHERE p."lineupId"=c."lineupId" ) AS "market"
FROM lineup p
WHERE "ingestId" > (SELECT * FROM max_ingest_id)
;


-- Populate _md5_entity_celebrity table
WITH max_ingest_id AS ( 	SELECT COALESCE( MAX("ingestId"), {1}*( SELECT COALESCE(MIN("ingestId"),0) FROM {0}.celebrity ) )	FROM {0}._md5_entity_celebrity )
INSERT INTO {0}._md5_entity_celebrity ("timestamp","entityId","updateId","updateDate","ingestId","celebrity","name","award","asset","mediography","mediography_credit","participanttype","biography","relationship","relationshipevent","education","milestone","note","quote","highlight","socialmedia","enhancedaward")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp", p."personId"::TEXT AS "entityId", p."updateId", p."updateDate", p."ingestId", p."MD5" AS "celebrity"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.celebrity_name c WHERE p."personId"=c."personId" ) AS "name"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.celebrity_award c WHERE p."personId"=c."personId" ) AS "award"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.celebrity_asset c WHERE p."personId"=c."personId" ) AS "asset"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.celebrity_mediography c WHERE p."personId"=c."personId" ) AS "mediography"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.celebrity_mediography_credit c WHERE p."personId"=c."personId" ) AS "mediography_credit"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.celebrity_participanttype c WHERE p."personId"=c."personId" ) AS "participanttype"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.celebrity_biography c WHERE p."personId"=c."personId" ) AS "biography"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.celebrity_relationship c WHERE p."personId"=c."personId" ) AS "relationship"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.celebrity_relationshipevent c WHERE p."personId"=c."personId" ) AS "relationshipevent"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.celebrity_education c WHERE p."personId"=c."personId" ) AS "education"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.celebrity_milestone c WHERE p."personId"=c."personId" ) AS "milestone"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.celebrity_note c WHERE p."personId"=c."personId" ) AS "note"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.celebrity_quote c WHERE p."personId"=c."personId" ) AS "quote"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.celebrity_highlight c WHERE p."personId"=c."personId" ) AS "highlight"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.celebrity_socialmedia c WHERE p."personId"=c."personId" ) AS "socialmedia"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.celebrity_enhancedaward c WHERE p."personId"=c."personId" ) AS "enhancedaward"
FROM celebrity p
WHERE "ingestId" > (SELECT * FROM max_ingest_id)
;


-- Populate _md5_entity_descriptortaxonomy table
WITH max_ingest_id AS ( 	SELECT COALESCE( MAX("ingestId"), {1}*( SELECT COALESCE(MIN("ingestId"),0) FROM {0}.descriptortaxonomy ) )	FROM {0}._md5_entity_descriptortaxonomy )
INSERT INTO {0}._md5_entity_descriptortaxonomy ("timestamp","entityId","updateId","updateDate","ingestId","descriptortaxonomy","descriptor")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp", p."taxonomyId"::TEXT AS "entityId", p."updateId", p."updateDate", p."ingestId", p."MD5" AS "descriptortaxonomy"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.descriptortaxonomy_descriptor c WHERE p."taxonomyId"=c."taxonomyId" ) AS "descriptor"
FROM descriptortaxonomy p
WHERE "ingestId" > (SELECT * FROM max_ingest_id)
;


-- Populate _md5_entity_descriptor table
WITH max_ingest_id AS ( 	SELECT COALESCE( MAX("ingestId"), {1}*( SELECT COALESCE(MIN("ingestId"),0) FROM {0}.descriptor ) )	FROM {0}._md5_entity_descriptor )
INSERT INTO {0}._md5_entity_descriptor ("timestamp","entityId","updateId","updateDate","ingestId","descriptor")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp", p."descriptorId"::TEXT AS "entityId", p."updateId", p."updateDate", p."ingestId", p."MD5" AS "descriptor"
FROM descriptor p
WHERE "ingestId" > (SELECT * FROM max_ingest_id)
;


-- Populate _md5_entity_season table
WITH max_ingest_id AS ( 	SELECT COALESCE( MAX("ingestId"), {1}*( SELECT COALESCE(MIN("ingestId"),0) FROM {0}.season ) )	FROM {0}._md5_entity_season )
INSERT INTO {0}._md5_entity_season ("timestamp","entityId","updateId","updateDate","ingestId","season","title","description","cast","crew","asset","asset_id")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp", p."seasonTMSId"::TEXT AS "entityId", p."updateId", p."updateDate", p."ingestId", p."MD5" AS "season"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.season_title c WHERE p."seasonTMSId"=c."seasonTMSId" ) AS "title"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.season_description c WHERE p."seasonTMSId"=c."seasonTMSId" ) AS "description"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.season_cast c WHERE p."seasonTMSId"=c."seasonTMSId" ) AS "cast"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.season_crew c WHERE p."seasonTMSId"=c."seasonTMSId" ) AS "crew"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.season_asset c WHERE p."seasonTMSId"=c."seasonTMSId" ) AS "asset"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.season_asset_id c WHERE p."seasonTMSId"=c."seasonTMSId" ) AS "asset_id"
FROM season p
WHERE "ingestId" > (SELECT * FROM max_ingest_id)
;


-- Populate _md5_entity_program table
WITH max_ingest_id AS ( 	SELECT COALESCE( MAX("ingestId"), {1}*( SELECT COALESCE(MIN("ingestId"),0) FROM {0}.program ) )	FROM {0}._md5_entity_program )
INSERT INTO {0}._md5_entity_program ("timestamp","entityId","updateId","updateDate","ingestId","program","season","title","description","cast","crew","country","award","genre","rating","qualityrating","ratingadvisory","mvinfo","mvtrailer","epinfo","epinfo_alt","spinfo","spteam","spevent","spdata","spdata_event","asset","asset_id","release","release_attribute","release_distributor","relationship","externallink","descriptor","origaudiolang")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp", p."TMSId"::TEXT AS "entityId", p."updateId", p."updateDate", p."ingestId", p."MD5" AS "program"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.program_season c WHERE p."TMSId"=c."TMSId" ) AS "season"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.program_title c WHERE p."TMSId"=c."TMSId" ) AS "title"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.program_description c WHERE p."TMSId"=c."TMSId" ) AS "description"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.program_cast c WHERE p."TMSId"=c."TMSId" ) AS "cast"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.program_crew c WHERE p."TMSId"=c."TMSId" ) AS "crew"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.program_country c WHERE p."TMSId"=c."TMSId" ) AS "country"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.program_award c WHERE p."TMSId"=c."TMSId" ) AS "award"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.program_genre c WHERE p."TMSId"=c."TMSId" ) AS "genre"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.program_rating c WHERE p."TMSId"=c."TMSId" ) AS "rating"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.program_qualityrating c WHERE p."TMSId"=c."TMSId" ) AS "qualityrating"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.program_ratingadvisory c WHERE p."TMSId"=c."TMSId" ) AS "ratingadvisory"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.program_mvinfo c WHERE p."TMSId"=c."TMSId" ) AS "mvinfo"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.program_mvtrailer c WHERE p."TMSId"=c."TMSId" ) AS "mvtrailer"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.program_epinfo c WHERE p."TMSId"=c."TMSId" ) AS "epinfo"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.program_epinfo_alt c WHERE p."TMSId"=c."TMSId" ) AS "epinfo_alt"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.program_spinfo c WHERE p."TMSId"=c."TMSId" ) AS "spinfo"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.program_spteam c WHERE p."TMSId"=c."TMSId" ) AS "spteam"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.program_spevent c WHERE p."TMSId"=c."TMSId" ) AS "spevent"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.program_spdata c WHERE p."TMSId"=c."TMSId" ) AS "spdata"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.program_spdata_event c WHERE p."TMSId"=c."TMSId" ) AS "spdata_event"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.program_asset c WHERE p."TMSId"=c."TMSId" ) AS "asset"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.program_asset_id c WHERE p."TMSId"=c."TMSId" ) AS "asset_id"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.program_release c WHERE p."TMSId"=c."TMSId" ) AS "release"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.program_release_attribute c WHERE p."TMSId"=c."TMSId" ) AS "release_attribute"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.program_release_distributor c WHERE p."TMSId"=c."TMSId" ) AS "release_distributor"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.program_relationship c WHERE p."TMSId"=c."TMSId" ) AS "relationship"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.program_externallink c WHERE p."TMSId"=c."TMSId" ) AS "externallink"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.program_descriptor c WHERE p."TMSId"=c."TMSId" ) AS "descriptor"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.program_origaudiolang c WHERE p."TMSId"=c."TMSId" ) AS "origaudiolang"
FROM program p
WHERE "ingestId" > (SELECT * FROM max_ingest_id)
;


-- Populate _md5_entity_availability table
WITH max_ingest_id AS ( 	SELECT COALESCE( MAX("ingestId"), {1}*( SELECT COALESCE(MIN("ingestId"),0) FROM {0}.availability ) )	FROM {0}._md5_entity_availability )
INSERT INTO {0}._md5_entity_availability ("timestamp","entityId","updateId","updateDate","ingestId","availability","id","url","viewingoption","providerdata")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp", p."availabilityId"::TEXT AS "entityId", p."updateId", p."updateDate", p."ingestId", p."MD5" AS "availability"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.availability_id c WHERE p."availabilityId"=c."availabilityId" ) AS "id"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.availability_url c WHERE p."availabilityId"=c."availabilityId" ) AS "url"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.availability_viewingoption c WHERE p."availabilityId"=c."availabilityId" ) AS "viewingoption"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.availability_providerdata c WHERE p."availabilityId"=c."availabilityId" ) AS "providerdata"
FROM availability p
WHERE "ingestId" > (SELECT * FROM max_ingest_id)
;


-- Populate _md5_entity_mapping table
WITH max_ingest_id AS ( 	SELECT COALESCE( MAX("ingestId"), {1}*( SELECT COALESCE(MIN("ingestId"),0) FROM {0}.mapping ) )	FROM {0}._md5_entity_mapping )
INSERT INTO {0}._md5_entity_mapping ("timestamp","entityId","updateId","updateDate","ingestId","mapping","id","link")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp", p."mappingId"::TEXT AS "entityId", p."updateId", p."updateDate", p."ingestId", p."MD5" AS "mapping"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.mapping_id c WHERE p."mappingId"=c."mappingId" ) AS "id"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.mapping_link c WHERE p."mappingId"=c."mappingId" ) AS "link"
FROM mapping p
WHERE "ingestId" > (SELECT * FROM max_ingest_id)
;


-- Populate _md5_entity_schedule table
WITH max_ingest_id AS ( 	SELECT COALESCE( MAX("ingestId"), {1}*( SELECT COALESCE(MIN("ingestId"),0) FROM {0}.schedule ) )	FROM {0}._md5_entity_schedule )
INSERT INTO {0}._md5_entity_schedule ("timestamp","entityId","updateId","updateDate","ingestId","schedule","event","event_bcastid","event_right","event_right_param")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp", p."scheduleId"::TEXT AS "entityId", p."updateId", p."updateDate", p."ingestId", p."MD5" AS "schedule"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.schedule_event c WHERE p."scheduleId"=c."scheduleId" ) AS "event"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.schedule_event_bcastid c WHERE p."scheduleId"=c."scheduleId" ) AS "event_bcastid"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.schedule_event_right c WHERE p."scheduleId"=c."scheduleId" ) AS "event_right"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.schedule_event_right_param c WHERE p."scheduleId"=c."scheduleId" ) AS "event_right_param"
FROM schedule p
WHERE "ingestId" > (SELECT * FROM max_ingest_id)
;


-- Populate _md5_entity_sourceprogram table
WITH max_ingest_id AS ( 	SELECT COALESCE( MAX("ingestId"), {1}*( SELECT COALESCE(MIN("ingestId"),0) FROM {0}.sourceprogram ) )	FROM {0}._md5_entity_sourceprogram )
INSERT INTO {0}._md5_entity_sourceprogram ("timestamp","entityId","updateId","updateDate","ingestId","sourceprogram","label","versionlabel","catalog","catalog_language","catalog_market","title","description","cast","crew","country","genre","rating","rating_advisory","mvinfo","epinfo","season","season_title","season_desc","season_cast","season_crew","season_asset","season_asset_id","season_asset_language","season_asset_market","season_asset_extattr","season_asset_tag","season_xid","asset","asset_id","asset_language","asset_market","asset_extattr","asset_tag","xid")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp", p."gnidsId"::TEXT AS "entityId", p."updateId", p."updateDate", p."ingestId", p."MD5" AS "sourceprogram"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_label c WHERE p."gnidsId"=c."gnidsId" ) AS "label"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_versionlabel c WHERE p."gnidsId"=c."gnidsId" ) AS "versionlabel"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_catalog c WHERE p."gnidsId"=c."gnidsId" ) AS "catalog"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_catalog_language c WHERE p."gnidsId"=c."gnidsId" ) AS "catalog_language"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_catalog_market c WHERE p."gnidsId"=c."gnidsId" ) AS "catalog_market"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_title c WHERE p."gnidsId"=c."gnidsId" ) AS "title"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_description c WHERE p."gnidsId"=c."gnidsId" ) AS "description"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_cast c WHERE p."gnidsId"=c."gnidsId" ) AS "cast"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_crew c WHERE p."gnidsId"=c."gnidsId" ) AS "crew"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_country c WHERE p."gnidsId"=c."gnidsId" ) AS "country"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_genre c WHERE p."gnidsId"=c."gnidsId" ) AS "genre"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_rating c WHERE p."gnidsId"=c."gnidsId" ) AS "rating"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_rating_advisory c WHERE p."gnidsId"=c."gnidsId" ) AS "rating_advisory"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_mvinfo c WHERE p."gnidsId"=c."gnidsId" ) AS "mvinfo"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_epinfo c WHERE p."gnidsId"=c."gnidsId" ) AS "epinfo"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_season c WHERE p."gnidsId"=c."gnidsId" ) AS "season"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_season_title c WHERE p."gnidsId"=c."gnidsId" ) AS "season_title"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_season_desc c WHERE p."gnidsId"=c."gnidsId" ) AS "season_desc"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_season_cast c WHERE p."gnidsId"=c."gnidsId" ) AS "season_cast"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_season_crew c WHERE p."gnidsId"=c."gnidsId" ) AS "season_crew"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_season_asset c WHERE p."gnidsId"=c."gnidsId" ) AS "season_asset"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_season_asset_id c WHERE p."gnidsId"=c."gnidsId" ) AS "season_asset_id"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_season_asset_language c WHERE p."gnidsId"=c."gnidsId" ) AS "season_asset_language"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_season_asset_market c WHERE p."gnidsId"=c."gnidsId" ) AS "season_asset_market"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_season_asset_extattr c WHERE p."gnidsId"=c."gnidsId" ) AS "season_asset_extattr"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_season_asset_tag c WHERE p."gnidsId"=c."gnidsId" ) AS "season_asset_tag"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_season_xid c WHERE p."gnidsId"=c."gnidsId" ) AS "season_xid"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_asset c WHERE p."gnidsId"=c."gnidsId" ) AS "asset"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_asset_id c WHERE p."gnidsId"=c."gnidsId" ) AS "asset_id"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_asset_language c WHERE p."gnidsId"=c."gnidsId" ) AS "asset_language"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_asset_market c WHERE p."gnidsId"=c."gnidsId" ) AS "asset_market"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_asset_extattr c WHERE p."gnidsId"=c."gnidsId" ) AS "asset_extattr"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_asset_tag c WHERE p."gnidsId"=c."gnidsId" ) AS "asset_tag"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sourceprogram_xid c WHERE p."gnidsId"=c."gnidsId" ) AS "xid"
FROM sourceprogram p
WHERE "ingestId" > (SELECT * FROM max_ingest_id)
;


-- Populate _md5_entity_popularity table
WITH max_ingest_id AS ( 	SELECT COALESCE( MAX("ingestId"), {1}*( SELECT COALESCE(MIN("ingestId"),0) FROM {0}.popularity ) )	FROM {0}._md5_entity_popularity )
INSERT INTO {0}._md5_entity_popularity ("timestamp","entityId","updateId","updateDate","ingestId","popularity")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp", p."popularityId"::TEXT AS "entityId", p."updateId", p."updateDate", p."ingestId", p."MD5" AS "popularity"
FROM popularity p
WHERE "ingestId" > (SELECT * FROM max_ingest_id)
;


-- Populate _md5_entity_university table
WITH max_ingest_id AS ( 	SELECT COALESCE( MAX("ingestId"), {1}*( SELECT COALESCE(MIN("ingestId"),0) FROM {0}.university ) )	FROM {0}._md5_entity_university )
INSERT INTO {0}._md5_entity_university ("timestamp","entityId","updateId","updateDate","ingestId","university","name","asset")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp", p."universityId"::TEXT AS "entityId", p."updateId", p."updateDate", p."ingestId", p."MD5" AS "university"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.university_name c WHERE p."universityId"=c."universityId" ) AS "name"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.university_asset c WHERE p."universityId"=c."universityId" ) AS "asset"
FROM university p
WHERE "ingestId" > (SELECT * FROM max_ingest_id)
;


-- Populate _md5_entity_venue table
WITH max_ingest_id AS ( 	SELECT COALESCE( MAX("ingestId"), {1}*( SELECT COALESCE(MIN("ingestId"),0) FROM {0}.venue ) )	FROM {0}._md5_entity_venue )
INSERT INTO {0}._md5_entity_venue ("timestamp","entityId","updateId","updateDate","ingestId","venue")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp", p."venueId"::TEXT AS "entityId", p."updateId", p."updateDate", p."ingestId", p."MD5" AS "venue"
FROM venue p
WHERE "ingestId" > (SELECT * FROM max_ingest_id)
;


-- Populate _md5_entity_venuebrand table
WITH max_ingest_id AS ( 	SELECT COALESCE( MAX("ingestId"), {1}*( SELECT COALESCE(MIN("ingestId"),0) FROM {0}.venuebrand ) )	FROM {0}._md5_entity_venuebrand )
INSERT INTO {0}._md5_entity_venuebrand ("timestamp","entityId","updateId","updateDate","ingestId","venuebrand","name")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp", p."venueBrandId"::TEXT AS "entityId", p."updateId", p."updateDate", p."ingestId", p."MD5" AS "venuebrand"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.venuebrand_name c WHERE p."venueBrandId"=c."venueBrandId" ) AS "name"
FROM venuebrand p
WHERE "ingestId" > (SELECT * FROM max_ingest_id)
;


-- Populate _md5_entity_sportsorg table
WITH max_ingest_id AS ( 	SELECT COALESCE( MAX("ingestId"), {1}*( SELECT COALESCE(MIN("ingestId"),0) FROM {0}.sportsorg ) )	FROM {0}._md5_entity_sportsorg )
INSERT INTO {0}._md5_entity_sportsorg ("timestamp","entityId","updateId","updateDate","ingestId","sportsorg","asset","conf","conf_asset","div","teambrand","event")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp", p."organizationId"::TEXT AS "entityId", p."updateId", p."updateDate", p."ingestId", p."MD5" AS "sportsorg"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sportsorg_asset c WHERE p."organizationId"=c."organizationId" ) AS "asset"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sportsorg_conf c WHERE p."organizationId"=c."organizationId" ) AS "conf"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sportsorg_conf_asset c WHERE p."organizationId"=c."organizationId" ) AS "conf_asset"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sportsorg_div c WHERE p."organizationId"=c."organizationId" ) AS "div"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sportsorg_teambrand c WHERE p."organizationId"=c."organizationId" ) AS "teambrand"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.sportsorg_event c WHERE p."organizationId"=c."organizationId" ) AS "event"
FROM sportsorg p
WHERE "ingestId" > (SELECT * FROM max_ingest_id)
;


-- Populate _md5_entity_team table
WITH max_ingest_id AS ( 	SELECT COALESCE( MAX("ingestId"), {1}*( SELECT COALESCE(MIN("ingestId"),0) FROM {0}.team ) )	FROM {0}._md5_entity_team )
INSERT INTO {0}._md5_entity_team ("timestamp","entityId","updateId","updateDate","ingestId","team","genre")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp", p."teamId"::TEXT AS "entityId", p."updateId", p."updateDate", p."ingestId", p."MD5" AS "team"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.team_genre c WHERE p."teamId"=c."teamId" ) AS "genre"
FROM team p
WHERE "ingestId" > (SELECT * FROM max_ingest_id)
;


-- Populate _md5_entity_teambrand table
WITH max_ingest_id AS ( 	SELECT COALESCE( MAX("ingestId"), {1}*( SELECT COALESCE(MIN("ingestId"),0) FROM {0}.teambrand ) )	FROM {0}._md5_entity_teambrand )
INSERT INTO {0}._md5_entity_teambrand ("timestamp","entityId","updateId","updateDate","ingestId","teambrand","name","asset")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp", p."teamBrandId"::TEXT AS "entityId", p."updateId", p."updateDate", p."ingestId", p."MD5" AS "teambrand"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.teambrand_name c WHERE p."teamBrandId"=c."teamBrandId" ) AS "name"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.teambrand_asset c WHERE p."teamBrandId"=c."teamBrandId" ) AS "asset"
FROM teambrand p
WHERE "ingestId" > (SELECT * FROM max_ingest_id)
;


-- Populate _md5_entity_vdannotation table
WITH max_ingest_id AS ( 	SELECT COALESCE( MAX("ingestId"), {1}*( SELECT COALESCE(MIN("ingestId"),0) FROM {0}.vdannotation ) )	FROM {0}._md5_entity_vdannotation )
INSERT INTO {0}._md5_entity_vdannotation ("timestamp","entityId","updateId","updateDate","ingestId","vdannotation","descriptor")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp", p."TMSId"::TEXT AS "entityId", p."updateId", p."updateDate", p."ingestId", p."MD5" AS "vdannotation"
,( SELECT MD5(STRING_AGG(c."MD5", '|' ORDER BY "MD5")) FROM {0}.vdannotation_descriptor c WHERE p."TMSId"=c."TMSId" ) AS "descriptor"
FROM vdannotation p
WHERE "ingestId" > (SELECT * FROM max_ingest_id)
;




-- Create table to keep entity MD5s
CREATE TABLE IF NOT EXISTS {0}._md5_entity (
	 "timestamp" TIMESTAMP
	,"entity" TEXT
	,"entityId" TEXT
	,"updateId" INT8
	,"updateDate" TIMESTAMP
	,"ingestId" INT8
	,"MD5" TEXT
);

CREATE INDEX IF NOT EXISTS "__md5_entity_entityId" ON {0}._md5_entity USING btree ("entityId");
CREATE INDEX IF NOT EXISTS "__md5_entity_ingestId" ON {0}._md5_entity USING btree ("ingestId");


-- Purge old data
DELETE FROM {0}._md5_entity WHERE "timestamp" < CURRENT_DATE-{2};


-- Aggregate and merge MD5s of all entities into a single table (_md5_entity)
WITH max_ingest_id AS (SELECT COALESCE(MAX("ingestId"),0) FROM {0}._md5_entity), entity_md5s AS ( 
	SELECT NULL AS "entity", NULL AS "entityId", NULL AS "updateId", NULL AS "updateDate", NULL AS "ingestId", NULL AS "MD5" WHERE FALSE
	UNION SELECT 'cv' AS "entity", "entityId", "updateId", "updateDate", "ingestId"
		,MD5(CONCAT_WS('|', "cv"
 			,"attribute"
		)) AS "MD5"
	FROM {0}._md5_entity_cv WHERE "ingestId" > (SELECT * FROM max_ingest_id)
	UNION SELECT 'source' AS "entity", "entityId", "updateId", "updateDate", "ingestId"
		,MD5(CONCAT_WS('|', "source"
 			,"country","altname","attribute","edlang","bcastlang","relationship","affiliate","asset","marketid","genre","group","transportid"
		)) AS "MD5"
	FROM {0}._md5_entity_source WHERE "ingestId" > (SELECT * FROM max_ingest_id)
	UNION SELECT 'lineup' AS "entity", "entityId", "updateId", "updateDate", "ingestId"
		,MD5(CONCAT_WS('|', "lineup"
 			,"channel","channel_transport","channel_transport_id","postalcode","market"
		)) AS "MD5"
	FROM {0}._md5_entity_lineup WHERE "ingestId" > (SELECT * FROM max_ingest_id)
	UNION SELECT 'celebrity' AS "entity", "entityId", "updateId", "updateDate", "ingestId"
		,MD5(CONCAT_WS('|', "celebrity"
 			,"name","award","asset","mediography","mediography_credit","participanttype","biography","relationship","relationshipevent","education","milestone","note","quote","highlight","socialmedia","enhancedaward"
		)) AS "MD5"
	FROM {0}._md5_entity_celebrity WHERE "ingestId" > (SELECT * FROM max_ingest_id)
	UNION SELECT 'descriptortaxonomy' AS "entity", "entityId", "updateId", "updateDate", "ingestId"
		,MD5(CONCAT_WS('|', "descriptortaxonomy"
 			,"descriptor"
		)) AS "MD5"
	FROM {0}._md5_entity_descriptortaxonomy WHERE "ingestId" > (SELECT * FROM max_ingest_id)
	UNION SELECT 'descriptor' AS "entity", "entityId", "updateId", "updateDate", "ingestId"
		,MD5(CONCAT_WS('|', "descriptor"
 			
		)) AS "MD5"
	FROM {0}._md5_entity_descriptor WHERE "ingestId" > (SELECT * FROM max_ingest_id)
	UNION SELECT 'season' AS "entity", "entityId", "updateId", "updateDate", "ingestId"
		,MD5(CONCAT_WS('|', "season"
 			,"title","description","cast","crew","asset","asset_id"
		)) AS "MD5"
	FROM {0}._md5_entity_season WHERE "ingestId" > (SELECT * FROM max_ingest_id)
	UNION SELECT 'program' AS "entity", "entityId", "updateId", "updateDate", "ingestId"
		,MD5(CONCAT_WS('|', "program"
 			,"season","title","description","cast","crew","country","award","genre","rating","qualityrating","ratingadvisory","mvinfo","mvtrailer","epinfo","epinfo_alt","spinfo","spteam","spevent","spdata","spdata_event","asset","asset_id","release","release_attribute","release_distributor","relationship","externallink","descriptor","origaudiolang"
		)) AS "MD5"
	FROM {0}._md5_entity_program WHERE "ingestId" > (SELECT * FROM max_ingest_id)
	UNION SELECT 'availability' AS "entity", "entityId", "updateId", "updateDate", "ingestId"
		,MD5(CONCAT_WS('|', "availability"
 			,"id","url","viewingoption","providerdata"
		)) AS "MD5"
	FROM {0}._md5_entity_availability WHERE "ingestId" > (SELECT * FROM max_ingest_id)
	UNION SELECT 'mapping' AS "entity", "entityId", "updateId", "updateDate", "ingestId"
		,MD5(CONCAT_WS('|', "mapping"
 			,"id","link"
		)) AS "MD5"
	FROM {0}._md5_entity_mapping WHERE "ingestId" > (SELECT * FROM max_ingest_id)
	UNION SELECT 'schedule' AS "entity", "entityId", "updateId", "updateDate", "ingestId"
		,MD5(CONCAT_WS('|', "schedule"
 			,"event","event_bcastid","event_right","event_right_param"
		)) AS "MD5"
	FROM {0}._md5_entity_schedule WHERE "ingestId" > (SELECT * FROM max_ingest_id)
	UNION SELECT 'sourceprogram' AS "entity", "entityId", "updateId", "updateDate", "ingestId"
		,MD5(CONCAT_WS('|', "sourceprogram"
 			,"label","versionlabel","catalog","catalog_language","catalog_market","title","description","cast","crew","country","genre","rating","rating_advisory","mvinfo","epinfo","season","season_title","season_desc","season_cast","season_crew","season_asset","season_asset_id","season_asset_language","season_asset_market","season_asset_extattr","season_asset_tag","season_xid","asset","asset_id","asset_language","asset_market","asset_extattr","asset_tag","xid"
		)) AS "MD5"
	FROM {0}._md5_entity_sourceprogram WHERE "ingestId" > (SELECT * FROM max_ingest_id)
	UNION SELECT 'popularity' AS "entity", "entityId", "updateId", "updateDate", "ingestId"
		,MD5(CONCAT_WS('|', "popularity"
 			
		)) AS "MD5"
	FROM {0}._md5_entity_popularity WHERE "ingestId" > (SELECT * FROM max_ingest_id)
	UNION SELECT 'university' AS "entity", "entityId", "updateId", "updateDate", "ingestId"
		,MD5(CONCAT_WS('|', "university"
 			,"name","asset"
		)) AS "MD5"
	FROM {0}._md5_entity_university WHERE "ingestId" > (SELECT * FROM max_ingest_id)
	UNION SELECT 'venue' AS "entity", "entityId", "updateId", "updateDate", "ingestId"
		,MD5(CONCAT_WS('|', "venue"
 			
		)) AS "MD5"
	FROM {0}._md5_entity_venue WHERE "ingestId" > (SELECT * FROM max_ingest_id)
	UNION SELECT 'venuebrand' AS "entity", "entityId", "updateId", "updateDate", "ingestId"
		,MD5(CONCAT_WS('|', "venuebrand"
 			,"name"
		)) AS "MD5"
	FROM {0}._md5_entity_venuebrand WHERE "ingestId" > (SELECT * FROM max_ingest_id)
	UNION SELECT 'sportsorg' AS "entity", "entityId", "updateId", "updateDate", "ingestId"
		,MD5(CONCAT_WS('|', "sportsorg"
 			,"asset","conf","conf_asset","div","teambrand","event"
		)) AS "MD5"
	FROM {0}._md5_entity_sportsorg WHERE "ingestId" > (SELECT * FROM max_ingest_id)
	UNION SELECT 'team' AS "entity", "entityId", "updateId", "updateDate", "ingestId"
		,MD5(CONCAT_WS('|', "team"
 			,"genre"
		)) AS "MD5"
	FROM {0}._md5_entity_team WHERE "ingestId" > (SELECT * FROM max_ingest_id)
	UNION SELECT 'teambrand' AS "entity", "entityId", "updateId", "updateDate", "ingestId"
		,MD5(CONCAT_WS('|', "teambrand"
 			,"name","asset"
		)) AS "MD5"
	FROM {0}._md5_entity_teambrand WHERE "ingestId" > (SELECT * FROM max_ingest_id)
	UNION SELECT 'vdannotation' AS "entity", "entityId", "updateId", "updateDate", "ingestId"
		,MD5(CONCAT_WS('|', "vdannotation"
 			,"descriptor"
		)) AS "MD5"
	FROM {0}._md5_entity_vdannotation WHERE "ingestId" > (SELECT * FROM max_ingest_id)
) 
INSERT INTO {0}._md5_entity ("timestamp","entity","entityId","updateId","updateDate","ingestId","MD5") 
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp" 
	,"entity","entityId","updateId","updateDate","ingestId","MD5" 
FROM entity_md5s; 



-- Create endpoint table to keep endpoint/object MD5s 
CREATE TABLE IF NOT EXISTS {0}._md5_endpoint (
	 "timestamp" TIMESTAMP
	,"endpoint" TEXT
	,"objectId" TEXT
	,"entityIds" TEXT
	,"updateId" INT8
	,"updateDate" TIMESTAMP
	,"ingestId" INT8
	,"MD5" TEXT
);

CREATE INDEX IF NOT EXISTS "__md5_endpoint_objectId" ON {0}._md5_endpoint USING btree ("objectId");
CREATE INDEX IF NOT EXISTS "__md5_endpoint_ingestId" ON {0}._md5_endpoint USING btree ("ingestId");


-- Purge old data
DELETE FROM {0}._md5_endpoint WHERE "timestamp" < CURRENT_DATE-{2};


-- Reconstruct endpoint/object MD5s using entity MD5s and populate endpoint table (_md5_endpoint) 
WITH max_ingest_id AS (SELECT COALESCE(MAX("ingestId"),0) FROM {0}._md5_endpoint) 
,reconstructed_endpoint_md5s AS ( 
	SELECT p.entity, p."entityId", p."updateId", p."updateDate", p."ingestId"
		,p."MD5" AS "parent", MD5(STRING_AGG(c."MD5",'|' ORDER BY c."MD5")) AS "children"
		,CONCAT_WS(':', MIN(c."entity"), ARRAY_AGG(c."entityId" ORDER BY c."entityId")) AS "child_entityIds"
	FROM {0}._md5_entity p
		LEFT JOIN {0}.program_season pc ON p."entityId"=pc."TMSId"::TEXT
		LEFT JOIN {0}._md5_entity c ON pc."seasonTMSId"::TEXT=c."entityId" AND c.entity='season'
			AND c."ingestId" > (SELECT * FROM max_ingest_id)
	WHERE p.entity='program' AND p."ingestId" > (SELECT * FROM max_ingest_id)
	GROUP BY 1,2,3,4,5,6
	UNION
	SELECT p.entity, p."entityId", p."updateId", p."updateDate", p."ingestId"
		,p."MD5" AS "parent", MD5(STRING_AGG(c."MD5",'|' ORDER BY c."MD5")) AS "children"
		,CONCAT_WS(':', MIN(c."entity"), ARRAY_AGG(c."entityId" ORDER BY c."entityId")) AS "child_entityIds"
	FROM {0}._md5_entity p
		LEFT JOIN {0}.descriptortaxonomy_descriptor pc ON p."entityId"=pc."taxonomyId"::TEXT
		LEFT JOIN {0}._md5_entity c ON pc."descriptorId"::TEXT=c."entityId" AND c.entity='descriptor'
			AND c."ingestId" > (SELECT * FROM max_ingest_id)
	WHERE p.entity='descriptortaxonomy' AND p."ingestId" > (SELECT * FROM max_ingest_id)
	GROUP BY 1,2,3,4,5,6
	UNION
	SELECT p.entity, p."entityId", p."updateId", p."updateDate", p."ingestId"
		,p."MD5" AS "parent", MD5(STRING_AGG(c."MD5",'|' ORDER BY c."MD5")) AS "children"
		,CONCAT_WS(':', MIN(c."entity"), ARRAY_AGG(c."entityId" ORDER BY c."entityId")) AS "child_entityIds"
	FROM {0}._md5_entity p
		LEFT JOIN {0}.sportsorg_sportsconf pc ON p."entityId"=pc."organizationId"::TEXT
		LEFT JOIN {0}._md5_entity c ON pc."conferenceId"::TEXT=c."entityId" AND c.entity='sportsconf'
			AND c."ingestId" > (SELECT * FROM max_ingest_id)
	WHERE p.entity='sportsorg' AND p."ingestId" > (SELECT * FROM max_ingest_id)
	GROUP BY 1,2,3,4,5,6
	UNION
	SELECT p.entity, p."entityId", p."updateId", p."updateDate", p."ingestId"
		,p."MD5" AS "parent", MD5(STRING_AGG(c."MD5",'|' ORDER BY c."MD5")) AS "children"
		,CONCAT_WS(':', MIN(c."entity"), ARRAY_AGG(c."entityId" ORDER BY c."entityId")) AS "child_entityIds"
	FROM {0}._md5_entity p
		LEFT JOIN {0}.venuebrand pc ON p."entityId"=pc."venueId"::TEXT
		LEFT JOIN {0}._md5_entity c ON pc."venueBrandId"::TEXT=c."entityId" AND c.entity='venuebrand'
			AND c."ingestId" > (SELECT * FROM max_ingest_id)
	WHERE p.entity='venue' AND p."ingestId" > (SELECT * FROM max_ingest_id)
	GROUP BY 1,2,3,4,5,6
	UNION
	SELECT p.entity, p."entityId", p."updateId", p."updateDate", p."ingestId"
		,p."MD5" AS "parent", MD5(STRING_AGG(c."MD5",'|' ORDER BY c."MD5")) AS "children"
		,CONCAT_WS(':', MIN(c."entity"), ARRAY_AGG(c."entityId" ORDER BY c."entityId")) AS "child_entityIds"
	FROM {0}._md5_entity p
		LEFT JOIN {0}.teambrand pc ON p."entityId"=pc."teamId"::TEXT
		LEFT JOIN {0}._md5_entity c ON pc."teamBrandId"::TEXT=c."entityId" AND c.entity='teambrand'
			AND c."ingestId" > (SELECT * FROM max_ingest_id)
	WHERE p.entity='team' AND p."ingestId" > (SELECT * FROM max_ingest_id)
	GROUP BY 1,2,3,4,5,6
	UNION
	SELECT p.entity, p."entityId", p."updateId", p."updateDate", p."ingestId" 
		,p."MD5" AS "parent", NULL AS "children", NULL AS "child_entityIds" 
	FROM {0}._md5_entity p  
	WHERE p.entity NOT IN ( 'program','season','descriptortaxonomy','descriptor','sportsorg','sportsconf','venue','venuebrand','team','teambrand' ) 
		AND p."ingestId" > (SELECT * FROM max_ingest_id) 
) 
INSERT INTO {0}._md5_endpoint ("timestamp","endpoint","objectId","entityIds","updateId","updateDate","ingestId","MD5") 
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp" 
	,CASE 
		WHEN entity='program' THEN 'Programs'
		WHEN entity='schedule' THEN 'Schedules'
		WHEN entity='source' THEN 'Sources'
		WHEN entity='lineup' THEN 'Lineups'
		WHEN entity='availability' THEN 'ProgramAvailabilities'
		WHEN entity='mapping' THEN 'ProgramMappings'
		WHEN entity='celebrity' THEN 'Celebrities'
		WHEN entity='sportsorg' THEN 'Organizations'
		WHEN entity='team' THEN 'Teams'
		WHEN entity='university' THEN 'Universities'
		WHEN entity='venue' THEN 'Venues'
		WHEN entity='descriptortaxonomy' THEN 'VideoDescriptorsTaxonomy'
		WHEN entity='popularity' THEN 'VideoPopularity'
		WHEN entity='cv' THEN 'ControlledVocabulary'
		ELSE entity 
	END AS "endpoint" 
 	,"entityId" AS "objectId" 
	,CONCAT_WS('|',"entity"||':'||"entityId", CASE WHEN "child_entityIds"='{NULL}' THEN NULL ELSE "child_entityIds" END) AS "entityIds" 
	,"updateId", "updateDate", "ingestId" 
	,MD5(CONCAT_WS('|',"parent","children")) AS "MD5" 
FROM reconstructed_endpoint_md5s 
;

