
-- {0}: core schema

SET SEARCH_PATH TO '{0}';

CREATE TABLE IF NOT EXISTS _stats (
	"timestamp" timestamp without time zone NOT NULL,
	"metric" character varying(255) NOT NULL,
	"dimension" character varying(255),
	"value" real );

CREATE INDEX IF NOT EXISTS "_stats_timestamp" ON {0}._stats USING btree ("timestamp");
CREATE INDEX IF NOT EXISTS "_stats_metric" ON {0}._stats USING btree ("metric");



WITH table_sizes AS (
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
		,table_schema
		,SPLIT_PART(table_name,'_',1) AS entity, table_name
		,pg_total_relation_size('"' || table_schema || '"."' || table_name || '"') AS size
	FROM information_schema.tables
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")

SELECT "timestamp", 'db_size{entity}' AS "metric", entity AS "dimension", SUM(size) AS "value"
FROM table_sizes
WHERE table_schema IN ('{0}') AND "entity" != ''
GROUP BY 1,2,3

UNION SELECT "timestamp", 'db_size{entity}' AS "metric", 'stats' AS "dimension", SUM(size) AS "value"
FROM table_sizes
WHERE table_schema IN ('{0}') AND "entity" = ''
GROUP BY 1,2,3

UNION SELECT "timestamp", 'db_size{entity}' AS "metric", 'all' AS "dimension", SUM(size) AS "value"
FROM table_sizes
WHERE table_schema IN ('{0}')
GROUP BY 1,2,3

;
	
-- ingest_id stats for program
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT 
	TO_TIMESTAMP( "ingestId"::VARCHAR(14), 'YYYYMMDDHH24MISS' ) AS "timestamp"
    ,'program_ingests' AS metric
    ,NULL AS "dimension"
    ,COUNT("TMSId") AS value
FROM program
WHERE TO_TIMESTAMP( "ingestId"::VARCHAR(14), 'YYYYMMDDHH24MISS' ) 
	> (SELECT COALESCE(MAX("timestamp"),'1970-01-01') FROM _stats WHERE metric = 'program_ingests')
GROUP BY 1,2,3 ORDER BY 1 DESC
;
		
-- ingest_id stats for schedule
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT 
	TO_TIMESTAMP( "ingestId"::VARCHAR(14), 'YYYYMMDDHH24MISS' ) AS "timestamp"
    ,'schedule_ingests' AS metric
    ,NULL AS "dimension"
    ,COUNT("scheduleId") AS value
FROM schedule
WHERE TO_TIMESTAMP( "ingestId"::VARCHAR(14), 'YYYYMMDDHH24MISS' ) 
	> (SELECT COALESCE(MAX("timestamp"),'1970-01-01') FROM _stats WHERE metric = 'schedule_ingests')
GROUP BY 1,2,3 ORDER BY 1 DESC
;
		
-- ingest_id stats for source
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT 
	TO_TIMESTAMP( "ingestId"::VARCHAR(14), 'YYYYMMDDHH24MISS' ) AS "timestamp"
    ,'source_ingests' AS metric
    ,NULL AS "dimension"
    ,COUNT("prgSvcId") AS value
FROM source
WHERE TO_TIMESTAMP( "ingestId"::VARCHAR(14), 'YYYYMMDDHH24MISS' ) 
	> (SELECT COALESCE(MAX("timestamp"),'1970-01-01') FROM _stats WHERE metric = 'source_ingests')
GROUP BY 1,2,3 ORDER BY 1 DESC
;
		
-- ingest_id stats for celebrity
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT 
	TO_TIMESTAMP( "ingestId"::VARCHAR(14), 'YYYYMMDDHH24MISS' ) AS "timestamp"
    ,'celebrity_ingests' AS metric
    ,NULL AS "dimension"
    ,COUNT("personId") AS value
FROM celebrity
WHERE TO_TIMESTAMP( "ingestId"::VARCHAR(14), 'YYYYMMDDHH24MISS' ) 
	> (SELECT COALESCE(MAX("timestamp"),'1970-01-01') FROM _stats WHERE metric = 'celebrity_ingests')
GROUP BY 1,2,3 ORDER BY 1 DESC
;
		
-- ingest_id stats for lineup
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT 
	TO_TIMESTAMP( "ingestId"::VARCHAR(14), 'YYYYMMDDHH24MISS' ) AS "timestamp"
    ,'lineup_ingests' AS metric
    ,NULL AS "dimension"
    ,COUNT("lineupId") AS value
FROM lineup
WHERE TO_TIMESTAMP( "ingestId"::VARCHAR(14), 'YYYYMMDDHH24MISS' ) 
	> (SELECT COALESCE(MAX("timestamp"),'1970-01-01') FROM _stats WHERE metric = 'lineup_ingests')
GROUP BY 1,2,3 ORDER BY 1 DESC
;
		
-- ingest_id stats for availability
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT 
	TO_TIMESTAMP( "ingestId"::VARCHAR(14), 'YYYYMMDDHH24MISS' ) AS "timestamp"
    ,'availability{catalogName}_ingests' AS metric
    ,"catalogName" AS "dimension"
    ,COUNT("availabilityId") AS value
FROM availability
WHERE TO_TIMESTAMP( "ingestId"::VARCHAR(14), 'YYYYMMDDHH24MISS' ) 
	> (SELECT COALESCE(MAX("timestamp"),'1970-01-01') FROM _stats WHERE metric = 'availability{catalogName}_ingests')
GROUP BY 1,2,3 ORDER BY 1 DESC
;
		
-- ingest_id stats for mapping
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT 
	TO_TIMESTAMP( "ingestId"::VARCHAR(14), 'YYYYMMDDHH24MISS' ) AS "timestamp"
    ,'mapping{catalogName}_ingests' AS metric
    ,"catalogName" AS "dimension"
    ,COUNT("mappingId") AS value
FROM mapping
WHERE TO_TIMESTAMP( "ingestId"::VARCHAR(14), 'YYYYMMDDHH24MISS' ) 
	> (SELECT COALESCE(MAX("timestamp"),'1970-01-01') FROM _stats WHERE metric = 'mapping{catalogName}_ingests')
GROUP BY 1,2,3 ORDER BY 1 DESC
;
		
-- ingest_id stats for descriptortaxonomy
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT 
	TO_TIMESTAMP( "ingestId"::VARCHAR(14), 'YYYYMMDDHH24MISS' ) AS "timestamp"
    ,'descriptortaxonomy_ingests' AS metric
    ,NULL AS "dimension"
    ,COUNT("taxonomyId") AS value
FROM descriptortaxonomy
WHERE TO_TIMESTAMP( "ingestId"::VARCHAR(14), 'YYYYMMDDHH24MISS' ) 
	> (SELECT COALESCE(MAX("timestamp"),'1970-01-01') FROM _stats WHERE metric = 'descriptortaxonomy_ingests')
GROUP BY 1,2,3 ORDER BY 1 DESC
;
		
-- ingest_id stats for descriptor
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT 
	TO_TIMESTAMP( "ingestId"::VARCHAR(14), 'YYYYMMDDHH24MISS' ) AS "timestamp"
    ,'descriptor_ingests' AS metric
    ,NULL AS "dimension"
    ,COUNT("descriptorId") AS value
FROM descriptor
WHERE TO_TIMESTAMP( "ingestId"::VARCHAR(14), 'YYYYMMDDHH24MISS' ) 
	> (SELECT COALESCE(MAX("timestamp"),'1970-01-01') FROM _stats WHERE metric = 'descriptor_ingests')
GROUP BY 1,2,3 ORDER BY 1 DESC
;
		
-- ingest_id stats for popularity
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT 
	TO_TIMESTAMP( "ingestId"::VARCHAR(14), 'YYYYMMDDHH24MISS' ) AS "timestamp"
    ,'popularity_ingests' AS metric
    ,NULL AS "dimension"
    ,COUNT("popularityId") AS value
FROM popularity
WHERE TO_TIMESTAMP( "ingestId"::VARCHAR(14), 'YYYYMMDDHH24MISS' ) 
	> (SELECT COALESCE(MAX("timestamp"),'1970-01-01') FROM _stats WHERE metric = 'popularity_ingests')
GROUP BY 1,2,3 ORDER BY 1 DESC
;
		
-- ingest_id stats for sportsorg
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT 
	TO_TIMESTAMP( "ingestId"::VARCHAR(14), 'YYYYMMDDHH24MISS' ) AS "timestamp"
    ,'sportsorg_ingests' AS metric
    ,NULL AS "dimension"
    ,COUNT("organizationId") AS value
FROM sportsorg
WHERE TO_TIMESTAMP( "ingestId"::VARCHAR(14), 'YYYYMMDDHH24MISS' ) 
	> (SELECT COALESCE(MAX("timestamp"),'1970-01-01') FROM _stats WHERE metric = 'sportsorg_ingests')
GROUP BY 1,2,3 ORDER BY 1 DESC
;
		
-- ingest_id stats for team
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT 
	TO_TIMESTAMP( "ingestId"::VARCHAR(14), 'YYYYMMDDHH24MISS' ) AS "timestamp"
    ,'team_ingests' AS metric
    ,NULL AS "dimension"
    ,COUNT("teamId") AS value
FROM team
WHERE TO_TIMESTAMP( "ingestId"::VARCHAR(14), 'YYYYMMDDHH24MISS' ) 
	> (SELECT COALESCE(MAX("timestamp"),'1970-01-01') FROM _stats WHERE metric = 'team_ingests')
GROUP BY 1,2,3 ORDER BY 1 DESC
;
		
-- ingest_id stats for venue
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT 
	TO_TIMESTAMP( "ingestId"::VARCHAR(14), 'YYYYMMDDHH24MISS' ) AS "timestamp"
    ,'venue_ingests' AS metric
    ,NULL AS "dimension"
    ,COUNT("venueId") AS value
FROM venue
WHERE TO_TIMESTAMP( "ingestId"::VARCHAR(14), 'YYYYMMDDHH24MISS' ) 
	> (SELECT COALESCE(MAX("timestamp"),'1970-01-01') FROM _stats WHERE metric = 'venue_ingests')
GROUP BY 1,2,3 ORDER BY 1 DESC
;
		
-- ingest_id stats for university
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT 
	TO_TIMESTAMP( "ingestId"::VARCHAR(14), 'YYYYMMDDHH24MISS' ) AS "timestamp"
    ,'university_ingests' AS metric
    ,NULL AS "dimension"
    ,COUNT("universityId") AS value
FROM university
WHERE TO_TIMESTAMP( "ingestId"::VARCHAR(14), 'YYYYMMDDHH24MISS' ) 
	> (SELECT COALESCE(MAX("timestamp"),'1970-01-01') FROM _stats WHERE metric = 'university_ingests')
GROUP BY 1,2,3 ORDER BY 1 DESC
;
		
-- update_date stats for program
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT 
	TO_TIMESTAMP(
		CEILING(
			EXTRACT(EPOCH FROM "updateDate") / 900 
		) * 900)::TIMESTAMP AS "timestamp"	
    ,'program_updates' AS metric
    ,NULL AS "dimension"    
    ,COUNT("TMSId") AS value
FROM program
WHERE "updateDate" > (SELECT COALESCE(MAX("timestamp"),'1970-01-01') FROM _stats WHERE metric = 'program_updates')
GROUP BY 1,2,3 ORDER BY 1 DESC
;
		
-- update_date stats for schedule
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT 
	TO_TIMESTAMP(
		CEILING(
			EXTRACT(EPOCH FROM "updateDate") / 900 
		) * 900)::TIMESTAMP AS "timestamp"	
    ,'schedule_updates' AS metric
    ,NULL AS "dimension"    
    ,COUNT("scheduleId") AS value
FROM schedule
WHERE "updateDate" > (SELECT COALESCE(MAX("timestamp"),'1970-01-01') FROM _stats WHERE metric = 'schedule_updates')
GROUP BY 1,2,3 ORDER BY 1 DESC
;
		
-- update_date stats for source
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT 
	TO_TIMESTAMP(
		CEILING(
			EXTRACT(EPOCH FROM "updateDate") / 900 
		) * 900)::TIMESTAMP AS "timestamp"	
    ,'source_updates' AS metric
    ,NULL AS "dimension"    
    ,COUNT("prgSvcId") AS value
FROM source
WHERE "updateDate" > (SELECT COALESCE(MAX("timestamp"),'1970-01-01') FROM _stats WHERE metric = 'source_updates')
GROUP BY 1,2,3 ORDER BY 1 DESC
;
		
-- update_date stats for celebrity
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT 
	TO_TIMESTAMP(
		CEILING(
			EXTRACT(EPOCH FROM "updateDate") / 900 
		) * 900)::TIMESTAMP AS "timestamp"	
    ,'celebrity_updates' AS metric
    ,NULL AS "dimension"    
    ,COUNT("personId") AS value
FROM celebrity
WHERE "updateDate" > (SELECT COALESCE(MAX("timestamp"),'1970-01-01') FROM _stats WHERE metric = 'celebrity_updates')
GROUP BY 1,2,3 ORDER BY 1 DESC
;
		
-- update_date stats for lineup
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT 
	TO_TIMESTAMP(
		CEILING(
			EXTRACT(EPOCH FROM "updateDate") / 900 
		) * 900)::TIMESTAMP AS "timestamp"	
    ,'lineup_updates' AS metric
    ,NULL AS "dimension"    
    ,COUNT("lineupId") AS value
FROM lineup
WHERE "updateDate" > (SELECT COALESCE(MAX("timestamp"),'1970-01-01') FROM _stats WHERE metric = 'lineup_updates')
GROUP BY 1,2,3 ORDER BY 1 DESC
;
		
-- update_date stats for availability
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT 
	TO_TIMESTAMP(
		CEILING(
			EXTRACT(EPOCH FROM "updateDate") / 900 
		) * 900)::TIMESTAMP AS "timestamp"	
    ,'availability{catalogName}_updates' AS metric
    ,"catalogName" AS "dimension"    
    ,COUNT("availabilityId") AS value
FROM availability
WHERE "updateDate" > (SELECT COALESCE(MAX("timestamp"),'1970-01-01') FROM _stats WHERE metric = 'availability{catalogName}_updates')
GROUP BY 1,2,3 ORDER BY 1 DESC
;
		
-- update_date stats for mapping
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT 
	TO_TIMESTAMP(
		CEILING(
			EXTRACT(EPOCH FROM "updateDate") / 900 
		) * 900)::TIMESTAMP AS "timestamp"	
    ,'mapping{catalogName}_updates' AS metric
    ,"catalogName" AS "dimension"    
    ,COUNT("mappingId") AS value
FROM mapping
WHERE "updateDate" > (SELECT COALESCE(MAX("timestamp"),'1970-01-01') FROM _stats WHERE metric = 'mapping{catalogName}_updates')
GROUP BY 1,2,3 ORDER BY 1 DESC
;
		
-- update_date stats for descriptortaxonomy
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT 
	TO_TIMESTAMP(
		CEILING(
			EXTRACT(EPOCH FROM "updateDate") / 900 
		) * 900)::TIMESTAMP AS "timestamp"	
    ,'descriptortaxonomy_updates' AS metric
    ,NULL AS "dimension"    
    ,COUNT("taxonomyId") AS value
FROM descriptortaxonomy
WHERE "updateDate" > (SELECT COALESCE(MAX("timestamp"),'1970-01-01') FROM _stats WHERE metric = 'descriptortaxonomy_updates')
GROUP BY 1,2,3 ORDER BY 1 DESC
;
		
-- update_date stats for descriptor
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT 
	TO_TIMESTAMP(
		CEILING(
			EXTRACT(EPOCH FROM "updateDate") / 900 
		) * 900)::TIMESTAMP AS "timestamp"	
    ,'descriptor_updates' AS metric
    ,NULL AS "dimension"    
    ,COUNT("descriptorId") AS value
FROM descriptor
WHERE "updateDate" > (SELECT COALESCE(MAX("timestamp"),'1970-01-01') FROM _stats WHERE metric = 'descriptor_updates')
GROUP BY 1,2,3 ORDER BY 1 DESC
;
		
-- update_date stats for popularity
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT 
	TO_TIMESTAMP(
		CEILING(
			EXTRACT(EPOCH FROM "updateDate") / 900 
		) * 900)::TIMESTAMP AS "timestamp"	
    ,'popularity_updates' AS metric
    ,NULL AS "dimension"    
    ,COUNT("popularityId") AS value
FROM popularity
WHERE "updateDate" > (SELECT COALESCE(MAX("timestamp"),'1970-01-01') FROM _stats WHERE metric = 'popularity_updates')
GROUP BY 1,2,3 ORDER BY 1 DESC
;
		
-- update_date stats for sportsorg
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT 
	TO_TIMESTAMP(
		CEILING(
			EXTRACT(EPOCH FROM "updateDate") / 900 
		) * 900)::TIMESTAMP AS "timestamp"	
    ,'sportsorg_updates' AS metric
    ,NULL AS "dimension"    
    ,COUNT("organizationId") AS value
FROM sportsorg
WHERE "updateDate" > (SELECT COALESCE(MAX("timestamp"),'1970-01-01') FROM _stats WHERE metric = 'sportsorg_updates')
GROUP BY 1,2,3 ORDER BY 1 DESC
;
		
-- update_date stats for team
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT 
	TO_TIMESTAMP(
		CEILING(
			EXTRACT(EPOCH FROM "updateDate") / 900 
		) * 900)::TIMESTAMP AS "timestamp"	
    ,'team_updates' AS metric
    ,NULL AS "dimension"    
    ,COUNT("teamId") AS value
FROM team
WHERE "updateDate" > (SELECT COALESCE(MAX("timestamp"),'1970-01-01') FROM _stats WHERE metric = 'team_updates')
GROUP BY 1,2,3 ORDER BY 1 DESC
;
		
-- update_date stats for venue
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT 
	TO_TIMESTAMP(
		CEILING(
			EXTRACT(EPOCH FROM "updateDate") / 900 
		) * 900)::TIMESTAMP AS "timestamp"	
    ,'venue_updates' AS metric
    ,NULL AS "dimension"    
    ,COUNT("venueId") AS value
FROM venue
WHERE "updateDate" > (SELECT COALESCE(MAX("timestamp"),'1970-01-01') FROM _stats WHERE metric = 'venue_updates')
GROUP BY 1,2,3 ORDER BY 1 DESC
;
		
-- update_date stats for university
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT 
	TO_TIMESTAMP(
		CEILING(
			EXTRACT(EPOCH FROM "updateDate") / 900 
		) * 900)::TIMESTAMP AS "timestamp"	
    ,'university_updates' AS metric
    ,NULL AS "dimension"    
    ,COUNT("universityId") AS value
FROM university
WHERE "updateDate" > (SELECT COALESCE(MAX("timestamp"),'1970-01-01') FROM _stats WHERE metric = 'university_updates')
GROUP BY 1,2,3 ORDER BY 1 DESC
;
		
-- program counts with status
WITH raw_counts AS (
	
	SELECT 
		p."deleted", p."inactive"
		,'programs{STATUS}' AS "metric"
		,NULL AS "dimension"
		,COUNT(p."TMSId") AS "count"
	FROM program p
	GROUP BY 1,2,3,4
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted'),('inactive')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS") AS "dimension" 
	FROM dim_status 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','inactive',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "inactive"=1 AND "deleted" IS NULL  GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "inactive" IS NULL AND "deleted" IS NULL   GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'programs{STATUS}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- program counts with status by desc language
WITH raw_counts AS (
	
	SELECT 
		p."deleted", p."inactive", p."desc_lang"
		,'programs{STATUS|desc_lang}' AS "metric"
		,p."desc_lang" AS "dimension"
		,COUNT(p."TMSId") AS "count"
	FROM program p
	GROUP BY 1,2,3,4,5
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted'),('inactive')),
dim_desc_lang AS (SELECT DISTINCT "desc_lang" AS "desc_lang" FROM raw_counts),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS","desc_lang") AS "dimension" 
	FROM dim_status CROSS JOIN dim_desc_lang 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','inactive',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "inactive"=1 AND "deleted" IS NULL  GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "inactive" IS NULL AND "deleted" IS NULL   GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'programs{STATUS|desc_lang}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- active program counts by progType
WITH raw_counts AS (
	
	SELECT 
		'programs[active]{progType}' AS "metric"
		,p."progType" AS "dimension"
		,COUNT(p."TMSId") AS "count"
	FROM program p
	WHERE p."deleted" IS NULL AND p."inactive" IS NULL
	GROUP BY 1,2
	
),
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- active program counts by progType/subType
WITH raw_counts AS (
	
	SELECT 
		'programs[active]{progType|subType}' AS "metric"
		,CONCAT_WS('|',p."progType",p."subType") AS "dimension"
		,COUNT(p."TMSId") AS "count"
	FROM program p
	WHERE p."deleted" IS NULL AND p."inactive" IS NULL
	GROUP BY 1,2
	
),
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- episode series with status
WITH raw_counts AS (
	
	SELECT 
		CASE WHEN p."TMSId" IS NULL THEN 1 ELSE NULL END AS "is_null", p."deleted", p."inactive"
		,'episode[active]_parentseries{STATUS}' AS "metric"
		,NULL AS "dimension"
		,COUNT(DISTINCT p."TMSId") AS "count"
	FROM program ep
		LEFT JOIN program p ON ep."connectorId"=p."TMSId"
	WHERE ep."deleted" IS NULL AND ep."inactive" IS NULL
	GROUP BY 1,2,3,4,5
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted'),('inactive'),('missing')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS") AS "dimension" 
	FROM dim_status 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','missing',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "is_null"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','inactive',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "inactive"=1 AND "deleted" IS NULL  GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "inactive" IS NULL AND "deleted" IS NULL  AND "is_null" IS NULL GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'episode[active]_parentseries{STATUS}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- episode seasons with status
WITH raw_counts AS (
	
	SELECT 
		CASE WHEN s."seasonTMSId" IS NULL THEN 1 ELSE NULL END AS "is_null", s."deleted", s."inactive"
		,'episode[active]_parentseasons{STATUS}' AS "metric"
		,NULL AS "dimension"
		,COUNT(DISTINCT s."seasonTMSId") AS "count"
	FROM program ep
		LEFT JOIN season s ON s."seasonTMSId"=ep."seasonId"||'-'||ep."connectorId"
	WHERE ep."deleted" IS NULL AND ep."inactive" IS NULL 
		AND ep."seasonId" IS NOT NULL
	GROUP BY 1,2,3,4,5
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted'),('inactive'),('missing')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS") AS "dimension" 
	FROM dim_status 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','missing',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "is_null"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','inactive',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "inactive"=1 AND "deleted" IS NULL  GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "inactive" IS NULL AND "deleted" IS NULL  AND "is_null" IS NULL GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'episode[active]_parentseasons{STATUS}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- availabiities by catalog
WITH raw_counts AS (
	
	SELECT 
		'availabilities{catalogName}' AS "metric"
		,a."catalogName" AS "dimension"
		,COUNT(a."availabilityId") AS "count"
	FROM availability a
	GROUP BY 1,2
	
),
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- availabiities with status by catalog
WITH raw_counts AS (
	
	SELECT 
		a."deleted", a."catalogName"
		,'availabilities{STATUS|catalogName}' AS "metric"
		,a."catalogName" AS "dimension"
		,COUNT(a."availabilityId") AS "count"
	FROM availability a
	GROUP BY 1,2,3
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted')),
dim_catalogname AS (SELECT DISTINCT "catalogName" AS "catalogName" FROM raw_counts),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS","catalogName") AS "dimension" 
	FROM dim_status CROSS JOIN dim_catalogname 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE 1=1 AND "deleted" IS NULL   GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'availabilities{STATUS|catalogName}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- active availabiities with status by catalog/license
WITH raw_counts AS (
	
	SELECT 
		'availabilities[active]{catalogName|license}' AS "metric"
		,CONCAT_WS('|',a."catalogName",av."license") AS "dimension"
		,COUNT(a."availabilityId") AS "count"
	FROM availability a
		JOIN availability_viewingoption av ON a."availabilityId"=av."availabilityId"
	WHERE a."deleted" IS NULL
	GROUP BY 1,2
	
),
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- active availabiities with status by catalog/urltype
WITH raw_counts AS (
	
	SELECT 
		'availabilities[active]{catalogName|urltype}' AS "metric"
		,CONCAT_WS('|',a."catalogName",au."type") AS "dimension"
		,COUNT(a."availabilityId") AS "count"
	FROM availability a
		JOIN availability_url au ON a."availabilityId"=au."availabilityId"
	WHERE a."deleted" IS NULL
	GROUP BY 1,2
	
),
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- active availabiities with status by catalog/providerdata
WITH raw_counts AS (
	
	SELECT 
		'availabilities[active]{catalogName|providerdata}' AS "metric"
		,CONCAT_WS('|',a."catalogName",ap."key") AS "dimension"
		,COUNT(a."availabilityId") AS "count"
	FROM availability a
		JOIN availability_providerdata ap ON a."availabilityId"=ap."availabilityId"
	WHERE a."deleted" IS NULL
	GROUP BY 1,2
	
),
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- active availabilities by catalog/window
WITH raw_counts AS (
	
	SELECT
		CASE
			WHEN (a."availableFrom" IS NULL OR a."expiresAt" IS NULL) THEN 'undef'
			WHEN (CURRENT_DATE BETWEEN a."availableFrom" AND a."expiresAt") THEN 'in'
			WHEN (CURRENT_DATE > a."expiresAt") THEN 'expired'
			WHEN (CURRENT_DATE < a."availableFrom") THEN 'future'		
		END AS "window"
		,a."catalogName"
		,'availabilities[active]{catalogName|window}' AS "metric"
		,COUNT(a."availabilityId") AS "count"
	FROM availability a
	WHERE a."deleted" IS NULL
	GROUP BY 1,2,3
	
),
dim_catalogname AS (SELECT DISTINCT "dimension" AS "catalogName" FROM _stats WHERE metric='availabilities{catalogName}'),
dim_window("window") AS (VALUES ('undef'),('in'),('expired'),('future')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"catalogName","window") AS "dimension" 
	FROM dim_catalogname CROSS JOIN dim_window 
), 
counts AS (
	SELECT "metric", CONCAT_WS('|',"catalogName","window") AS "dimension", "count" AS "value" FROM raw_counts
),
counts_with_zeros AS (
	SELECT 'availabilities[active]{catalogName|window}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- active availabilities by catalog - windowsize:1wk
WITH raw_counts AS (
	
	SELECT 
		'availabilities[active]{catalogName|windowSize}' AS "metric"
		,CONCAT_WS('|',a."catalogName",'1wk') AS "dimension"
		,COUNT(a."availabilityId") AS "count"
	FROM availability a
	WHERE a."deleted" IS NULL
		AND a."expiresAt" IS NOT NULL
		AND a."availableFrom" IS NOT NULL
		AND a."expiresAt" <= (a."availableFrom" +'7day'::INTERVAL)
	GROUP BY 1,2
		
),
dim_catalogname AS (SELECT DISTINCT "dimension" AS "catalogName" FROM _stats WHERE metric='availabilities{catalogName}'),
dim_windowsize("windowSize") AS (VALUES ('1wk')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"catalogName","windowSize") AS "dimension" 
	FROM dim_catalogname CROSS JOIN dim_windowsize 
), 
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
),
counts_with_zeros AS (
	SELECT 'availabilities[active]{catalogName|windowSize}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- active availabilities by catalog - windowsize:1mo
WITH raw_counts AS (
	
	SELECT 
		'availabilities[active]{catalogName|windowSize}' AS "metric"
		,CONCAT_WS('|',a."catalogName",'1mo') AS "dimension"
		,COUNT(a."availabilityId") AS "count"
	FROM availability a
	WHERE a."deleted" IS NULL
		AND a."expiresAt" IS NOT NULL
		AND a."availableFrom" IS NOT NULL
		AND a."expiresAt" > (a."availableFrom" +'7day'::INTERVAL) AND a."expiresAt" <= (a."availableFrom" +'1month'::INTERVAL)
	GROUP BY 1,2
		
),
dim_catalogname AS (SELECT DISTINCT "dimension" AS "catalogName" FROM _stats WHERE metric='availabilities{catalogName}'),
dim_windowsize("windowSize") AS (VALUES ('1mo')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"catalogName","windowSize") AS "dimension" 
	FROM dim_catalogname CROSS JOIN dim_windowsize 
), 
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
),
counts_with_zeros AS (
	SELECT 'availabilities[active]{catalogName|windowSize}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- active availabilities by catalog - windowsize:1yr
WITH raw_counts AS (
	
	SELECT 
		'availabilities[active]{catalogName|windowSize}' AS "metric"
		,CONCAT_WS('|',a."catalogName",'1yr') AS "dimension"
		,COUNT(a."availabilityId") AS "count"
	FROM availability a
	WHERE a."deleted" IS NULL
		AND a."expiresAt" IS NOT NULL
		AND a."availableFrom" IS NOT NULL
		AND a."expiresAt" > (a."availableFrom" +'1month'::INTERVAL) AND a."expiresAt" <= (a."availableFrom" +'1year'::INTERVAL)
	GROUP BY 1,2
		
),
dim_catalogname AS (SELECT DISTINCT "dimension" AS "catalogName" FROM _stats WHERE metric='availabilities{catalogName}'),
dim_windowsize("windowSize") AS (VALUES ('1yr')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"catalogName","windowSize") AS "dimension" 
	FROM dim_catalogname CROSS JOIN dim_windowsize 
), 
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
),
counts_with_zeros AS (
	SELECT 'availabilities[active]{catalogName|windowSize}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- active availabilities by catalog - windowsize:longterm
WITH raw_counts AS (
	
	SELECT 
		'availabilities[active]{catalogName|windowSize}' AS "metric"
		,CONCAT_WS('|',a."catalogName",'longterm') AS "dimension"
		,COUNT(a."availabilityId") AS "count"
	FROM availability a
	WHERE a."deleted" IS NULL
		AND a."expiresAt" IS NOT NULL
		AND a."availableFrom" IS NOT NULL
		AND a."expiresAt" > (a."availableFrom" +'1year'::INTERVAL)
	GROUP BY 1,2
		
),
dim_catalogname AS (SELECT DISTINCT "dimension" AS "catalogName" FROM _stats WHERE metric='availabilities{catalogName}'),
dim_windowsize("windowSize") AS (VALUES ('longterm')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"catalogName","windowSize") AS "dimension" 
	FROM dim_catalogname CROSS JOIN dim_windowsize 
), 
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
),
counts_with_zeros AS (
	SELECT 'availabilities[active]{catalogName|windowSize}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- availabiity programs with status
WITH raw_counts AS (
	
	SELECT 
		CASE WHEN p."TMSId" IS NULL THEN 1 ELSE NULL END AS "is_null", p."deleted", p."inactive"
		,'availability[active]_programs{STATUS}' AS "metric"
		,NULL AS "dimension"
		,COUNT(DISTINCT ai."id") AS "count"
	FROM availability a
		JOIN availability_id ai ON a."availabilityId"=ai."availabilityId"
		LEFT JOIN program p ON ai."id"=p."TMSId"
	WHERE a."deleted" IS NULL 
		AND ai."type"='tmsId'
	GROUP BY 1,2,3,4,5
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted'),('inactive'),('missing')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS") AS "dimension" 
	FROM dim_status 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','missing',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "is_null"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','inactive',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "inactive"=1 AND "deleted" IS NULL  GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "inactive" IS NULL AND "deleted" IS NULL  AND "is_null" IS NULL GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'availability[active]_programs{STATUS}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- availability sources with status
WITH raw_counts AS (
	
	SELECT 
		CASE WHEN s."prgSvcId" IS NULL THEN 1 ELSE NULL END AS "is_null", s."deleted", s."inactive"
		,'availability[active]_sources{STATUS}' AS "metric"
		,NULL AS "dimension"
		,COUNT(DISTINCT ai."id") AS "count"
	FROM availability a
		JOIN availability_id ai ON a."availabilityId"=ai."availabilityId"
		LEFT JOIN source s ON ai."id"::INTEGER=s."prgSvcId"
	WHERE a."deleted" IS NULL 
		AND ai."type"='prgSvcId'
	GROUP BY 1,2,3,4,5
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted'),('inactive'),('missing')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS") AS "dimension" 
	FROM dim_status 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','missing',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "is_null"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','inactive',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "inactive"=1 AND "deleted" IS NULL  GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "inactive" IS NULL AND "deleted" IS NULL  AND "is_null" IS NULL GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'availability[active]_sources{STATUS}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- active availabiity programs by catalog
WITH raw_counts AS (
	
	SELECT 
		'availability[active]_programs{catalogName}' AS "metric"
		,a."catalogName" AS "dimension"
		,COUNT(DISTINCT ai.id) AS "count"
	FROM availability a
		JOIN availability_id ai ON a."availabilityId"=ai."availabilityId"
	WHERE a."deleted" IS NULL
		AND ai."type"='tmsId'
	GROUP BY 1,2
	
),
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- mappings by catalog
WITH raw_counts AS (
	
	SELECT 
		'mappings{catalogName}' AS "metric"
		,m."catalogName" AS "dimension"
		,COUNT(m."mappingId") AS "count"
	FROM mapping m
	GROUP BY 1,2
	
),
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- mappings with status by catalog
WITH raw_counts AS (
	
	SELECT 
		m."deleted", m."catalogName"
		,'mappings{STATUS|catalogName}' AS "metric"
		,m."catalogName" AS "dimension"
		,COUNT(m."mappingId") AS "count"
	FROM mapping m
	GROUP BY 1,2,3
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted')),
dim_catalogname AS (SELECT DISTINCT "catalogName" AS "catalogName" FROM raw_counts),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS","catalogName") AS "dimension" 
	FROM dim_status CROSS JOIN dim_catalogname 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE 1=1 AND "deleted" IS NULL   GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'mappings{STATUS|catalogName}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- active mappings by catalog/mapping status
WITH raw_counts AS (
	
	SELECT 
		 m."catalogName", m."status"
		,'mappings[active]{catalogName|status}' AS "metric"
		,CONCAT_WS('|',m."catalogName",m."status") AS "dimension"
		,COUNT(m."mappingId") AS "count"
	FROM mapping m
	WHERE m."deleted" IS NULL
	GROUP BY 1,2
	
),
dim_catalogname AS (SELECT DISTINCT "catalogName" AS "catalogName" FROM raw_counts),
dim_status AS (SELECT DISTINCT "status" AS "status" FROM raw_counts),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"catalogName","status") AS "dimension" 
	FROM dim_catalogname CROSS JOIN dim_status 
), 
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
),
counts_with_zeros AS (
	SELECT 'mappings[active]{catalogName|status}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- active/Mapped mappings by catalog/window
WITH raw_counts AS (
	
	SELECT
		CASE
			WHEN (m."avail_start" IS NULL OR m."avail_end" IS NULL) THEN 'undef'
			WHEN (CURRENT_DATE BETWEEN m."avail_start" AND m."avail_end") THEN 'in'
			WHEN (CURRENT_DATE > m."avail_end") THEN 'expired'
			WHEN (CURRENT_DATE < m."avail_start") THEN 'future'		
		END AS "window"
		,m."catalogName"
		,'mappings[active,Mapped]{catalogName|window}' AS "metric"
		,COUNT(m."mappingId") AS "count"
	FROM mapping m
	WHERE m."deleted" IS NULL 
		AND m."status"='Mapped'
	GROUP BY 1,2,3
	
),
dim_catalogname AS (SELECT DISTINCT "dimension" AS "catalogName" FROM _stats WHERE metric='mappings{catalogName}'),
dim_window("window") AS (VALUES ('undef'),('in'),('expired'),('future')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"catalogName","window") AS "dimension" 
	FROM dim_catalogname CROSS JOIN dim_window 
), 
counts AS (
	SELECT "metric", CONCAT_WS('|',"catalogName","window") AS "dimension", "count" AS "value" FROM raw_counts
),
counts_with_zeros AS (
	SELECT 'mappings[active,Mapped]{catalogName|window}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- active/ToBeMapped mappings by catalog/window
WITH raw_counts AS (
	
	SELECT
		CASE
			WHEN (m."avail_start" IS NULL OR m."avail_end" IS NULL) THEN 'undef'
			WHEN (CURRENT_DATE BETWEEN m."avail_start" AND m."avail_end") THEN 'in'
			WHEN (CURRENT_DATE > m."avail_end") THEN 'expired'
			WHEN (CURRENT_DATE < m."avail_start") THEN 'future'		
		END AS "window"
		,m."catalogName"
		,'mappings[active,ToBeMapped]{catalogName|window}' AS "metric"
		,COUNT(m."mappingId") AS "count"
	FROM mapping m
	WHERE m."deleted" IS NULL 
		AND m."status"='ToBeMapped'
	GROUP BY 1,2,3
	
),
dim_catalogname AS (SELECT DISTINCT "dimension" AS "catalogName" FROM _stats WHERE metric='mappings{catalogName}'),
dim_window("window") AS (VALUES ('undef'),('in'),('expired'),('future')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"catalogName","window") AS "dimension" 
	FROM dim_catalogname CROSS JOIN dim_window 
), 
counts AS (
	SELECT "metric", CONCAT_WS('|',"catalogName","window") AS "dimension", "count" AS "value" FROM raw_counts
),
counts_with_zeros AS (
	SELECT 'mappings[active,ToBeMapped]{catalogName|window}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- active/ToBeMapped mappings by catalog/reason
WITH raw_counts AS (
	
	SELECT
		CONCAT_WS('|',m."catalogName",COALESCE(m."message_reason",' NULL')) AS "dimension"
		,'mappings[active,ToBeMapped]{catalogName|reason}' AS "metric"
		,COUNT(m."mappingId") AS "count"
	FROM mapping m
	WHERE m."deleted" IS NULL 
		AND m."status"='ToBeMapped'
	GROUP BY 1,2
	
),
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- active/Unmappable mappings by catalog/reason
WITH raw_counts AS (
	
	SELECT
		CONCAT_WS('|',m."catalogName",COALESCE(m."message_reason",' NULL')) AS "dimension"
		,'mappings[active,Unmappable]{catalogName|reason}' AS "metric"
		,COUNT(m."mappingId") AS "count"
	FROM mapping m
	WHERE m."deleted" IS NULL 
		AND m."status"='Unmappable'
	GROUP BY 1,2
	
),
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- mapping programs with status
WITH raw_counts AS (
	
	SELECT 
		CASE WHEN p."TMSId" IS NULL THEN 1 ELSE NULL END AS is_null, p."deleted", p."inactive"
		,'mapping[active]_programs{STATUS}' AS "metric"
		,NULL AS "dimension"
		,COUNT(DISTINCT mi."id") AS "count"
	FROM mapping m
		JOIN mapping_id mi ON m."mappingId"=mi."mappingId"
		LEFT JOIN program p ON mi."id"=p."TMSId"
	WHERE m."deleted" IS NULL
		AND mi."type"='TMSId'
	GROUP BY 1,2,3,4,5
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted'),('inactive'),('missing')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS") AS "dimension" 
	FROM dim_status 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','missing',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "is_null"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','inactive',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "inactive"=1 AND "deleted" IS NULL  GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "inactive" IS NULL AND "deleted" IS NULL  AND "is_null" IS NULL GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'mapping[active]_programs{STATUS}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- active mapping programs by catalog
WITH raw_counts AS (
	
	SELECT 
		'mapping[active]_programs{catalogName}' AS "metric"
		,m."catalogName" AS "dimension"
		,COUNT(DISTINCT mi."id") AS "count"
	FROM mapping m
		JOIN mapping_id mi ON m."mappingId"=mi."mappingId"
	WHERE m."deleted" IS NULL
		AND mi."type"='TMSId'
	GROUP BY 1,2
	
),
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- schedule sources
WITH raw_counts AS (
	
	SELECT 
		'schedule_sources' AS "metric"
		,NULL AS "dimension"
		,COUNT(DISTINCT h."prgSvcId") AS "count"
	FROM schedule h
	GROUP BY 1,2
	
),
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- schedule dates
WITH raw_counts AS (
	
	SELECT 
		CASE 
			WHEN h."date" >= CURRENT_DATE THEN 'forward'
			WHEN h."date" < CURRENT_DATE THEN 'backward'
		END AS "dimension"
		,'schedule_dates{horizon}' AS "metric"
		,COUNT(DISTINCT h."date") AS "count"
	FROM schedule h
	GROUP BY 1,2
	
),
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- schedule events
WITH raw_counts AS (
	
	SELECT 
		CASE 
			WHEN h."date" >= CURRENT_DATE THEN 'forward'
			WHEN h."date" < CURRENT_DATE THEN 'backward'
		END AS "dimension"
		,'schedule_events{horizon}' AS "metric"
		,COUNT(he."eventId") AS "count"
	FROM schedule h
		JOIN schedule_event he ON h."scheduleId"=he."scheduleId"
	GROUP BY 1,2
	
),
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- schedule events by pType - today
WITH raw_counts AS (
	
	SELECT 
		CASE 
			WHEN (p."progType"='TBA') THEN 'tba'
			WHEN (p."progType"='Off Air') THEN 'offair'
			ELSE 'generic'
		END AS "dimension"
		,'schedule[today]_events{pType}' AS "metric"
		,COUNT(he."TMSId") AS "count"
	FROM schedule h
		JOIN schedule_event he ON h."scheduleId"=he."scheduleId"
		JOIN program p ON he."TMSId"=p."TMSId"
	WHERE h."date" = CURRENT_DATE
	GROUP BY 1,2
		
),
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- schedule events by pType - next7d
WITH raw_counts AS (
	
	SELECT 
		CASE 
			WHEN (p."progType"='TBA') THEN 'tba'
			WHEN (p."progType"='Off Air') THEN 'offair'
			ELSE 'generic'
		END AS "dimension"
		,'schedule[next7d]_events{pType}' AS "metric"
		,COUNT(he."TMSId") AS "count"
	FROM schedule h
		JOIN schedule_event he ON h."scheduleId"=he."scheduleId"
		JOIN program p ON he."TMSId"=p."TMSId"
	WHERE h."date" BETWEEN CURRENT_DATE AND (CURRENT_DATE +'7day'::INTERVAL)
	GROUP BY 1,2
		
),
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- schedule events by pType - last7d
WITH raw_counts AS (
	
	SELECT 
		CASE 
			WHEN (p."progType"='TBA') THEN 'tba'
			WHEN (p."progType"='Off Air') THEN 'offair'
			ELSE 'generic'
		END AS "dimension"
		,'schedule[last7d]_events{pType}' AS "metric"
		,COUNT(he."TMSId") AS "count"
	FROM schedule h
		JOIN schedule_event he ON h."scheduleId"=he."scheduleId"
		JOIN program p ON he."TMSId"=p."TMSId"
	WHERE h."date" BETWEEN (CURRENT_DATE -'7day'::INTERVAL) AND CURRENT_DATE
	GROUP BY 1,2
		
),
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- schedule events by pType - forward
WITH raw_counts AS (
	
	SELECT 
		CASE 
			WHEN (p."progType"='TBA') THEN 'tba'
			WHEN (p."progType"='Off Air') THEN 'offair'
			ELSE 'generic'
		END AS "dimension"
		,'schedule[forward]_events{pType}' AS "metric"
		,COUNT(he."TMSId") AS "count"
	FROM schedule h
		JOIN schedule_event he ON h."scheduleId"=he."scheduleId"
		JOIN program p ON he."TMSId"=p."TMSId"
	WHERE h."date" >= CURRENT_DATE
	GROUP BY 1,2
		
),
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- schedule programs with status - 1d
WITH raw_counts AS (
	
	SELECT 
		CASE WHEN p."TMSId" IS NULL THEN 1 ELSE NULL END AS is_null, p."deleted", p."inactive"
		,'schedule[now-1d]_programs{STATUS}' AS "metric"
		,NULL AS "dimension"
		,COUNT(DISTINCT he."TMSId") AS "count"
	FROM schedule h
		JOIN schedule_event he ON h."scheduleId"=he."scheduleId"
		LEFT JOIN program p ON he."TMSId"=p."TMSId"
	WHERE h."date" BETWEEN CURRENT_DATE AND (CURRENT_DATE +'1day'::INTERVAL)
	GROUP BY 1,2,3,4,5
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted'),('inactive'),('missing')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS") AS "dimension" 
	FROM dim_status 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','missing',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "is_null"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','inactive',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "inactive"=1 AND "deleted" IS NULL  GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "inactive" IS NULL AND "deleted" IS NULL  AND "is_null" IS NULL GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'schedule[now-1d]_programs{STATUS}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- schedule programs with status - forward
WITH raw_counts AS (
	
	SELECT 
		CASE WHEN p."TMSId" IS NULL THEN 1 ELSE NULL END AS is_null, p."deleted", p."inactive"
		,'schedule[forward]_programs{STATUS}' AS "metric"
		,NULL AS "dimension"
		,COUNT(DISTINCT he."TMSId") AS "count"
	FROM schedule h
		JOIN schedule_event he ON h."scheduleId"=he."scheduleId"
		LEFT JOIN program p ON he."TMSId"=p."TMSId"
	WHERE h."date" >= CURRENT_DATE
	GROUP BY 1,2,3,4,5
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted'),('inactive'),('missing')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS") AS "dimension" 
	FROM dim_status 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','missing',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "is_null"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','inactive',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "inactive"=1 AND "deleted" IS NULL  GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "inactive" IS NULL AND "deleted" IS NULL  AND "is_null" IS NULL GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'schedule[forward]_programs{STATUS}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- schedule sources with status - forward
WITH raw_counts AS (
	
	SELECT 
		CASE WHEN s."prgSvcId" IS NULL THEN 1 ELSE NULL END AS is_null, s."deleted", s."inactive"
		,'schedule[forward]_sources{STATUS}' AS "metric"
		,NULL AS "dimension"
		,COUNT(DISTINCT h."prgSvcId") AS "count"
	FROM schedule h
		LEFT JOIN source s ON h."prgSvcId"=s."prgSvcId"
	WHERE h."date" >= CURRENT_DATE
	GROUP BY 1,2,3,4,5
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted'),('inactive'),('missing')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS") AS "dimension" 
	FROM dim_status 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','missing',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "is_null"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','inactive',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "inactive"=1 AND "deleted" IS NULL  GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "inactive" IS NULL AND "deleted" IS NULL  AND "is_null" IS NULL GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'schedule[forward]_sources{STATUS}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- schedule discontinuities by source/midnight - today

WITH events AS (
	SELECT he."eventId"
		,h."prgSvcId"
		,(SUBSTRING(he."scheduleId", POSITION('-' IN he."scheduleId")+1)||' '||he.time)::TIMESTAMP AS "start"
		,(SUBSTRING(he."scheduleId", POSITION('-' IN he."scheduleId")+1)||' '||he.time)::TIMESTAMP + SUBSTRING(he.dur FROM 3 FOR 6)::INTERVAL AS "end"
	FROM schedule_event he
		JOIN "schedule" h ON he."scheduleId"=h."scheduleId"
	WHERE h."date" BETWEEN CURRENT_DATE -'1day'::INTERVAL AND CURRENT_DATE +'1day'::INTERVAL
	ORDER BY 2,3
), events_with_next AS (
	SELECT "eventId", "prgSvcId", "start", "end"
		,LEAD("start") OVER (PARTITION BY "prgSvcId") AS "next_start"
	FROM events
), events_with_gap AS (
	SELECT "eventId", "prgSvcId"
		,"start", "end", "next_start"
		,EXTRACT (EPOCH FROM COALESCE("next_start","end"))-EXTRACT (EPOCH FROM "end") AS "gap"
		,CASE WHEN "start"::DATE="end"::DATE THEN 0 ELSE 1 END AS "midnight"
	FROM events_with_next
), counts AS (
	SELECT
		'schedule[today]_discontinuities{prgSvcId|midnight}' AS "metric"
		,CONCAT_WS('|',"prgSvcId","midnight") AS "dimension"
		,COUNT("eventId") AS "value"
	FROM events_with_gap 
	WHERE "gap" != 0 
	GROUP BY 1,2
	UNION SELECT 
		'schedule[today]_discontinuities{prgSvcId|midnight}' AS "metric",'|0' AS "dimension", 0 AS "value"
	UNION SELECT 
		'schedule[today]_discontinuities{prgSvcId|midnight}' AS "metric",'|1' AS "dimension", 0 AS "value"
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- schedule discontinuities by source/midnight - forward

WITH events AS (
	SELECT he."eventId"
		,h."prgSvcId"
		,(SUBSTRING(he."scheduleId", POSITION('-' IN he."scheduleId")+1)||' '||he.time)::TIMESTAMP AS "start"
		,(SUBSTRING(he."scheduleId", POSITION('-' IN he."scheduleId")+1)||' '||he.time)::TIMESTAMP + SUBSTRING(he.dur FROM 3 FOR 6)::INTERVAL AS "end"
	FROM schedule_event he
		JOIN "schedule" h ON he."scheduleId"=h."scheduleId"
	WHERE h."date" >= CURRENT_DATE
	ORDER BY 2,3
), events_with_next AS (
	SELECT "eventId", "prgSvcId", "start", "end"
		,LEAD("start") OVER (PARTITION BY "prgSvcId") AS "next_start"
	FROM events
), events_with_gap AS (
	SELECT "eventId", "prgSvcId"
		,"start", "end", "next_start"
		,EXTRACT (EPOCH FROM COALESCE("next_start","end"))-EXTRACT (EPOCH FROM "end") AS "gap"
		,CASE WHEN "start"::DATE="end"::DATE THEN 0 ELSE 1 END AS "midnight"
	FROM events_with_next
), counts AS (
	SELECT
		'schedule[forward]_discontinuities{prgSvcId|midnight}' AS "metric"
		,CONCAT_WS('|',"prgSvcId","midnight") AS "dimension"
		,COUNT("eventId") AS "value"
	FROM events_with_gap 
	WHERE "gap" != 0 
	GROUP BY 1,2
	UNION SELECT 
		'schedule[forward]_discontinuities{prgSvcId|midnight}' AS "metric",'|0' AS "dimension", 0 AS "value"
	UNION SELECT 
		'schedule[forward]_discontinuities{prgSvcId|midnight}' AS "metric",'|1' AS "dimension", 0 AS "value"
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- source counts with entity status
WITH raw_counts AS (
	
	SELECT 
		s."deleted", s."inactive"
		,'sources{STATUS}' AS "metric"
		,NULL AS "dimension"
		,COUNT(s."prgSvcId") AS "count"
	FROM source s
	GROUP BY 1,2,3,4
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted'),('inactive')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS") AS "dimension" 
	FROM dim_status 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','inactive',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "inactive"=1 AND "deleted" IS NULL  GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "inactive" IS NULL AND "deleted" IS NULL   GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'sources{STATUS}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- active source counts by editing status/type
WITH raw_counts AS (
	
	SELECT 
		'sources[active]{status|type}' AS "metric"
		,CONCAT_WS('|',s."status",s."type") AS "dimension"
		,COUNT(s."prgSvcId") AS "count"
	FROM source s
	WHERE s."deleted" IS NULL AND s.inactive IS NULL
	GROUP BY 1,2
	
),
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- active source counts by source type
WITH raw_counts AS (
	
	SELECT 
		'sources[active]{type}' AS "metric"
		,s."type" AS "dimension"
		,COUNT(s."prgSvcId") AS "count"
	FROM source s
	WHERE s."deleted" IS NULL AND s.inactive IS NULL
	GROUP BY 1,2
	
),
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- active source counts by ed language
WITH raw_counts AS (
	
	SELECT 
		'sources[active]{edLang}' AS "metric"
		,sel."edLang" AS "dimension"
		,COUNT(DISTINCT s."prgSvcId") AS "count"
	FROM source s
		JOIN source_edlang sel on s."prgSvcId"=sel."prgSvcId"
	WHERE s."deleted" IS NULL AND s."inactive" IS NULL
	GROUP BY 1,2
	
),
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- active source counts by country
WITH raw_counts AS (
	
	SELECT 
		'sources[active]{country}' AS "metric"
		,sc."country" AS "dimension"
		,COUNT(DISTINCT s."prgSvcId") AS "count"
	FROM source s
		JOIN source_country sc on s."prgSvcId"=sc."prgSvcId"
	WHERE s."deleted" IS NULL AND s."inactive" IS NULL
	GROUP BY 1,2
	
),
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- celebrity counts with entity status
WITH raw_counts AS (
	
	SELECT 
		c."deleted"
		,'celebrities{STATUS}' AS "metric"
		,NULL AS "dimension"
		,COUNT(c."personId") AS "count"
	FROM celebrity c
	GROUP BY 1,2,3
	
),
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE 1=1 AND "deleted" IS NULL   GROUP BY 1,2 
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- active celebrity names
WITH raw_counts AS (
	
	SELECT 
		'celebrity[active]_names' AS "metric"
		,NULL AS "dimension"
		,COUNT(DISTINCT cn."nameId") AS "count"
	FROM celebrity c
		JOIN celebrity_name cn ON c."personId"=cn."personId"
	WHERE c."deleted" IS NULL
	GROUP BY 1,2
	
),
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- active celebrity names by language
WITH raw_counts AS (
	
	SELECT 
		'celebrity[active]_names{language}' AS "metric"
		,cn."lang" AS "dimension"
		,COUNT(DISTINCT cn."nameId") AS "count"
	FROM celebrity c
		JOIN celebrity_name cn ON c."personId"=cn."personId"
	WHERE c."deleted" IS NULL
	GROUP BY 1,2
	
),
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- active celebrities by type
WITH raw_counts AS (
	
	SELECT 
		'celebrities[active]{type}' AS "metric"
		,c."type" AS "dimension"
		,COUNT(c."personId") AS "count"
	FROM celebrity c
	WHERE c."deleted" IS NULL
	GROUP BY 1,2
	
),
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- active celebrities by image category
WITH raw_counts AS (
	
	SELECT 
		'celebrities[active]{imageCategory}' AS "metric"
		,ca."category" AS "dimension"
		,COUNT(DISTINCT c."personId") AS "count"
	FROM celebrity c
		JOIN celebrity_asset ca ON c."personId"=ca."personId"
	WHERE c."deleted" IS NULL
	GROUP BY 1,2
	
),
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- program cast celebrities with status
WITH raw_counts AS (
	
	SELECT 
		CASE WHEN c."personId" IS NULL THEN 1 ELSE NULL END AS "is_null", c."deleted"
		,'program[active,cast]_celebrities{STATUS}' AS "metric"
		,NULL AS "dimension"
		,COUNT(DISTINCT pct."personId") AS "count"
	FROM program p
		JOIN program_cast pct ON p."TMSId"=pct."TMSId"
		LEFT JOIN celebrity c ON pct."personId"=c."personId"
	WHERE p."deleted" IS NULL
	GROUP BY 1,2,3,4
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted'),('missing')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS") AS "dimension" 
	FROM dim_status 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','missing',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "is_null"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE 1=1 AND "deleted" IS NULL  AND "is_null" IS NULL GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'program[active,cast]_celebrities{STATUS}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- program crew celebrities with status
WITH raw_counts AS (
	
	SELECT 
		CASE WHEN c."personId" IS NULL THEN 1 ELSE NULL END AS "is_null", c."deleted"
		,'program[active,crew]_celebrities{STATUS}' AS "metric"
		,NULL AS "dimension"
		,COUNT(DISTINCT pcw."personId") AS "count"
	FROM program p
		JOIN program_crew pcw ON p."TMSId"=pcw."TMSId"
		LEFT JOIN celebrity c ON pcw."personId"=c."personId"
	WHERE p."deleted" IS NULL
	GROUP BY 1,2,3,4
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted'),('missing')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS") AS "dimension" 
	FROM dim_status 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','missing',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "is_null"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE 1=1 AND "deleted" IS NULL  AND "is_null" IS NULL GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'program[active,crew]_celebrities{STATUS}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- descriptor taxonomy counts with entity status
WITH raw_counts AS (
	
	SELECT 
		d."deleted"
		,'descriptortaxonomies{STATUS}' AS "metric"
		,NULL AS "dimension"
		,COUNT(d."taxonomyId") AS "count"
	FROM descriptortaxonomy d
	GROUP BY 1,2,3
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS") AS "dimension" 
	FROM dim_status 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE 1=1 AND "deleted" IS NULL   GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'descriptortaxonomies{STATUS}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- descriptor counts with entity status
WITH raw_counts AS (
	
	SELECT 
		d."deleted"
		,'descriptors{STATUS}' AS "metric"
		,NULL AS "dimension"
		,COUNT(d."descriptorId") AS "count"
	FROM descriptor d
	GROUP BY 1,2,3
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS") AS "dimension" 
	FROM dim_status 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE 1=1 AND "deleted" IS NULL   GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'descriptors{STATUS}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- active descriptors by type
WITH raw_counts AS (
	
	SELECT 
		'descriptors[active]{typeName}' AS "metric"
		,d."typeName" AS "dimension"
		,COUNT(d."descriptorId") AS "count"
	FROM descriptor d
	WHERE d."deleted" IS NULL
	GROUP BY 1,2
	
),
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- descriptor parents with status
WITH raw_counts AS (
	
	SELECT 
		CASE WHEN dp."descriptorId" IS NULL THEN 1 ELSE NULL END AS "is_null", dp."deleted"
		,'descriptor[active]_parents{STATUS}' AS "metric"
		,NULL AS "dimension"
		,COUNT(DISTINCT d."parent_descriptorId") AS "count"
	FROM descriptor d
		LEFT JOIN descriptor dp ON dp."descriptorId"=d."parent_descriptorId"
	WHERE d."deleted" IS NULL
	GROUP BY 1,2,3,4
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted'),('missing')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS") AS "dimension" 
	FROM dim_status 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','missing',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "is_null"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE 1=1 AND "deleted" IS NULL  AND "is_null" IS NULL GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'descriptor[active]_parents{STATUS}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- program descriptors with status
WITH raw_counts AS (
	
	SELECT 
		CASE WHEN d."descriptorId" IS NULL THEN 1 ELSE NULL END AS "is_null", d."deleted"
		,'program[active]_descriptors{STATUS}' AS "metric"
		,NULL AS "dimension"
		,COUNT(DISTINCT pd."descriptorId") AS "count"
	FROM program p
		JOIN program_descriptor pd ON p."TMSId"=pd."TMSId"
		LEFT JOIN descriptor d ON pd."descriptorId"=d."descriptorId"
	WHERE p."deleted" IS NULL AND p."inactive" IS NULL
	GROUP BY 1,2,3,4
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted'),('missing')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS") AS "dimension" 
	FROM dim_status 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','missing',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "is_null"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE 1=1 AND "deleted" IS NULL  AND "is_null" IS NULL GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'program[active]_descriptors{STATUS}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- popularity counts with entity status
WITH raw_counts AS (
	
	SELECT 
		p."deleted"
		,'popularity{STATUS}' AS "metric"
		,NULL AS "dimension"
		,COUNT(p."popularityId") AS "count"
	FROM popularity p
	GROUP BY 1,2,3
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS") AS "dimension" 
	FROM dim_status 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE 1=1 AND "deleted" IS NULL   GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'popularity{STATUS}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- organization counts with entity status
WITH raw_counts AS (
	
	SELECT 
		o."deleted"
		,'organizations{STATUS}' AS "metric"
		,NULL AS "dimension"
		,COUNT(o."organizationId") AS "count"
	FROM sportsorg o
	GROUP BY 1,2,3
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS") AS "dimension" 
	FROM dim_status 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE 1=1 AND "deleted" IS NULL   GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'organizations{STATUS}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- conference counts
WITH raw_counts AS (
	
	SELECT 
		'conferences' AS "metric"
		,NULL AS "dimension"
		,COUNT(c."conferenceId") AS "count"
	FROM sportsconf c
	GROUP BY 1,2
	
),
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- active official organization counts by sport/genre
WITH raw_counts AS (
	
	SELECT 
		'organizations[active,official]{genre}' AS "metric"
		,o."genre" AS "dimension"
		,COUNT(o."organizationId") AS "count"
	FROM sportsorg o
		WHERE o."deleted" IS NULL
			AND o."official"=1
	GROUP BY 1,2
	
),
counts AS (
	SELECT "metric", "dimension" AS "dimension", "count" AS "value" FROM raw_counts
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts"
;

-- team counts with entity status
WITH raw_counts AS (
	
	SELECT 
		t."deleted"
		,'teams{STATUS}' AS "metric"
		,NULL AS "dimension"
		,COUNT(t."teamId") AS "count"
	FROM team t
	GROUP BY 1,2,3
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS") AS "dimension" 
	FROM dim_status 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE 1=1 AND "deleted" IS NULL   GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'teams{STATUS}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- active teambrand teams with entity status
WITH raw_counts AS (
	
	SELECT 
		CASE WHEN t."teamId" IS NULL THEN 1 ELSE NULL END AS "is_null", t."deleted"
		,'teambrand[active]_teams{STATUS}' AS "metric"
		,NULL AS "dimension"
		,COUNT(DISTINCT tb."teamId") AS "count"
	FROM teambrand tb
		LEFT JOIN team t ON tb."teamId"=t."teamId"
	WHERE tb."deleted" IS NULL AND tb."active"=1
	GROUP BY 1,2,3,4
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted'),('missing')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS") AS "dimension" 
	FROM dim_status 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','missing',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "is_null"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE 1=1 AND "deleted" IS NULL  AND "is_null" IS NULL GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'teambrand[active]_teams{STATUS}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- teambrand counts with status by active flag
WITH raw_counts AS (
	
	SELECT 
		tb."deleted", tb."active" AS "active_brand"
		,'teambrands{STATUS|active_brand}' AS "metric"
		,tb."active" AS "dimension"
		,COUNT(tb."teamBrandId") AS "count"
	FROM teambrand tb
	GROUP BY 1,2,3
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted')),
dim_active_brand AS (SELECT DISTINCT "active_brand" AS "active_brand" FROM raw_counts),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS","active_brand") AS "dimension" 
	FROM dim_status CROSS JOIN dim_active_brand 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE 1=1 AND "deleted" IS NULL   GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'teambrands{STATUS|active_brand}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- program teambrands with status by active flag
WITH raw_counts AS (
	
	SELECT 
		CASE WHEN tb."teamBrandId" IS NULL THEN 1 ELSE NULL END AS "is_null", tb."deleted", tb."active" AS "active_brand"
		,'program[active]_teambrands{STATUS|active_brand}' AS "metric"
		,tb."active" AS "dimension"
		,COUNT(DISTINCT pst."teamBrandId") AS "count"
	FROM program p
		JOIN program_spteam pst ON p."TMSId"=pst."TMSId"
		LEFT JOIN teambrand tb ON pst."teamBrandId"=tb."teamBrandId"
	WHERE p."deleted" IS NULL
	GROUP BY 1,2,3,4,5
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted'),('missing')),
dim_active_brand AS (SELECT DISTINCT "active_brand" AS "active_brand" FROM raw_counts),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS","active_brand") AS "dimension" 
	FROM dim_status CROSS JOIN dim_active_brand 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','missing',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "is_null"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE 1=1 AND "deleted" IS NULL  AND "is_null" IS NULL GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'program[active]_teambrands{STATUS|active_brand}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- organization teambrands with status by active flag
WITH raw_counts AS (
	
	SELECT 
		CASE WHEN tb."teamBrandId" IS NULL THEN 1 ELSE NULL END AS "is_null", tb."deleted", tb."active" AS "active_brand"
		,'organization[active]_teambrands{STATUS|active_brand}' AS "metric"
		,tb."active" AS "dimension"
		,COUNT(DISTINCT sotb."teamBrandId") AS "count"
	FROM sportsorg so
		JOIN sportsorg_teambrand sotb ON so."organizationId"=sotb."organizationId"
		LEFT JOIN teambrand tb ON sotb."teamBrandId"=tb."teamBrandId"
	WHERE so."deleted" IS NULL
	GROUP BY 1,2,3,4,5
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted'),('missing')),
dim_active_brand AS (SELECT DISTINCT "active_brand" AS "active_brand" FROM raw_counts),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS","active_brand") AS "dimension" 
	FROM dim_status CROSS JOIN dim_active_brand 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','missing',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "is_null"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE 1=1 AND "deleted" IS NULL  AND "is_null" IS NULL GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'organization[active]_teambrands{STATUS|active_brand}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- venue counts with entity status
WITH raw_counts AS (
	
	SELECT 
		v."deleted"
		,'venues{STATUS}' AS "metric"
		,NULL AS "dimension"
		,COUNT(v."venueId") AS "count"
	FROM venue v
	GROUP BY 1,2,3
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS") AS "dimension" 
	FROM dim_status 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE 1=1 AND "deleted" IS NULL   GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'venues{STATUS}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- active venuebrand venues with entity status
WITH raw_counts AS (
	
	SELECT 
		CASE WHEN v."venueId" IS NULL THEN 1 ELSE NULL END AS "is_null", v."deleted"
		,'venuebrand[active]_venues{STATUS}' AS "metric"
		,NULL AS "dimension"
		,COUNT(DISTINCT vb."venueId") AS "count"
	FROM venuebrand vb
		LEFT JOIN venue v ON vb."venueId"=v."venueId"
	WHERE vb."deleted" IS NULL AND vb."active"=1
	GROUP BY 1,2,3,4
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted'),('missing')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS") AS "dimension" 
	FROM dim_status 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','missing',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "is_null"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE 1=1 AND "deleted" IS NULL  AND "is_null" IS NULL GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'venuebrand[active]_venues{STATUS}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- active team venues with entity status
WITH raw_counts AS (
	
	SELECT 
		CASE WHEN v."venueId" IS NULL THEN 1 ELSE NULL END AS "is_null", v."deleted"
		,'team[active]_venues{STATUS}' AS "metric"
		,NULL AS "dimension"
		,COUNT(DISTINCT t."venueId") AS "count"
	FROM team t
		LEFT JOIN venue v ON t."venueId"=v."venueId"
	WHERE t."deleted" IS NULL
	GROUP BY 1,2,3,4
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted'),('missing')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS") AS "dimension" 
	FROM dim_status 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','missing',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "is_null"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE 1=1 AND "deleted" IS NULL  AND "is_null" IS NULL GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'team[active]_venues{STATUS}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- venuebrand counts with status by active flag
WITH raw_counts AS (
	
	SELECT 
		vb."deleted", vb."active" AS "active_brand"
		,'venuebrands{STATUS|active_brand}' AS "metric"
		,vb."active" AS "dimension"
		,COUNT(vb."venueBrandId") AS "count"
	FROM venuebrand vb
	GROUP BY 1,2,3
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted')),
dim_active_brand AS (SELECT DISTINCT "active_brand" AS "active_brand" FROM raw_counts),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS","active_brand") AS "dimension" 
	FROM dim_status CROSS JOIN dim_active_brand 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE 1=1 AND "deleted" IS NULL   GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'venuebrands{STATUS|active_brand}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- program venuebrands with status by active flag
WITH raw_counts AS (
	
	SELECT 
		CASE WHEN vb."venueBrandId" IS NULL THEN 1 ELSE NULL END AS "is_null", vb."deleted", vb."active" AS "active_brand"
		,'program[active]_venuebrands{STATUS|active_brand}' AS "metric"
		,vb."active" AS "dimension"
		,COUNT(DISTINCT psi."venueBrandId") AS "count"
	FROM program p
		JOIN program_spinfo psi ON p."TMSId"=psi."TMSId"
		LEFT JOIN venuebrand vb ON psi."venueBrandId"=vb."venueBrandId"
	WHERE p."deleted" IS NULL
	GROUP BY 1,2,3,4,5
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted'),('missing')),
dim_active_brand AS (SELECT DISTINCT "active_brand" AS "active_brand" FROM raw_counts),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS","active_brand") AS "dimension" 
	FROM dim_status CROSS JOIN dim_active_brand 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','missing',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "is_null"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE 1=1 AND "deleted" IS NULL  AND "is_null" IS NULL GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'program[active]_venuebrands{STATUS|active_brand}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- university counts with entity status
WITH raw_counts AS (
	
	SELECT 
		u."deleted"
		,'universities{STATUS}' AS "metric"
		,NULL AS "dimension"
		,COUNT(u."universityId") AS "count"
	FROM university u
	GROUP BY 1,2,3
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS") AS "dimension" 
	FROM dim_status 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE 1=1 AND "deleted" IS NULL   GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'universities{STATUS}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;

-- active team universities with entity status
WITH raw_counts AS (
	
	SELECT 
		CASE WHEN u."universityId" IS NULL THEN 1 ELSE NULL END AS "is_null", u."deleted"
		,'team[active]_universities{STATUS}' AS "metric"
		,NULL AS "dimension"
		,COUNT(DISTINCT t."universityId") AS "count"
	FROM team t
		LEFT JOIN university u ON t."universityId"=u."universityId"
	WHERE t."deleted" IS NULL
	GROUP BY 1,2,3,4
	
),
dim_status("STATUS") AS (VALUES ('total'),('active'),('deleted'),('missing')),
all_dimension_combinations AS ( 
	SELECT CONCAT_WS('|',"STATUS") AS "dimension" 
	FROM dim_status 
), 
counts AS (
	SELECT NULL AS "metric", NULL AS "dimension", NULL AS "value" WHERE FALSE
	UNION SELECT "metric" 
		,CONCAT_WS('|','total',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','missing',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "is_null"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','deleted',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE "deleted"=1 GROUP BY 1,2 
	UNION SELECT "metric" 
		,CONCAT_WS('|','active',"dimension") AS "dimension"
		,SUM("count") AS "value"
	FROM raw_counts WHERE 1=1 AND "deleted" IS NULL  AND "is_null" IS NULL GROUP BY 1,2 
),
counts_with_zeros AS (
	SELECT 'team[active]_universities{STATUS}' AS "metric",
			adc."dimension",
			COALESCE(c."value",0) AS "value"
	FROM all_dimension_combinations adc LEFT JOIN counts c
		ON adc.dimension=c.dimension
)
INSERT INTO _stats ("timestamp", "metric", "dimension", "value")
SELECT DATE_TRUNC('second', CURRENT_TIMESTAMP) AS "timestamp"
	,"metric", "dimension", "value"
FROM "counts_with_zeros"
;
