-- {0}: core schema

ATTACH "__gxd_runsql_sqlite_db_path_stub__{0}.db" AS core;

CREATE TABLE IF NOT EXISTS core._stats (
    timestamp DATETIME NOT NULL, metric VARCHAR(255) NOT NULL, dimension VARCHAR(255), value REAL );

CREATE INDEX IF NOT EXISTS core._stats_timestamp ON _stats (timestamp);
CREATE INDEX IF NOT EXISTS core._stats_metric ON _stats (metric);


-- Grouping update_date into 900sec (15min) buckets using formula: from_epoch( ceiling( to_epoch(datetime)/900 ) * 900 )
-- Epoch conversion in SQLite - to: strftime('%s', datetime); from: datetime( epoch, 'unixepoch')
-- Because SQLite does not have ceiling() function, using expression CAST(epoch/900 AS INT) + (epoch/900 > CAST(epoch/900 AS INT)) as an equivalent
-- update_date stats for source
INSERT INTO core._stats (timestamp, metric, value)
SELECT datetime( (
    CAST(strftime('%s', t.updateDate)/900 AS INT) + ( strftime('%s', t.updateDate)/900 > CAST(strftime('%s', t.updateDate)/900 AS INT) )
    ) * 900,'unixepoch') AS timestamp
    ,'source_updates' AS metric, COUNT(t.prgSvcId) AS value
FROM core.source t
WHERE t.updateDate > (SELECT COALESCE(MAX(timestamp),'1970-01-01') FROM core._stats WHERE metric = 'source_updates')
GROUP BY timestamp ORDER BY timestamp DESC;

-- Grouping update_date into 900sec (15min) buckets using formula: from_epoch( ceiling( to_epoch(datetime)/900 ) * 900 )
-- Epoch conversion in SQLite - to: strftime('%s', datetime); from: datetime( epoch, 'unixepoch')
-- Because SQLite does not have ceiling() function, using expression CAST(epoch/900 AS INT) + (epoch/900 > CAST(epoch/900 AS INT)) as an equivalent
-- update_date stats for lineup
INSERT INTO core._stats (timestamp, metric, value)
SELECT datetime( (
    CAST(strftime('%s', t.updateDate)/900 AS INT) + ( strftime('%s', t.updateDate)/900 > CAST(strftime('%s', t.updateDate)/900 AS INT) )
    ) * 900,'unixepoch') AS timestamp
    ,'lineup_updates' AS metric, COUNT(t.lineupId) AS value
FROM core.lineup t
WHERE t.updateDate > (SELECT COALESCE(MAX(timestamp),'1970-01-01') FROM core._stats WHERE metric = 'lineup_updates')
GROUP BY timestamp ORDER BY timestamp DESC;

-- Grouping update_date into 900sec (15min) buckets using formula: from_epoch( ceiling( to_epoch(datetime)/900 ) * 900 )
-- Epoch conversion in SQLite - to: strftime('%s', datetime); from: datetime( epoch, 'unixepoch')
-- Because SQLite does not have ceiling() function, using expression CAST(epoch/900 AS INT) + (epoch/900 > CAST(epoch/900 AS INT)) as an equivalent
-- update_date stats for celebrity
INSERT INTO core._stats (timestamp, metric, value)
SELECT datetime( (
    CAST(strftime('%s', t.updateDate)/900 AS INT) + ( strftime('%s', t.updateDate)/900 > CAST(strftime('%s', t.updateDate)/900 AS INT) )
    ) * 900,'unixepoch') AS timestamp
    ,'celebrity_updates' AS metric, COUNT(t.personId) AS value
FROM core.celebrity t
WHERE t.updateDate > (SELECT COALESCE(MAX(timestamp),'1970-01-01') FROM core._stats WHERE metric = 'celebrity_updates')
GROUP BY timestamp ORDER BY timestamp DESC;

-- Grouping update_date into 900sec (15min) buckets using formula: from_epoch( ceiling( to_epoch(datetime)/900 ) * 900 )
-- Epoch conversion in SQLite - to: strftime('%s', datetime); from: datetime( epoch, 'unixepoch')
-- Because SQLite does not have ceiling() function, using expression CAST(epoch/900 AS INT) + (epoch/900 > CAST(epoch/900 AS INT)) as an equivalent
-- update_date stats for program
INSERT INTO core._stats (timestamp, metric, value)
SELECT datetime( (
    CAST(strftime('%s', t.updateDate)/900 AS INT) + ( strftime('%s', t.updateDate)/900 > CAST(strftime('%s', t.updateDate)/900 AS INT) )
    ) * 900,'unixepoch') AS timestamp
    ,'program_updates' AS metric, COUNT(t.TMSId) AS value
FROM core.program t
WHERE t.updateDate > (SELECT COALESCE(MAX(timestamp),'1970-01-01') FROM core._stats WHERE metric = 'program_updates')
GROUP BY timestamp ORDER BY timestamp DESC;

-- Grouping update_date into 900sec (15min) buckets using formula: from_epoch( ceiling( to_epoch(datetime)/900 ) * 900 )
-- Epoch conversion in SQLite - to: strftime('%s', datetime); from: datetime( epoch, 'unixepoch')
-- Because SQLite does not have ceiling() function, using expression CAST(epoch/900 AS INT) + (epoch/900 > CAST(epoch/900 AS INT)) as an equivalent
-- update_date stats for availability
INSERT INTO core._stats (timestamp, metric, value)
SELECT datetime( (
    CAST(strftime('%s', t.updateDate)/900 AS INT) + ( strftime('%s', t.updateDate)/900 > CAST(strftime('%s', t.updateDate)/900 AS INT) )
    ) * 900,'unixepoch') AS timestamp
    ,'availability_updates' AS metric, COUNT(t.availabilityId) AS value
FROM core.availability t
WHERE t.updateDate > (SELECT COALESCE(MAX(timestamp),'1970-01-01') FROM core._stats WHERE metric = 'availability_updates')
GROUP BY timestamp ORDER BY timestamp DESC;

-- Grouping update_date into 900sec (15min) buckets using formula: from_epoch( ceiling( to_epoch(datetime)/900 ) * 900 )
-- Epoch conversion in SQLite - to: strftime('%s', datetime); from: datetime( epoch, 'unixepoch')
-- Because SQLite does not have ceiling() function, using expression CAST(epoch/900 AS INT) + (epoch/900 > CAST(epoch/900 AS INT)) as an equivalent
-- update_date stats for mapping
INSERT INTO core._stats (timestamp, metric, value)
SELECT datetime( (
    CAST(strftime('%s', t.updateDate)/900 AS INT) + ( strftime('%s', t.updateDate)/900 > CAST(strftime('%s', t.updateDate)/900 AS INT) )
    ) * 900,'unixepoch') AS timestamp
    ,'mapping_updates' AS metric, COUNT(t.mappingId) AS value
FROM core.mapping t
WHERE t.updateDate > (SELECT COALESCE(MAX(timestamp),'1970-01-01') FROM core._stats WHERE metric = 'mapping_updates')
GROUP BY timestamp ORDER BY timestamp DESC;

-- Grouping update_date into 900sec (15min) buckets using formula: from_epoch( ceiling( to_epoch(datetime)/900 ) * 900 )
-- Epoch conversion in SQLite - to: strftime('%s', datetime); from: datetime( epoch, 'unixepoch')
-- Because SQLite does not have ceiling() function, using expression CAST(epoch/900 AS INT) + (epoch/900 > CAST(epoch/900 AS INT)) as an equivalent
-- update_date stats for schedule
INSERT INTO core._stats (timestamp, metric, value)
SELECT datetime( (
    CAST(strftime('%s', t.updateDate)/900 AS INT) + ( strftime('%s', t.updateDate)/900 > CAST(strftime('%s', t.updateDate)/900 AS INT) )
    ) * 900,'unixepoch') AS timestamp
    ,'schedule_updates' AS metric, COUNT(t.scheduleId) AS value
FROM core.schedule t
WHERE t.updateDate > (SELECT COALESCE(MAX(timestamp),'1970-01-01') FROM core._stats WHERE metric = 'schedule_updates')
GROUP BY timestamp ORDER BY timestamp DESC;


-- Parsing datetime parts from ingest_id and concatenating them to form proper datetime
-- ingest_id stats for source
INSERT INTO core._stats (timestamp, metric, value)
SELECT datetime(
    substr(t.ingestId,1,4)||'-'||
    substr(t.ingestId,5,2)||'-'||
    substr(t.ingestId,7,2)||' '||
    substr(t.ingestId,9,2)||':'||
    substr(t.ingestId,11,2)||':'||
    substr(t.ingestId,13,2)
    ) AS timestamp,
    'source_ingests' AS metric, COUNT(t.prgSvcId) AS value
FROM core.source t
WHERE datetime(
    substr(t.ingestId,1,4)||'-'||
    substr(t.ingestId,5,2)||'-'||
    substr(t.ingestId,7,2)||' '||
    substr(t.ingestId,9,2)||':'||
    substr(t.ingestId,11,2)||':'||
    substr(t.ingestId,13,2)
    ) > (SELECT COALESCE(MAX(timestamp),'1970-01-01') FROM core._stats WHERE metric = 'source_ingests')
GROUP BY t.ingestId ORDER BY t.ingestId DESC;

-- Parsing datetime parts from ingest_id and concatenating them to form proper datetime
-- ingest_id stats for lineup
INSERT INTO core._stats (timestamp, metric, value)
SELECT datetime(
    substr(t.ingestId,1,4)||'-'||
    substr(t.ingestId,5,2)||'-'||
    substr(t.ingestId,7,2)||' '||
    substr(t.ingestId,9,2)||':'||
    substr(t.ingestId,11,2)||':'||
    substr(t.ingestId,13,2)
    ) AS timestamp,
    'lineup_ingests' AS metric, COUNT(t.lineupId) AS value
FROM core.lineup t
WHERE datetime(
    substr(t.ingestId,1,4)||'-'||
    substr(t.ingestId,5,2)||'-'||
    substr(t.ingestId,7,2)||' '||
    substr(t.ingestId,9,2)||':'||
    substr(t.ingestId,11,2)||':'||
    substr(t.ingestId,13,2)
    ) > (SELECT COALESCE(MAX(timestamp),'1970-01-01') FROM core._stats WHERE metric = 'lineup_ingests')
GROUP BY t.ingestId ORDER BY t.ingestId DESC;

-- Parsing datetime parts from ingest_id and concatenating them to form proper datetime
-- ingest_id stats for celebrity
INSERT INTO core._stats (timestamp, metric, value)
SELECT datetime(
    substr(t.ingestId,1,4)||'-'||
    substr(t.ingestId,5,2)||'-'||
    substr(t.ingestId,7,2)||' '||
    substr(t.ingestId,9,2)||':'||
    substr(t.ingestId,11,2)||':'||
    substr(t.ingestId,13,2)
    ) AS timestamp,
    'celebrity_ingests' AS metric, COUNT(t.personId) AS value
FROM core.celebrity t
WHERE datetime(
    substr(t.ingestId,1,4)||'-'||
    substr(t.ingestId,5,2)||'-'||
    substr(t.ingestId,7,2)||' '||
    substr(t.ingestId,9,2)||':'||
    substr(t.ingestId,11,2)||':'||
    substr(t.ingestId,13,2)
    ) > (SELECT COALESCE(MAX(timestamp),'1970-01-01') FROM core._stats WHERE metric = 'celebrity_ingests')
GROUP BY t.ingestId ORDER BY t.ingestId DESC;

-- Parsing datetime parts from ingest_id and concatenating them to form proper datetime
-- ingest_id stats for program
INSERT INTO core._stats (timestamp, metric, value)
SELECT datetime(
    substr(t.ingestId,1,4)||'-'||
    substr(t.ingestId,5,2)||'-'||
    substr(t.ingestId,7,2)||' '||
    substr(t.ingestId,9,2)||':'||
    substr(t.ingestId,11,2)||':'||
    substr(t.ingestId,13,2)
    ) AS timestamp,
    'program_ingests' AS metric, COUNT(t.TMSId) AS value
FROM core.program t
WHERE datetime(
    substr(t.ingestId,1,4)||'-'||
    substr(t.ingestId,5,2)||'-'||
    substr(t.ingestId,7,2)||' '||
    substr(t.ingestId,9,2)||':'||
    substr(t.ingestId,11,2)||':'||
    substr(t.ingestId,13,2)
    ) > (SELECT COALESCE(MAX(timestamp),'1970-01-01') FROM core._stats WHERE metric = 'program_ingests')
GROUP BY t.ingestId ORDER BY t.ingestId DESC;

-- Parsing datetime parts from ingest_id and concatenating them to form proper datetime
-- ingest_id stats for availability
INSERT INTO core._stats (timestamp, metric, value)
SELECT datetime(
    substr(t.ingestId,1,4)||'-'||
    substr(t.ingestId,5,2)||'-'||
    substr(t.ingestId,7,2)||' '||
    substr(t.ingestId,9,2)||':'||
    substr(t.ingestId,11,2)||':'||
    substr(t.ingestId,13,2)
    ) AS timestamp,
    'availability_ingests' AS metric, COUNT(t.availabilityId) AS value
FROM core.availability t
WHERE datetime(
    substr(t.ingestId,1,4)||'-'||
    substr(t.ingestId,5,2)||'-'||
    substr(t.ingestId,7,2)||' '||
    substr(t.ingestId,9,2)||':'||
    substr(t.ingestId,11,2)||':'||
    substr(t.ingestId,13,2)
    ) > (SELECT COALESCE(MAX(timestamp),'1970-01-01') FROM core._stats WHERE metric = 'availability_ingests')
GROUP BY t.ingestId ORDER BY t.ingestId DESC;

-- Parsing datetime parts from ingest_id and concatenating them to form proper datetime
-- ingest_id stats for mapping
INSERT INTO core._stats (timestamp, metric, value)
SELECT datetime(
    substr(t.ingestId,1,4)||'-'||
    substr(t.ingestId,5,2)||'-'||
    substr(t.ingestId,7,2)||' '||
    substr(t.ingestId,9,2)||':'||
    substr(t.ingestId,11,2)||':'||
    substr(t.ingestId,13,2)
    ) AS timestamp,
    'mapping_ingests' AS metric, COUNT(t.mappingId) AS value
FROM core.mapping t
WHERE datetime(
    substr(t.ingestId,1,4)||'-'||
    substr(t.ingestId,5,2)||'-'||
    substr(t.ingestId,7,2)||' '||
    substr(t.ingestId,9,2)||':'||
    substr(t.ingestId,11,2)||':'||
    substr(t.ingestId,13,2)
    ) > (SELECT COALESCE(MAX(timestamp),'1970-01-01') FROM core._stats WHERE metric = 'mapping_ingests')
GROUP BY t.ingestId ORDER BY t.ingestId DESC;

-- Parsing datetime parts from ingest_id and concatenating them to form proper datetime
-- ingest_id stats for schedule
INSERT INTO core._stats (timestamp, metric, value)
SELECT datetime(
    substr(t.ingestId,1,4)||'-'||
    substr(t.ingestId,5,2)||'-'||
    substr(t.ingestId,7,2)||' '||
    substr(t.ingestId,9,2)||':'||
    substr(t.ingestId,11,2)||':'||
    substr(t.ingestId,13,2)
    ) AS timestamp,
    'schedule_ingests' AS metric, COUNT(t.scheduleId) AS value
FROM core.schedule t
WHERE datetime(
    substr(t.ingestId,1,4)||'-'||
    substr(t.ingestId,5,2)||'-'||
    substr(t.ingestId,7,2)||' '||
    substr(t.ingestId,9,2)||':'||
    substr(t.ingestId,11,2)||':'||
    substr(t.ingestId,13,2)
    ) > (SELECT COALESCE(MAX(timestamp),'1970-01-01') FROM core._stats WHERE metric = 'schedule_ingests')
GROUP BY t.ingestId ORDER BY t.ingestId DESC;
