-- Change my_schema_name to the PDK core schema
SET SEARCH_PATH TO 'my_schema_name';

-- Extract one or more program records with more detailed information
-- Without images and video descriptors
SELECT 
	 p."TMSId", p."rootId", p."connectorId", p."seriesId", p."versionId"
	,p."progType", p."subType", p.title_lang, p.desc_lang
	,pt."subType" AS "title_subType", pt.title
	,pei.lang AS "ep_lang", pei.title AS "ep_title", pei."number" AS "ep_num", pei.season, pei."seasonYear"
	,p."origAirDate", p."runTime", p.duration
	,p."colorCode", p."versionLabel", p."origAudioLang"
	,p."sourceType", p."origNetwork"
	,(
		SELECT d."description"
		FROM program_description d 
		WHERE 1=1
			AND d."TMSId" = p."TMSId"
		ORDER BY d."size" DESC 
		LIMIT 1
	) AS "longestDescription"
	,(
		SELECT ARRAY_AGG(g."genre")
		FROM program_genre g
		WHERE 1=1
			AND g."TMSId" = p."TMSId"
	) AS "genres"
	,(
		SELECT ARRAY_AGG(CONCAT_WS(':', pr."ratingsBody", pr."rating_code"))
		FROM program_rating pr
		WHERE 1=1
			AND pr."TMSId" = p."TMSId"
	) AS "programRatings"
	,(
		SELECT ARRAY_AGG(c."country")
		FROM program_country c 
		WHERE 1=1 
			AND c."TMSId" = p."TMSId"
	) AS "productionCountries"
	,(
		SELECT ARRAY_AGG(CONCAT_WS(':', pr."country", pr."type", pr."date"))
		FROM program_release pr
		WHERE 1=1
			AND pr."TMSId" = p."TMSId"
	) AS "releases"
	,(
		SELECT ARRAY_AGG(CONCAT_WS(':', CASE WHEN pa."won"=1 THEN 'won' ELSE 'nom' END, pa."award" , pa."category"))
		FROM program_award pa 
		WHERE 1=1 
			AND pa."TMSId" = p."TMSId"
	) AS "awards"
	,(
		SELECT ARRAY_AGG(CONCAT_WS(':', pc."role", CONCAT_WS(' ', cn."first", cn."middle", cn."last")) ORDER BY pc."ord" ASC)
		FROM program_cast pc
			JOIN celebrity_name cn 
				ON cn."personId" = pc."personId" AND cn."nameId" = pc."nameId" AND cn."lang" = 'en'
		WHERE 1=1 
			AND pc."TMSId" = p."TMSId"
	) AS "cast"
	,(
		SELECT ARRAY_AGG(CONCAT_WS(':', pc."role", CONCAT_WS(' ', cn."first", cn."middle", cn."last")) ORDER BY pc."ord" ASC)
		FROM program_crew pc
			JOIN celebrity_name cn 
				ON cn."personId" = pc."personId" AND cn."nameId" = pc."nameId" AND cn."lang" = 'en'
		WHERE 1=1 
			AND pc."TMSId" = p."TMSId"
	) AS "crew"
FROM 
	program p
	LEFT JOIN program_title pt ON p."TMSId" = pt."TMSId" AND pt."type"='full'
	LEFT JOIN program_epinfo pei ON p."TMSId" = pei."TMSId"
WHERE 1=1 
	AND p."TMSId" IN ('MV006254650000', 'EP019440730036', 'MV004864780000')
;
