#  -----------------------------------------------------------------------------
#  Gracenote (A Nielsen Company) Proprietary Information
#  This software is supplied under the terms of a license agreement or
#  nondisclosure agreement with Nielsen/Gracenote, Inc. and may not be copied
#  or disclosed except in accordance with the terms of that agreement.
#  Copyright(c) 2020-present. Gracenote, A Nielsen Company, All Rights Reserved.
#  -----------------------------------------------------------------------------

#  =============================================================================
#  Remove configured SQLite DB files from configured SQLite DB path
#  =============================================================================

while getopts 'c:' OPTION; do
	case $OPTION in
		c) CONFIG=$OPTARG ;;
	esac
done

if [ -z "$CONFIG" ]; then
	echo "USAGE: $0 -c my.conf"
	echo
fi

# The script can be invoked either from PDK root dir or from utils dir
if [ -e ./.utils ]; then
	DIR=..
else
	DIR=.
fi

export GXD_PDK_DIR=$DIR
export GXD_PDK_CONFIG=$CONFIG
export GXD_LOG=/dev/null

. $DIR/bin/functions.sh
load_config

echo
echo "Found the SQLite config/config file with the DB path: $SQLITE_DIR"
echo "If the path is not absolute, it is relative to the PDK root directory"
echo
echo "WARNING! Existing .db files in above SQLite DB path will be deleted!"
echo "Affected files: ${SCHEMA_PREFIX}_stage.db, ${SCHEMA_PREFIX}_core.db" #, ${SCHEMA_PREFIX}_park.db"
echo
echo "Are you sure you want to proceed (y/n)? "
read ANSWER
if [ "$ANSWER" = "${ANSWER#[Yy]}" ]; then
    exit 
fi

# SQLite DB path may be absolute or relative to PDK root directory, so we have to execute the delete from it
SAVED_DIR=$(pwd)
cd $DIR
rm $SQLITE_DIR/${SCHEMA_PREFIX}_stage.db
rm $SQLITE_DIR/${SCHEMA_PREFIX}_core.db
#rm $SQLITE_DIR/${SCHEMA_PREFIX}_park.db
cd $SAVED_DIR

echo "Done"
echo

