#!/bin/sh

#  -----------------------------------------------------------------------------
#  Gracenote (A Nielsen Company) Proprietary Information
#  This software is supplied under the terms of a license agreement or
#  nondisclosure agreement with Nielsen/Gracenote, Inc. and may not be copied
#  or disclosed except in accordance with the terms of that agreement.
#  Copyright(c) 2020-present. Gracenote, A Nielsen Company, All Rights Reserved.
#  -----------------------------------------------------------------------------

#  =============================================================================
#  Run stats SQL script against configured database
#  =============================================================================

while getopts 'c:s:o:p:' OPTION; do
	case $OPTION in
		c) CONFIG=$OPTARG ;;
		s) SUFFIX=$OPTARG ;;
		o) SCHEMA_OVERRIDE=$OPTARG ;;
		p) PARAMETERS=$OPTARG ;;
	esac
done

if [ -z "$CONFIG" ]; then
	echo "USAGE: $0 -c my.conf [-s alt_sql_suffix] [-o schema_override] [-p parameters]"
	exit
fi

# The script can be invoked either from PDK root dir or from utils dir
if [ -e ./.utils ]; then
	DIR=..
else
	DIR=.
fi

DATETIME=$(date +%Y%m%d%H%M%S)
export GXD_PDK_DIR=$DIR
export GXD_PDK_CONFIG=$CONFIG
export GXD_LOG=$GXD_PDK_DIR/logs/stats_$DATETIME.log

. $DIR/bin/functions.sh
load_config

# Check if PDK ingest job is running - we don't want to run stats scripts while DB is being updated
if [ -e $DIR/vars/job_status.var ]; then
	. $DIR/vars/job_status.var
fi
if [ "$JOB_STATUS" = "RUNNING" ]; then
	msg_ok "Ingest job is currently running. Exiting stats script.."
	exit
fi
if [ "$JOB_STATUS" = "ERROR" ]; then
	msg_ok "Ingest job did not complete normally. Exiting stats script.."
	exit
fi

# Check if another PDK stats job is (still) running
if [ -e $DIR/vars/stats_status.var ]; then
	. $DIR/vars/stats_status.var
fi
if [ "$STATS_STATUS" = "RUNNING" ]; then
	msg_ok "Stats job is currently running. Exiting stats script.."
	exit
fi

# Set stats running flag
echo "STATS_STATUS=RUNNING" > $DIR/vars/stats_status.var

if [ -z "$SUFFIX" ]; then
	:
else
	SUFFIX=_$SUFFIX
fi

if [ -z "$SCHEMA_OVERRIDE" ]; then
	SCHEMA=${SCHEMA_PREFIX}_core
else
	SCHEMA=${SCHEMA_OVERRIDE}
fi

if [ -z "$PARAMETERS" ]; then
	PARAMETERS=$SCHEMA
else
	PARAMETERS="$SCHEMA|$PARAMETERS"
fi

msg_ok "Running stats$SUFFIX using config $CONFIG.."
if [ $DATABASE = "SQLITE" ]; then
	$PYTHON $GXD_PDK_DIR/bin/db_sqlite/runsql.py $GXD_PDK_DIR/db/sqlite/stats$SUFFIX.sql "$PARAMETERS"
elif [ $DATABASE = "PGSQL" ]; then
	$PYTHON $GXD_PDK_DIR/bin/db_pgsql/runsql.py $GXD_PDK_DIR/db/pgsql/stats$SUFFIX.sql "$PARAMETERS"
elif [ $DATABASE = "MYSQL" ]; then
	$PYTHON $GXD_PDK_DIR/bin/db_mysql/runsql.py $GXD_PDK_DIR/db/mysql/stats$SUFFIX.sql "$PARAMETERS"
fi

if [ $? != 0 ]; then
	msg_err "STATS: $PYTHON <database>/runsql.py db/<database>/stats$SUFFIX.sql "$PARAMETERS" returned error, database: $DATABASE"
	echo "STATS_STATUS=ERROR" > $DIR/vars/stats_status.var
	exit 1
fi

echo "STATS_STATUS=OK" > $DIR/vars/stats_status.var

msg_ok "Done"
echo

